<?php

namespace ThemsahAddons;
/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @return Plugin An instance of the class.
	 * @since 1.2.0
	 * @access public
	 *
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {

	}

	public function widget_styles() {

	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/article-slider.php' );
        require_once( __DIR__ . '/widgets/themsah-image-box.php' );
		require_once( __DIR__ . '/widgets/share.php' );
		require_once( __DIR__ . '/widgets/image.php' );
		require_once( __DIR__ . '/widgets/services-box.php' );
		require_once( __DIR__ . '/widgets/slider.php' );
		require_once( __DIR__ . '/widgets/comment-slider.php' );
		require_once( __DIR__ . '/widgets/flip-box.php' );
		if ( function_exists( 'pll_the_languages' ) ) {
			require_once( __DIR__ . '/widgets/language.php' );
		}
		require_once( __DIR__ . '/widgets/archive-portfolio.php' );
		require_once( __DIR__ . '/widgets/related-portfolio.php' );
		require_once( __DIR__ . '/widgets/brand-slider.php' );
		require_once( __DIR__ . '/widgets/login-form.php' );
		require_once( __DIR__ . '/widgets/mini-cart.php' );
		require_once( __DIR__ . '/widgets/mobile-menu.php' );
		require_once( __DIR__ . '/widgets/progress-bar.php' );
		require_once( __DIR__ . '/widgets/menu.php' );
		require_once( __DIR__ . '/widgets/search.php' );
		require_once( __DIR__ . '/widgets/skill-bar.php' );
		require_once( __DIR__ . '/widgets/category.php' );
		require_once( __DIR__ . '/widgets/last-post-sidebar.php' );
		require_once( __DIR__ . '/widgets/archive-articles.php' );
		require_once( __DIR__ . '/widgets/information.php' );
		require_once( __DIR__ . '/widgets/team.php' );
		require_once( __DIR__ . '/widgets/article-picture.php' );
		require_once( __DIR__ . '/widgets/breadcrumb.php' );
		require_once( __DIR__ . '/widgets/the-content.php' );
		require_once( __DIR__ . '/widgets/the-title.php' );
		require_once( __DIR__ . '/widgets/cf7-form.php' );
		require_once( __DIR__ . '/widgets/comment.php' );
		require_once( __DIR__ . '/widgets/post-navigation.php' );
		if ( class_exists( 'WooCommerce' ) ) {
			require_once( __DIR__ . '/widgets/product-pages.php' );
			require_once( __DIR__ . '/widgets/add-to-cart.php' );
			require_once( __DIR__ . '/widgets/product-price.php' );
			require_once( __DIR__ . '/widgets/product-gallery.php' );
			require_once( __DIR__ . '/widgets/product-rating.php' );
			require_once( __DIR__ . '/widgets/product-related.php' );
			require_once( __DIR__ . '/widgets/product-excerpt.php' );
			require_once( __DIR__ . '/widgets/product-tabs.php' );
			require_once( __DIR__ . '/widgets/product-meta.php' );
			require_once( __DIR__ . '/widgets/archive-product.php' );
			require_once( __DIR__ . '/widgets/products.php' );
			require_once( __DIR__ . '/widgets/product-pages.php' );

		}
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Article_Slider() );
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Themsah_Image_Box() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Share() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Themsah_Image() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Service() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Themsah_slider_widget() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Comment_SLider() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Brand_Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Archive_Portfolio() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Related_Portfolio() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Login_Form() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Themsah_Flip_Box() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Cf7_Form() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Menu() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Mobile_Menu() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Progress_Bar() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Search() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Skill_Bar() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Category() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Articlearchive() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Last_Post_Sidebar() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Information() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Team() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Artpic() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Breadcrumb() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Content() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Thetitle() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Comment() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Post_Navigation() );
		if ( function_exists( 'pll_the_languages' ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Change_Language() );
		}
		if ( class_exists( 'WooCommerce' ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Mini_Cart() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WOOCOMERCEPAGES() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\ADDTOCART() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTPRICE() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTIMAGE() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTRATING() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\RELATEDPRODUCT() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTEXCERPT() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTTABS() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTMETA() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\ARCHIVEPRODUCT() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\PRODUCTS() );
		}
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
