<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class ADDTOCART extends Widget_Base
{

    public function get_name()
    {
        return 'add-to-cart';
    }

    public function get_title()
    {
        return __('افزودن به سبد خرید', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-product-add-to-cart';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('محتوا', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'important_note',
            [
                'label' => __('', 'themsah'),
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => __('این صرفا یک پیش نمایش از دکمه افزودن به سبد خرید و متغیرهای محصول برای استایل دهی است.', 'themsah'),
                'content_classes' => 'info-text-controller',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'style_section',
            [
                'label' => __('استایل', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'btn_heading',
            [
                'label' => esc_html__('دکمه', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->start_controls_tabs('box-btn');
        $this->start_controls_tab(
            'normal-btn',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'more-result-color',
            [
                'label' => __('رنگ متن', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} form.cart button' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'more-result-background',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} form.cart button',
                'separator' => 'after'
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab(
            'hover-btn',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'more-hover-result-color',
            [
                'label' => __('رنگ هاور', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} form.cart button:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'more-result-background-hover',
                'label' => esc_html__('پس زمینه هاور', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} form.cart button:hover',
                'separator' => 'after'
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'more-result-typography',
                'label' => __('تایپوگرافی دکمه افزودن به سبد خرید', 'plugin-domain'),
                'selector' => '{{WRAPPER}} form.cart button',
            ]
        );


        $this->add_responsive_control(
            'more-result-border-radius',
            [
                'label' => __('گردی گوشه ها', 'plugin-domain'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} form.cart button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'input_heading',
            [
                'label' => esc_html__('متغیر ها', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_responsive_control(
            'input-border-radius',
            [
                'label' => __('گردی گوشه های ورودی', 'plugin-domain'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .input-text , {{WRAPPER}} form.cart select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_control(
            'v-price-color',
            [
                'label' => __('رنگ قیمت متغیرها', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} form.cart .price' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'v-price-typography',
                'label' => __('تایپوگرافی قیمت متغیرها', 'plugin-domain'),
                'selector' => '{{WRAPPER}} form.cart .price',
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'stock_heading',
            [
                'label' => esc_html__('موجودی', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'stock-color',
            [
                'label' => __('رنگ متن موجودی انبار', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} form.cart p.stock.in-stock' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'stock-typography',
                'label' => __('تایپوگرافی متن موجودی انبار', 'plugin-domain'),
                'selector' => '{{WRAPPER}} form.cart p.stock.in-stock',
            ]
        );

        $this->end_controls_section();
    }


    protected function render()
    {
        global $post;

        if (!is_singular('product')) {
            $post = themsah_get_preview_product(); // phpcs:ignore
            setup_postdata($post);
        }

        woocommerce_template_single_add_to_cart();

        if (!is_singular('product')) {
            wp_reset_postdata();
        }
    }

    protected function content_template()
    {
    }
}

