<?php

namespace ThemsahAddons\Widgets;

use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Articlearchive extends Widget_Base {

	public function get_name() {
		return 'Articlearchive';
	}

	public function get_title() {
		return __( 'مقالات صفحه آرشیو', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-archive-posts';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);
		
		
        $this->add_control(
            'select-box',
            [
                'label' => esc_html__( 'نوع باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'type-1',
                'options' => [
                    'type-1'  => esc_html__( 'نوع اول', 'plugin-name' ),
                    'type-2' => esc_html__( 'نوع دوم', 'plugin-name' ),

                ],
            ]
        );

		$this->add_control(
			'count_in_line',
			[
				'label'   => __( 'تعداد در هر ردیف', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '4',
				'options' => [
					'6' => __( '2', 'themsah' ),
					'4' => __( '3', 'themsah' ),

				],
			]
		);

		$this->add_control(
			'more-text',
			[
				'label'   => __( 'متن دکمه ادامه مطلب', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => 'ادامه مطلب',
			]
		);
        $this->add_control(
            'read-more-icon',
            [
                'label' => esc_html__( 'آیکن دکمه ادامه مطلب', 'themsah' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-chevron-left',
                    'library' => 'solid',
                ],
            ]
        );

		$this->add_control(
			'title_count',
			[
				'label'   => __( 'تعداد کلمات عنوان', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'default' => '8',
			]
		);

        $this->add_control(
            'excerpt_count',
            [
                'label'   => __( 'تعداد کلمات خلاصه', 'themsah' ),
                'type'    => \Elementor\Controls_Manager::NUMBER,
                'default' => '20',
            ]
        );
		
		$this->add_control(
			'post_pers',
			[
				'label'   => __( 'تعداد پست در برگه', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 100,
				'step'    => 1,
				'default' => 3,
			]
		);


        $this->add_control(
            'default-image',
            [
                'label'   => __( 'تصویر شاخص پیشفرض', 'themsah' ),
                'type'    => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
                'default' => 'article_box',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'show_date',
            [
                'label'        => __( 'تاریخ انتشار', 'themsah' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => __( 'بله', 'themsah' ),
                'label_off'    => __( 'خیر', 'themsah' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'show_excerpt',
            [
                'label'        => __( 'خلاصه مطلب', 'themsah' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => __( 'بله', 'themsah' ),
                'label_off'    => __( 'خیر', 'themsah' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );


		$this->end_controls_section();
        $this->start_controls_section(
            'content_sections',
            [
                'label' => __( 'تنظیمات باکس', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label'     => __( 'پس زمینه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box,{{WRAPPER}} .article-box-type-2' => 'background: {{VALUE}}' ,
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow',
                'label'    => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .article-box,{{WRAPPER}} .article-box-type-2',
            ]
        );



        $this->add_responsive_control(
            'box-border-radius',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2,{{WRAPPER}} .article-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .article-box,{{WRAPPER}} .article-box-type-2',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color_hover',
            [
                'label'     => __( 'پس زمینه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box:hover,{{WRAPPER}} .article-box-type-2:hover' => 'background: {{VALUE}}' ,
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_hover',
                'label'    => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .article-box:hover,{{WRAPPER}} .article-box-type-2:hover',
            ]
        );

        $this->add_responsive_control(
            'box-border-radius-hover',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2:hover,{{WRAPPER}} .article-box:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border-hover',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .article-box:hover,{{WRAPPER}} .article-box-type-2:hover',
            ]
        );

        $this->add_responsive_control(
            'hover-top-value',
            [
                'label' => __( 'مقدار پرش به بالا', 'themsah' ),
                'type'  => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .article-box:hover,{{WRAPPER}} .article-box-type-2:hover' => 'transform: translateY(-{{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} .article-box,{{WRAPPER}} .article-box-type-2' => 'margin-top: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'image-style',
            [
                'label' => __( 'تصویر', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image-border-radius',
            [
                'label'      => __( 'گردی گوشه ها', 'themsah' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .article-box .thumbnail,{{WRAPPER}} .article-box-type-2 .thumbnail img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'image-padding',
            [
                'label'      => __( 'فاصله داخلی', 'themsah' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .article-box-type-2 .thumbnail' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'image-icon-color',
            [
                'label'     => __( 'رنگ آیکن روی عکس', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .thumbnail .overlay i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );

        $this->add_control(
            'image-icon-bac',
            [
                'label'     => __( 'رنگ پس زمنیه آیکن روی عکس', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .thumbnail .overlay i' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );


        $this->add_control(
            'image-cover',
            [
                'label'     => __( 'رنگ پس زمینه روکش تصویر هنگام هاور', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .thumbnail .overlay' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );

        $this->add_responsive_control(
            'height-image',
            [
                'label' => esc_html__( 'ارتفاع عکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 300,
                ],
                'selectors' => [
                    '{{WRAPPER}} img' =>  'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'box-content-style',
            [
                'label' => __( 'تنظیمات محتوای باکس', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'date_heading',
            [
                'label' => esc_html__( 'تاریخ', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'date-typography',
                'label'    => __( 'تایپوگرافی تاریخ', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .article-box-type-2 .date span , {{WRAPPER}} .article-box .date',
            ]
        );

        $this->add_responsive_control(
            'date-align',
            [
                'label' => esc_html__( 'چینش افقی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'right' => [
                        'title' => esc_html__( 'راست', 'themsah' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'وسط', 'themsah' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'left' => [
                        'title' => esc_html__( 'چپ', 'themsah' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .date' => 'text-align:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'date-color',
            [
                'label'     => __( 'رنگ تاریخ', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .thumbnail .date' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box-type-2 .date' => 'color: {{VALUE}}',
                ],
            ]
        );


        $this->add_control(
            'date-bac',
            [
                'label'     => __( 'رنگ پس زمینه تاریخ', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .thumbnail .date' => 'background: {{VALUE}}',
                ],
                'condition' =>array(
                    'select-box' => 'type-1',
                ),
            ]
        );

        $this->add_control(
            'before-date-color',
            [
                'label'     => __( 'رنگ خط زیر تاریخ', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .date span::before' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'title_heading',
            [
                'label' => esc_html__( 'عنوان', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'title-typography',
                'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .article-box h3 , {{WRAPPER}} .article-box-type-2 h3',
            ]
        );

        $this->add_responsive_control(
            'title-align',
            [
                'label' => esc_html__( 'چینش افقی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'right' => [
                        'title' => esc_html__( 'راست', 'themsah' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'وسط', 'themsah' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'left' => [
                        'title' => esc_html__( 'چپ', 'themsah' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .article-box h3,{{WRAPPER}} .article-box-type-2 h3' => 'text-align:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title-color',
            [
                'label'     => __( 'رنگ عنوان', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box-type-2 h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title-color-hover',
            [
                'label'     => __( 'رنگ هاور عنوان', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box:hover h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box-type-2:hover h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'excerpt_heading',
            [
                'label' => esc_html__( 'خلاصه', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'excerpt-typography',
                'label'    => __( 'تایپوگرافی خلاصه', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .article-box p,{{WRAPPER}} .article-box-type-2 p',
            ]
        );

        $this->add_responsive_control(
            'excerpt-align',
            [
                'label' => esc_html__( 'چینش افقی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'right' => [
                        'title' => esc_html__( 'راست', 'themsah' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'center' => [
                        'title' => esc_html__( 'وسط', 'themsah' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'left' => [
                        'title' => esc_html__( 'چپ', 'themsah' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .article-box p,{{WRAPPER}} .article-box-type-2 p' => 'text-align:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'excerpt-color',
            [
                'label'     => __( 'رنگ خلاصه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box-type-2 p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'excerpt-color-hover',
            [
                'label'     => __( 'رنگ هاور خلاصه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box:hover p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box-type-2:hover p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'cat_heading',
            [
                'label' => esc_html__( 'دسته بندی', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'cat-typography',
                'label'    => __( 'تایپوگرافی دسته بندی', 'themsah' ),
                
                'selectors' => '{{WRAPPER}} .article-box .article-box-footer span.cat a',
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );


        $this->add_control(
            'cat-color',
            [
                'label'     => __( 'رنگ دسته بندی', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box .article-box-footer span.cat'   => 'color: {{VALUE}}',
                    '{{WRAPPER}} .article-box .article-box-footer span.cat a' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-1',
                ],
                'separator' => 'before',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'btn_section',
            [
                'label' => __( 'دکمه', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'btn_typography',
                'label'    => __( 'تایپوگرافی', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .article-box .article-box-footer a.more,{{WRAPPER}} .article-box-type-2 .article-box-footer a.more',
            ]
        );


        $this->add_responsive_control(
            'btn-width',
            [
                'label' => esc_html__( 'نوع باکس', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '100%',
                'options' => [
                    'max-content'  => esc_html__( 'در متن', 'themsah' ),
                    '100%' => esc_html__( 'تمام عرض', 'themsah' ),
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .article-box-footer a.more' => 'width: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_responsive_control(
            'btn-border-radius',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .article-box-footer a.more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-padding',
            [
                'label' => __( 'فاصله داخلی', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .article-box-footer a.more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-space',
            [
                'label' => __( 'فاصله', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2 .article-box-footer a.more' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ]
            ]
        );

        $this->start_controls_tabs('box-btn');
        $this->start_controls_tab(
            'normal-btn',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-color-button',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .article-box-type-2 .article-box-footer a.more',
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'text-color-button',
            [
                'label' => esc_html__( 'رنگ متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.more' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-btn',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'hover-background-more-color',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .article-box-type-2:hover .article-box-footer a.more',
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'text-hover-color-button',
            [
                'label' => esc_html__( 'رنگ متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .article-box-type-2:hover .article-box-footer a.more,{{WRAPPER}} .article-box:hover .article-box-footer a.more' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

		$this->start_controls_section(
			'pagination-style',
			[
				'label' => __( 'استایل شمارشگر صفحات', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


        $this->add_responsive_control(
            'item-border-radius',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} span.current,{{WRAPPER}} a.page-numbers' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->start_controls_tabs( 'pagination' );
		$this->start_controls_tab( 'normal-pagination', [ 'label' => __( 'عادی', 'thensah' ) ] );

		$this->add_control(
			'number-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'pn-icon-color',
			[
				'label'     => __( 'رنگ ایکن های قبل و بعد', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a.prev svg g path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .pagination .page-numbers a.next svg g path' => 'fill: {{VALUE}}',
				],
			]
		);


		$this->end_controls_tab();

		$this->start_controls_tab( 'hover-pagination', [ 'label' => __( 'هاور', 'thensah' ) ] );
		$this->add_control(
			'number-hover-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-hover-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-hover-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'pn-hover-icon-color',
			[
				'label'     => __( 'رنگ ایکن های قبل و بعد', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a.prev:hover svg g path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .pagination .page-numbers a.next:hover svg g path' => 'fill: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'active-pagination', [ 'label' => __( 'فعال', 'thensah' ) ] );
		$this->add_control(
			'number-active-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-active-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-active-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'border-color: {{VALUE}}',
				],
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display();
        $read_more_icon   = $settings['read-more-icon'];
        $show_date   = $settings['show_date'];
        $show_excerpt   = $settings['show_excerpt'];
		if ( ! is_category() && ! is_tag() && !is_search()) { ?>

			<?php
			$post_pers = $settings['post_pers']; ?>
			<?php
			$paged        = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
			$blog_archive = new \WP_Query( array(
				'post_type'      => 'post',
				'posts_per_page' => $post_pers,
				'paged'          => $paged
			) );
			?>


			<?php if ( $blog_archive->have_posts() ) :?>
                <div class="row m-0 justify-content-end alignment mb-4 pt-3 d-none d-md-flex">
                    <i class="fas fa-th active grid" aria-hidden="true" title="گرید"></i>
                    <i class="fas fa-bars bar" aria-hidden="true" title="خطی"></i>
                </div>

                <div class="row article-archive-page">
					<?php while ( $blog_archive->have_posts() ) : $blog_archive->the_post(); ?>
                        <div class="col-12 col-md-<?php echo $settings['count_in_line']; ?> article-col">
                            <?php if($settings['select-box'] === 'type-1') {
                                article_box($settings['more-text'], $settings['title_count'] , $settings['excerpt_count'] ,'grid',$settings,$read_more_icon,$show_date,$show_excerpt);
                            }else{
                                article_box_type_2($settings['more-text'], $settings['title_count'] , $settings['excerpt_count'] ,'grid',$settings,$read_more_icon,$show_date,$show_excerpt);
                            } ?>
                        </div>
					<?php endwhile; ?>
                </div>



			<?php if ( $blog_archive->found_posts ) { ?>
                <div class="row justify-content-center pagination">
					<?php
					echo paginate_links( array(
						'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
						'total'        => $blog_archive->max_num_pages,
						'current'      => max( 1, get_query_var( 'paged' ) ),
						'format'       => '?paged=%#%',
						'show_all'     => false,
						'type'         => 'list',
						'end_size'     => 2,
						'mid_size'     => 2,
						'prev_next'    => true,
						'prev_text'    => '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(591.434 1094.375) rotate(180)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>',
						'next_text'    => '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(-580.833 -1084.125)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>',
						'add_args'     => false,
						'add_fragment' => '',
					) );
					?>
                </div>
			<?php } ?>
				<?php wp_reset_postdata(); ?>
			<?php else : ?>
                <p><?php _e( 'Sorry, no posts matched your criteria.' ); ?></p>
			<?php endif; ?>
		<?php } ?>
		<?php if ( is_category() || is_tag() || is_search() ) { ?>
			<?php if ( have_posts() ) { ?>
                <div class="row m-0 justify-content-end alignment mb-4 pt-3 d-none d-md-flex">
                    <i class="fas fa-th active grid" aria-hidden="true" title="گرید"></i>
                    <i class="fas fa-bars bar" aria-hidden="true" title="خطی"></i>
                </div>
                <div class="row article-archive-page">
					<?php while ( have_posts() ) {
						the_post(); ?>
                          <div class="col-12 col-md-<?php echo $settings['count_in_line']; ?> article-col">
                            <?php if($settings['select-box'] === 'type-1') {
                                article_box($settings['more-text'], $settings['title_count'] , $settings['excerpt_count'] ,'grid',$settings,$read_more_icon,$show_date,$show_excerpt);
                            }else{
                                article_box_type_2($settings['more-text'], $settings['title_count'] , $settings['excerpt_count'] ,'grid',$settings,$read_more_icon,$show_date,$show_excerpt);
                            } ?>
                        </div>
					<?php } ?>
                </div>
			<?php } ?>
                <div class="row justify-content-center">
					<?php the_posts_pagination( array(
						'type'               => 'list',
						'prev_text'          => __( '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(591.434 1094.375) rotate(180)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>', 'themsah' ),
						'next_text'          => __( '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(-580.833 -1084.125)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>', 'themsah' ),
						'screen_reader_text' => __( ' ' ),
					) ); ?>
                </div>

		<?php } ?>
        <script>
            $(document).ready(function (){
                $('body').on('click', 'i.bar', function () {
                    $('.article-col').removeClass('col-md-<?php echo $settings['count_in_line']; ?>');
                    $('.article-col .article-box').addClass('bar');
                    $(this).addClass('active');
                    $('i.grid').removeClass('active');
                });

                $('body').on('click', 'i.grid', function () {
                    $('.article-col').addClass('col-md-<?php echo $settings['count_in_line']; ?>');
                    $('.article-col .article-box').removeClass('bar');
                    $(this).addClass('active');
                    $('i.bar').removeClass('active');
                });

                //2
                $('body').on('click', 'i.bar', function () {
                    $('.article-col').removeClass('col-md-<?php echo $settings['count_in_line']; ?>');
                    $('.article-col .article-box-type-2').addClass('bar');
                    $(this).addClass('active');
                    $('i.grid').removeClass('active');
                });

                $('body').on('click', 'i.grid', function () {
                    $('.article-col').addClass('col-md-<?php echo $settings['count_in_line']; ?>');
                    $('.article-col .article-box-type-2').removeClass('bar');
                    $(this).addClass('active');
                    $('i.bar').removeClass('active');
                });
            });
        </script>
	<?php }


	protected function _content_template() {
	}
}
