<?php

namespace ThemsahAddons\Widgets;

use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Archive_Portfolio extends Widget_Base {

	public function get_name() {
		return 'archive-portfolio';
	}

	public function get_title() {
		return __( 'نمونه کارها', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-gallery-justified';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);

        $this->add_control(
            'select-box',
            [
                'label' => esc_html__( 'نوع باکس', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'type-1',
                'options' => [
                    'type-1'  => esc_html__( 'نوع اول', 'themsah' ),
                    'type-2' => esc_html__( 'نوع دوم', 'themsah' ),

                ],
            ]
        );



		$this->add_control(
			'default-image',
			[
				'label'   => __( 'تصویر شاخص پیشفرض', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'post_per',
			[
				'label'   => __( 'تعداد پست در برگه', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 1,
				'max'     => 20,
				'step'    => 1,
				'default' => 8,
			]
		);

		$this->add_control(
			'count_in_line',
			[
				'label'   => __( 'تعداد در هر ردیف', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '4',
				'options' => [
					'4' => __( '3', 'themsah' ),
					'3' => __( '4', 'themsah' ),

				],
			]
		);

        $this->add_control(
            'tabs-position',
            [
                'label' => esc_html__( 'جایگاه تب ها', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'top',
                'options' => [
                    'top'  => esc_html__( 'بالا', 'themsah' ),
                    'right' => esc_html__( 'راست', 'themsah' ),
                    'bottom' => esc_html__( 'پایین', 'themsah' ),
                    'left' => esc_html__( 'چپ', 'themsah' ),
                ],
            ]
        );

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'show_active',
			[
				'label'   => __( '', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::HIDDEN,
				'default' => '',
			]
		);
		$repeater->add_control(
			'port_cat',
			[
				'label'   => __( 'انتخاب دسته بندی', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => ' ',
				'options' => themsah_portfolio_cat()
			]
		);


		$repeater->add_control(
			'list_title', [
				'label'       => __( 'نام دسته بندی', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'دسته بندی', 'themsah' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'tab-list',
			[
				'label'       => __( 'Repeater List', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'show_active' => __( 'show active' ),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'content_section5',
			[
				'label' => __( 'تنظیمات تب های بالای باکس', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'tabs-spacing',
            [
                'label'      => __( 'فاصله تب ها از محتوا', 'themsah' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 40,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .themsah-projects.tabs-top .projects-nav-tab' => 'margin-bottom:{{SIZE}}{{UNIT}} !important',
                    '{{WRAPPER}} .themsah-projects.tabs-bottom .projects-nav-tab' => 'margin-top:calc({{SIZE}}{{UNIT}} - 30{{UNIT}}) !important',
                ],
            ]
        );

		$this->add_control(
			'text_align',
			[
				'label'   => __( 'چینش', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'end'    => [
						'title' => __( 'پایان', 'themsah' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon'  => 'fa fa-align-center',
					],
					'start'  => [
						'title' => __( 'آغاز', 'themsah' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'default' => 'start',
				'toggle'  => false,
				'selectors'  => [
					'{{WRAPPER}} .themsah-projects' => 'align-items:{{VALUE}} !important;',
				],
			]
		);


		$this->add_responsive_control(
			'item-spacing',
			[
				'label'      => __( 'فاصله بین تب ها', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 30,
				],
				'selectors'  => [
					'{{WRAPPER}} .themsah-projects:not(.tabs-right):not(.tabs-left) .projects-nav-tab a:not(:first-child):not(:last-child)' => 'margin-inline:calc({{SIZE}}{{UNIT}} / 2) !important',
					'{{WRAPPER}} .themsah-projects:not(.tabs-right):not(.tabs-left) .projects-nav-tab a:first-child'                        => 'margin-inline-end:calc({{SIZE}}{{UNIT}} / 2) !important;',
					'{{WRAPPER}} .themsah-projects:not(.tabs-right):not(.tabs-left) .projects-nav-tab a:last-child'                         => 'margin-inline-start:calc({{SIZE}}{{UNIT}} / 2) !important;',
                    '{{WRAPPER}} .themsah-projects:not(.tabs-top):not(.tabs-bottom) .projects-nav-tab a:not(:first-child):not(:last-child)' => 'margin-block:calc({{SIZE}}{{UNIT}} / 2) !important;',
                    '{{WRAPPER}} .themsah-projects:not(.tabs-top):not(.tabs-bottom) .projects-nav-tab a:first-child'                        => 'margin-bottom:calc({{SIZE}}{{UNIT}} / 2) !important;',
                    '{{WRAPPER}} .themsah-projects:not(.tabs-top):not(.tabs-bottom) .projects-nav-tab a:last-child'                         => 'margin-top:calc({{SIZE}}{{UNIT}} / 2) !important;',
				],
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'tab-item-typography',
				'label'    => __( 'تایپوگرافی متن تب ها', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .projects-nav-tab a',
			]
		);



        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'tab-background',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .projects-nav-tab',
            ]
        );


        $this->add_control(
            'border-radius-tab',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .projects-nav-tab' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'padding-tab',
            [
                'label' => esc_html__( 'فاصله داخلی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .projects-nav-tab' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .projects-nav-tab',
            ]
        );


        $this->add_control(
            'hover-type',
            [
                'label' => esc_html__( 'نوع هاور و فعال', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'underline',
                'options' => [
                    'underline'  => esc_html__( 'زیر خط دار', 'themsah' ),
                    'background' => esc_html__( 'پس زمینه', 'themsah' ),
                ],
            ]
        );

		$this->start_controls_tabs( 'tabs' );
		$this->start_controls_tab( 'normal-tabs-item', [ 'label' => __( 'عادی', 'themsah' ) ] );
		$this->add_control(
			'tab-color',
			[
				'label'     => __( 'رنگ متن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects-nav-tab a' => 'color: {{VALUE}}',
				],
			]
		);


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'item-background',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .projects-nav-tab a',
                'condition' => [
                        'hover-type' => 'background'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_item',
                'label'    => __( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .projects-nav-tab a',
                'condition' => array(
                    'hover-type' => 'background'
                ),
            ]
        );

        $this->add_control(
            'border-radius-item',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .projects-nav-tab a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'condition' => [
                    'hover-type' => 'background'
                ]
            ]
        );

		$this->end_controls_tab();
		$this->start_controls_tab( 'hover-tabs-item', [ 'label' => __( 'هاور', 'themsah' ) ] );
		$this->add_control(
			'tab-color-hover',
			[
				'label'     => __( 'رنگ متن ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects-nav-tab a:hover' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'item-background-hover',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .projects-nav-tab a:hover',
                'condition' => [
                    'hover-type' => 'background'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_item_hover',
                'label'    => __( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .projects-nav-tab a:hover',
                'condition' => array(
                    'hover-type' => 'background'
                ),
            ]
        );

		$this->end_controls_tab();
		$this->start_controls_tab( 'active-tabs-item', [ 'label' => __( 'فعال', 'themsah' ) ] );
		$this->add_control(
			'tab-color-active',
			[
				'label'     => __( 'رنگ فعال عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects-nav-tab a.active'  => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .projects-nav-tab a::before' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .projects-nav-tab a::after'  => 'background-color: {{VALUE}} !important',
				],
			]
		);

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'item-background-active',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .projects-nav-tab a.active',
                'condition' => [
                    'hover-type' => 'background'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_item_active',
                'label'    => __( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .projects-nav-tab a.active',
                'condition' => array(
                    'hover-type' => 'background'
                ),
            ]
        );

		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->end_controls_section();
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'تنظیمات باکس', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'box-border-radius',
			[
				'label'      => __( 'گردی گوشه ها', 'themsah' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .project-box'          => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .project-box .overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .project-box-2 ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					'{{WRAPPER}} .project-box-2::after ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow',
				'label'    => __( 'سایه باکس', 'themsah' ),
				'selector' => '{{WRAPPER}} .project-box',
				'condition' => array(
				    'select-box' => 'type-1'
				    ),
			]
		);

		$this->add_responsive_control(
			'box-height',
			[
				'label'      => __( 'ارتفاع باکس', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 1000,
						'step' => 5,
					],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 300,
				],
				'selectors'  => [
					'{{WRAPPER}} .project-box' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .project-box-2 img' => 'height: {{SIZE}}{{UNIT}} !important;',
				],
				'separator'  => 'after'
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'     => 'cover-background',
				'label'    => __( 'پس زمینه روکش باکس', 'themsah' ),
				'types'    => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .project-box .overlay .background',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box h3' => 'color: {{VALUE}}' ,
                    '{{WRAPPER}} .project-box-2 h3' => 'color: {{VALUE}}' ,
				],
				'separator' => 'before'
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title-typography',
				'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
				'selector' => '{{WRAPPER}} .project-box h3 , {{WRAPPER}} .project-box-2 h3',
			]
		);

        $this->add_control(
            'cat_color',
            [
                'label'     => __( 'رنگ دسته بندی', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .box-info-2 span' => 'color: {{VALUE}}' ,
                ],
                'separator' => 'before',
                'condition' => array(
                    'select-box' => 'type-2'
                ),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'cat-typography',
                'label'    => __( 'تایپوگرافی دسته بندی', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .box-info-2 span',
                'condition' => array(
                    'select-box' => 'type-2'
                ),
            ]
        );

		$this->add_control(
			'icon_color',
			[
				'label'     => __( 'رنگ آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box .overlay i' => 'color: {{VALUE}}',
				],
				'separator' => 'before',
                'condition' => array(
                    'select-box' => 'type-1'
                ),

			]
		);

		$this->add_control(
			'icon_color_bac',
			[
				'label'     => __( 'رنگ پس زمنیه آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box .overlay i' => 'background: {{VALUE}}',
				],
                'condition' => array(
                    'select-box' => 'type-1'
                ),
			]
		);


		$this->end_controls_section();
		$this->start_controls_section(
			'pagination-style',
			[
				'label' => __( 'استایل شمارشگر صفحات', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'pagination' );
		$this->start_controls_tab( 'normal-pagination', [ 'label' => __( 'عادی', 'thensah' ) ] );

		$this->add_control(
			'number-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'pn-icon-color',
			[
				'label'     => __( 'رنگ ایکن های قبل و بعد', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a.prev svg g path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .pagination .page-numbers a.next svg g path' => 'fill: {{VALUE}}',
				],
			]
		);
		  $this->add_control(
            'border-radius-pagination',
            [
                'label' => esc_html__( 'انحنای مرز', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .page-numbers' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->end_controls_tab();

		$this->start_controls_tab( 'hover-pagination', [ 'label' => __( 'هاور', 'thensah' ) ] );
		$this->add_control(
			'number-hover-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-hover-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-hover-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'pn-hover-icon-color',
			[
				'label'     => __( 'رنگ ایکن های قبل و بعد', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers a.prev:hover svg g path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .pagination .page-numbers a.next:hover svg g path' => 'fill: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'active-pagination', [ 'label' => __( 'فعال', 'thensah' ) ] );
		$this->add_control(
			'number-active-color',
			[
				'label'     => __( 'رنگ متن شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-active-bac',
			[
				'label'     => __( 'رنگ پس زمینه شماره ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'number-active-border-color',
			[
				'label'     => __( 'رنگ حاشیه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination .page-numbers li span.current' => 'border-color: {{VALUE}}',
				],
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( is_archive() || is_singular('elementor_library') ) {
			if ( ! is_tax() && !is_search() ) {
				$post_per = $settings['post_per'];
				$paged        = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
				$blog_archive = new \WP_Query( array(
					'post_type'      => 'portfolio',
					'posts_per_page' => $post_per,
					'paged'          => $paged
				) );
				if ( $blog_archive->have_posts() ) :?>
                    <div class="row">
						<?php while ( $blog_archive->have_posts() ) {
							$blog_archive->the_post(); 
						 if($settings['select-box'] === 'type-1') {
						?>
                            <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12">
                                <a href="<?php the_permalink(); ?>" class="project-box">
                                    <img src="<?php if ( has_post_thumbnail() ) {
										the_post_thumbnail_url( 'portfolio_box' );
									} else {
										echo $settings['default-image']['url'];
									} ?>" width="282" height="292" alt="">
                                    <div class="overlay">
                                        <div class="background"></div>
                                        <i class="fas fa-link" aria-hidden="true"></i>
                                    </div>
                                    <h3><?php the_title(); ?></h3>
                                </a>
                            </div>
						<?php } else{ ?>
							   <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12 portfolioo">
                                                    <a href="<?php the_permalink(); ?>" class="project-box-2">
                                                        <img src="<?php if ( has_post_thumbnail() ) {
                                                            the_post_thumbnail_url( 'portfolio_box' );
                                                        } else {
                                                            echo $settings['default-image']['url'];
                                                        } ?>" width="282" height="292" alt="">
                                                        <div class="box-info-2">
                                                        <h3><?php the_title(); ?></h3>
                                                        <span><?php the_portfolio_cat_not_a(); ?></span>
                                                        </div>
                                                    </a>
                                                </div>
							 <?php }?>
						<?php } ?>
                    </div>
					<?php if ( $blog_archive->found_posts ) { ?>
                        <div class="row justify-content-center pagination">
							<?php
							echo paginate_links( array(
								'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
								'total'        => $blog_archive->max_num_pages,
								'current'      => max( 1, get_query_var( 'paged' ) ),
								'format'       => '?paged=%#%',
								'show_all'     => false,
								'type'         => 'list',
								'end_size'     => 2,
								'mid_size'     => 2,
								'prev_next'    => true,
								'prev_text'    => '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(591.434 1094.375) rotate(180)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>',
								'next_text'    => '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(-580.833 -1084.125)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>',
								'add_args'     => false,
								'add_fragment' => '',
							) );
							?>
                        </div>
					<?php } ?>
					<?php wp_reset_postdata(); ?>
				<?php else : ?>
                    <p><?php _e( 'Sorry, no posts matched your criteria.' ); ?></p>
				<?php endif; ?>
			<?php } elseif ( is_tax() || is_search() ) {
				if ( have_posts() ) { ?>
                    <div class="row">
						<?php while ( have_posts() ) {
							the_post(); 
						if($settings['select-box'] === 'type-1'){
						?>
                            <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12">
                                <a href="<?php the_permalink(); ?>" class="project-box">
                                    <img src="<?php if ( has_post_thumbnail() ) {
										the_post_thumbnail_url( 'portfolio_box' );
									} else {
										echo $settings['default-image']['url'];
									} ?>" width="282" height="292" alt="">
                                    <div class="overlay">
                                        <div class="background"></div>
                                        <i class="fas fa-link" aria-hidden="true"></i>
                                    </div>
                                    <h3><?php the_title(); ?></h3>
                                </a>
                            </div>
						<?php }else { ?>
						  <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12 portfolioo">
                                                    <a href="<?php the_permalink(); ?>" class="project-box-2">
                                                        <img src="<?php if ( has_post_thumbnail() ) {
                                                            the_post_thumbnail_url( 'portfolio_box' );
                                                        } else {
                                                            echo $settings['default-image']['url'];
                                                        } ?>" width="282" height="292" alt="">
                                                        <div class="box-info-2">
                                                        <h3><?php the_title(); ?></h3>
                                                        <span><?php the_portfolio_cat_not_a(); ?></span>
                                                        </div>
                                                    </a>
                                                </div>
						<?php } ?>
						<?php } ?>
                    </div>
                    <div class="row justify-content-center">
						<?php the_posts_pagination( array(
							'type'               => 'list',
							'prev_text'          => __( '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(591.434 1094.375) rotate(180)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>', 'themsah' ),
							'next_text'          => __( '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 10.6 10.25">
												<g id="Group_326" data-name="Group 326" transform="translate(-580.833 -1084.125)">
													<path id="Path_156" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(572.243 1078.125)" fill="#5d6576"/>
													<path id="Path_156-2" data-name="Path 156" d="M13.715,6l1.2,1.2-3.912,3.921,3.912,3.921-1.2,1.2L8.59,11.125Z" transform="translate(576.514 1078.125)" fill="#5d6576"/>
												</g>
											</svg>', 'themsah' ),
							'screen_reader_text' => __( ' ' ),
						) ); ?>
                    </div>
					<?php wp_reset_postdata(); ?>
				<?php } else { ?>
                    <p><?php _e( 'Sorry, no posts matched your criteria.' ); ?></p>
				<?php } ?>

			<?php }
		} else { ?>
            <?php if($settings['select-box'] === 'type-1') { ?>
            <div class="themsah-projects projects<?= ' tabs-'.$settings['tabs-position'].' hover-'.$settings['hover-type']; ?>">
				<?php if ( $settings['tab-list'] ) { ?>
                    <div class="nav nav-tabs d-flex justify-content-<?php echo $settings['text_align']; ?> projects-nav-tab"
                         id="nav-tab"
                         role="tablist">
						<?php $i = 1;
						foreach ( $settings['tab-list'] as $item ) {
							$i ++; ?>
                            <a class="nav-item nav-link <?php echo $item['show_active']; ?>" id="tab<?php echo $i; ?>"
                               data-toggle="tab" href="#content-<?php echo $i; ?>" role="tab"
                               aria-controls="all" aria-selected="true"><?php echo $item['list_title']; ?></a>
						<?php } ?>
                    </div>
				<?php } ?>
				<?php if ( $settings['tab-list'] ) { ?>
                    <div class="tab-content" id="nav-tabContent">
						<?php $i = 1;
						foreach ( $settings['tab-list'] as $item ) {
							$i ++; ?>
                            <div class="tab-pane fade <?php echo $item['show_active']; ?>"
                                 id="content-<?php echo $i; ?>"
                                 role="tabpanel" aria-labelledby="all-tab">
								<?php
								if ( $item['port_cat'] == ' ' ) {
									$args = array(
										'post_type'      => 'portfolio',
										'posts_per_page' => $settings['post_per'],
									);
								} else {
									$args = array(
										'post_type'      => 'portfolio',
										'posts_per_page' => $settings['post_per'],
										'tax_query'      => array(
											array(
												'taxonomy' => 'portfolio_cat',
												'field'    => 'term_id',
												'terms'    => $item['port_cat'],
											)
										)
									);
								}
								$the_query = new \WP_Query( $args ); ?>
								<?php if ( $the_query->have_posts() ) { ?>
                                    <div class="row">
										<?php while ( $the_query->have_posts() ) {
											$the_query->the_post(); ?>
                                            <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12">
                                                <a href="<?php the_permalink(); ?>" class="project-box">
                                                    <img src="<?php if ( has_post_thumbnail() ) {
														the_post_thumbnail_url( 'portfolio_box' );
													} else {
														echo $settings['default-image']['url'];
													} ?>" width="282" height="292" alt="">
                                                    <div class="overlay">
                                                        <div class="background"></div>
                                                        <i class="fas fa-link" aria-hidden="true"></i>
                                                    </div>
                                                    <h3><?php the_title(); ?></h3>
                                                </a>
                                            </div>
										<?php } ?>
                                    </div>
								<?php } ?>
                            </div>
						<?php } ?>
                    </div>
				<?php } ?>
            </div>
                <?php } else { ?>
                <div class="themsah-projects projects-2<?= ' tabs-'.$settings['tabs-position'].' hover-'.$settings['hover-type']; ?>">
                    <?php if ( $settings['tab-list'] ) { ?>
                        <div class="nav nav-tabs d-flex justify-content-<?php echo $settings['text_align']; ?> projects-nav-tab"
                             id="nav-tab"
                             role="tablist">
                            <?php $i = 1;
                            foreach ( $settings['tab-list'] as $item ) {
                                $i ++; ?>
                                <a class="nav-item nav-link <?php echo $item['show_active']; ?>" id="tab<?php echo $i; ?>"
                                   data-toggle="tab" href="#content-<?php echo $i; ?>" role="tab"
                                   aria-controls="all" aria-selected="true"><?php echo $item['list_title']; ?></a>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    <?php if ( $settings['tab-list'] ) { ?>
                        <div class="tab-content" id="nav-tabContent">
                            <?php $i = 1;
                            foreach ( $settings['tab-list'] as $item ) {
                                $i ++; ?>
                                <div class="tab-pane fade <?php echo $item['show_active']; ?>"
                                     id="content-<?php echo $i; ?>"
                                     role="tabpanel" aria-labelledby="all-tab">
                                    <?php
                                    if ( $item['port_cat'] == ' ' ) {
                                        $args = array(
                                            'post_type'      => 'portfolio',
                                            'posts_per_page' => $settings['post_per'],
                                        );
                                    } else {
                                        $args = array(
                                            'post_type'      => 'portfolio',
                                            'posts_per_page' => $settings['post_per'],
                                            'tax_query'      => array(
                                                array(
                                                    'taxonomy' => 'portfolio_cat',
                                                    'field'    => 'term_id',
                                                    'terms'    => $item['port_cat'],
                                                )
                                            )
                                        );
                                    }
                                    $the_query = new \WP_Query( $args ); ?>
                                    <?php if ( $the_query->have_posts() ) { ?>
                                        <div class="row">
                                            <?php while ( $the_query->have_posts() ) {
                                                $the_query->the_post(); ?>
                                                <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12 portfolioo">
                                                    <a href="<?php the_permalink(); ?>" class="project-box-2">
                                                        <img src="<?php if ( has_post_thumbnail() ) {
                                                            the_post_thumbnail_url( 'portfolio_box' );
                                                        } else {
                                                            echo $settings['default-image']['url'];
                                                        } ?>" width="282" height="292" alt="">
                                                        <div class="box-info-2">
                                                        <h3><?php the_title(); ?></h3>
                                                        <span><?php the_portfolio_cat_not_a(); ?></span>
                                                        </div>
                                                    </a>
                                                </div>
                                            <?php } ?>
                                        </div>
                                    <?php } ?>
                                </div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                </div>

                <?php } ?>
		<?php }
	}


	protected function _content_template() {
	}
}
