<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class ARCHIVEPRODUCT extends Widget_Base
{

    public function get_name()
    {
        return 'ARCHIVEPRODUCT';
    }

    public function get_title()
    {
        return __('آرشیو محصولات', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-products';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'box_sections',
            [
                'label' => __('تنظیمات باکس محصول', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' => __('پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __('سایه باکس', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li',
            ]
        );


        $this->add_responsive_control(
            'box-border-radius',
            [
                'label' => esc_html__('گردی گوشه ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color_hover',
            [
                'label' => __('پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_hover',
                'label' => __('سایه باکس', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li:hover',
            ]
        );

        $this->add_responsive_control(
            'box-border-radius-hover',
            [
                'label' => esc_html__('گردی گوشه ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border-hover',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li:hover',
            ]
        );

        $this->add_responsive_control(
            'hover-top-value',
            [
                'label' => __('مقدار پرش به بالا', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover' => 'transform: translateY(-{{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} ul.products li' => 'margin-top: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'image-style',
            [
                'label' => __('تصویر', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'badge_heading',
            [
                'label' => esc_html__('بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'badge-typography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} ul.products li.product .onsale',
            ]
        );

        $this->add_control(
            'bag-bac',
            [
                'label' => __('رنگ پس زمینه بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'bag-color',
            [
                'label' => __('رنگ متن بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_responsive_control(
            'onsale-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'box-content-style',
            [
                'label' => __('تنظیمات محتوای باکس', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_heading',
            [
                'label' => esc_html__('عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('رنگ', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product h3' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'title-color-hover',
            [
                'label' => __('رنگ هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product:hover h2' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title-typography',
                'label' => __('تایپوگرافی عنوان مطلب', 'themsah'),

                'selector' => '{{WRAPPER}} ul.products li.product .woocommerce-loop-product__title, {{WRAPPER}} ul.products li.product .woocommerce-loop-product__title, {{WRAPPER}} ul.products li.product h3',
            ]
        );

        $this->add_control(
            'price_heading',
            [
                'label' => esc_html__('قیمت', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'price-typography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} .price',
            ]
        );


        $this->add_control(
            'price-color',
            [
                'label' => __('رنگ', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'btn_section',
            [
                'label' => __('دکمه', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} ul.products li.product a.button',
            ]
        );


        $this->add_responsive_control(
            'btn-width',
            [
                'label' => esc_html__('نوع باکس', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '100%',
                'options' => [
                    'max-content' => esc_html__('در متن', 'themsah'),
                    '100%' => esc_html__('تمام عرض', 'themsah'),
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'width: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_responsive_control(
            'btn-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-padding',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-space',
            [
                'label' => __('فاصله', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->start_controls_tabs('box-btn');
        $this->start_controls_tab(
            'normal-btn',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-color-button',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} ul.products li.product a.button',
            ]
        );

        $this->add_control(
            'text-color-button',
            [
                'label' => esc_html__('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-btn',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-hover-color-button',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} ul.products li.product:hover a.button',

            ]
        );

        $this->add_control(
            'text-hover-color-button',
            [
                'label' => esc_html__('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product:hover a.button' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        $this->start_controls_section(
            'pagination-style',
            [
                'label' => __('استایل شمارشگر صفحات', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('pagination');
        $this->start_controls_tab('normal-pagination', ['label' => __('عادی', 'thensah')]);

        $this->add_control(
            'number-color',
            [
                'label' => __('رنگ متن شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-bac',
            [
                'label' => __('رنگ پس زمینه شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-border-color',
            [
                'label' => __('رنگ حاشیه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next)' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'pn-icon-color',
            [
                'label' => __('رنگ ایکن های قبل و بعد', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a.prev svg g path' => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .pagination .page-numbers a.next svg g path' => 'fill: {{VALUE}}',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab('hover-pagination', ['label' => __('هاور', 'thensah')]);
        $this->add_control(
            'number-hover-color',
            [
                'label' => __('رنگ متن شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-hover-bac',
            [
                'label' => __('رنگ پس زمینه شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-hover-border-color',
            [
                'label' => __('رنگ حاشیه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a:not(.prev):not(.next):hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'pn-hover-icon-color',
            [
                'label' => __('رنگ ایکن های قبل و بعد', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers a.prev:hover svg g path' => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .pagination .page-numbers a.next:hover svg g path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab('active-pagination', ['label' => __('فعال', 'thensah')]);
        $this->add_control(
            'number-active-color',
            [
                'label' => __('رنگ متن شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers li span.current' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-active-bac',
            [
                'label' => __('رنگ پس زمینه شماره ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers li span.current' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number-active-border-color',
            [
                'label' => __('رنگ حاشیه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagination .page-numbers li span.current' => 'border-color: {{VALUE}}',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();


        if (woocommerce_product_loop()) {

            /**
             * Hook: woocommerce_before_shop_loop.
             *
             * @hooked woocommerce_output_all_notices - 10
             * @hooked woocommerce_result_count - 20
             * @hooked woocommerce_catalog_ordering - 30
             */
            do_action('woocommerce_before_shop_loop');

            woocommerce_product_loop_start();

            if (wc_get_loop_prop('total')) {
                while (have_posts()) {
                    the_post();

                    /**
                     * Hook: woocommerce_shop_loop.
                     */
                    do_action('woocommerce_shop_loop');

                    wc_get_template_part('content', 'product');
                }
            }

            woocommerce_product_loop_end();

            /**
             * Hook: woocommerce_after_shop_loop.
             *
             * @hooked woocommerce_pagination - 10
             */
            do_action('woocommerce_after_shop_loop');
        } else {
            /**
             * Hook: woocommerce_no_products_found.
             *
             * @hooked wc_no_products_found - 10
             */
            do_action('woocommerce_no_products_found');
        }

        /**
         * Hook: woocommerce_after_main_content.
         *
         * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
         */
        do_action('woocommerce_after_main_content');

    }


    protected function _content_template()
    {
    }
}
