<?php

namespace ThemsahAddons\Widgets;

use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use WP_Query;


if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly


class Artpic extends Widget_Base {

    public function get_name() {
        return 'Artpic';
    }

    public function get_title() {
        return __( 'تصویر شاخص', 'themsah' );
    }


    public function get_icon() {
        return 'eicon-featured-image';
    }


    public function get_categories() {
        return [ 'themsah_cat' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'محتوا', 'themsah' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image_size', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'border-radius',
            [
                'label' => esc_html__( 'گردی گوشه ها', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'سایه', 'plugin-name' ),
                'selector' => '{{WRAPPER}} img',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__( 'حاشیه', 'plugin-name' ),
                'selector' => '{{WRAPPER}} img',
            ]
        );


        $this->add_responsive_control(
            'width',
            [
                'label'      => __( 'عرض تصویر', 'plugin-domain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1500,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .thumbnail img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'height',
            [
                'label'      => __( 'ارتفاع تصویر px', 'plugin-domain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1000,
                        'step' => 1,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 400,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .thumbnail img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
    }


    protected function render() {
        $settings = $this->get_settings_for_display(); ?>

        <div class="thumbnail">
            <?php
            $post_meta = get_post_meta(get_the_ID());
            if ($post_meta['themsah-select-template'][0]=='post_single') {
                global $post;
                if ( ! is_singular( 'post' ) ) {
                    $post = themsah_get_preview_post(); // phpcs:ignore
                    setup_postdata( $post );
                }

                if ( has_post_thumbnail() ) { ?>
                    <img src="<?= Group_Control_Image_Size::get_attachment_image_src(get_post_thumbnail_id(), 'image_size', $settings);?>" alt="<?php the_title(); ?>">
                <?php } else { ?>
                    <img src="<?php echo get_template_directory_uri() . '/img/placeholder.png'; ?>"
                         alt="<?php the_title(); ?>">
                <?php }

                if ( ! is_singular( 'post' ) ) {
                    wp_reset_postdata();
                }
            }elseif ($post_meta['themsah-select-template'][0]=='portfolio_single') {
                global $post;
                if ( ! is_singular( 'portfolio' ) ) {
                    $post = themsah_get_preview_portfolio(); // phpcs:ignore
                    setup_postdata( $post );
                }

                if ( has_post_thumbnail() ) { ?>
                    <img src="<?= Group_Control_Image_Size::get_attachment_image_src(get_post_thumbnail_id(), 'image_size', $settings);?>" alt="<?php the_title(); ?>">
                <?php } else { ?>
                    <img src="<?php echo get_template_directory_uri() . '/img/placeholder.png'; ?>"
                         alt="<?php the_title(); ?>">
                <?php }

                if ( ! is_singular( 'portfolio' ) ) {
                    wp_reset_postdata();
                }
            }elseif ($post_meta['themsah-select-template'][0]=='product_single') {
                global $post;
                if ( ! is_singular( 'product' ) ) {
                    $post = themsah_get_preview_portfolio(); // phpcs:ignore
                    setup_postdata( $post );
                }

                if ( has_post_thumbnail() ) { ?>
                    <img src="<?= Group_Control_Image_Size::get_attachment_image_src(get_post_thumbnail_id(), 'image_size', $settings);?>" alt="<?php the_title(); ?>">
                <?php } else { ?>
                    <img src="<?php echo get_template_directory_uri() . '/img/placeholder.png'; ?>"
                         alt="<?php the_title(); ?>">
                <?php }

                if ( ! is_singular( 'product' ) ) {
                    wp_reset_postdata();
                }
            } else {
                if ( has_post_thumbnail() ) { ?>
                    <img src="<?= Group_Control_Image_Size::get_attachment_image_src(get_post_thumbnail_id(), 'image_size', $settings);?>" alt="<?php the_title(); ?>">
                <?php } else { ?>
                    <img src="<?php echo get_template_directory_uri() . '/img/placeholder.png'; ?>"
                         alt="<?php the_title(); ?>">
                <?php }
            }?>
        </div>
    <?php }

    protected function _content_template() {
    }
}
