<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Brand_Slider extends Widget_Base {

	public function get_name() {
		return 'brand-slider';
	}

	public function get_title() {
		return __( 'اسلایدر برند', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-media-carousel';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'brand-name', [
				'label'       => __( 'عنوان برند', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'شرکت نفت', 'themsah' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'brand-image',
			[
				'label'   => __( 'تصویر برند', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'brand-link',
			[
				'label' => __( 'لینک برند', 'themsah' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'themsah' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

		$this->add_control(
			'list',
			[
				'label'   => __( 'اسلایدها', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => [
					[
						'brand-name' => __( 'شرکت نفت', 'themsah' ),
						'brand-link' => __( 'https://example.com', 'themsah' ),
					],
					[
						'brand-name' => __( 'شرکت گاز', 'themsah' ),
						'brand-link' => __( 'https://example.com', 'themsah' ),
					],
				],
			]
		);


		$this->end_controls_section();
		$this->start_controls_section(
			'box_settings',
			[
				'label' => __( 'تنظیمات باکس', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);

		$this->start_controls_tabs( 'box-logo' );
		$this->start_controls_tab( 'normal-box-logo', [ 'label' => __( 'عادی', 'themsah' ) ] );

		$this->add_control(
			'background_color',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow',
				'label'    => __( 'سایه', 'themsah' ),
				'selector' => '{{WRAPPER}} .customer-logo-slider .logo-box',
			]
		);

		$this->add_responsive_control(
			'box-border-radius',
			[
				'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box-height',
			[
				'label' => __( 'ارتفاع باکس', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 5,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 165,
				],
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->start_controls_tab( 'hover-box-logo', [ 'label' => __( 'هاور', 'themsah' ) ] );

		$this->add_control(
			'background_color_hover',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow_hover',
				'label'    => __( 'سایه باکس', 'themsah' ),
				'selector' => '{{WRAPPER}} .customer-logo-slider .logo-box:hover',
			]
		);

		$this->add_responsive_control(
			'box-border-radius-hover',
			[
				'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box-height-hover',
			[
				'label' => __( 'ارتفاع باکس', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 5,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 165,
				],
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box:hover' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->end_controls_section();
		$this->start_controls_section(
			'title-style',
			[
				'label' => __( 'استایل عنوان', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);
		$this->add_control(
			'name_color',
			[
				'label'     => __( 'رنگ متن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box span' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'name_bac',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box span' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .customer-logo-slider .logo-box span::before' => 'border-top-color: {{VALUE}} !important',
				],
			]
		);
				$this->add_responsive_control(
			'toltip-border-radius',
			[
				'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box span ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();
		$this->start_controls_section(
			'total-settings',
			[
				'label' => __( 'تنظیمات کلی', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'slidesToShow', [
				'label'       => __( 'تعداد اسلاید در صفحه', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::NUMBER,
				'default'     => __( '4', 'themsah' ),
			]
		);

		$this->add_responsive_control(
			'slide-spacing',
			[
				'label' => __('فاصله اسلایدها', 'themsah'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .customer-logo-slider .logo-box' => 'margin-right: calc({{SIZE}}{{UNIT}} / 2);margin-left: calc({{SIZE}}{{UNIT}} / 2)',
				],
			]
		);

		$this->add_control(
			'show_dots',
			[
				'label'        => __( 'نمایش نقطه ها', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'نمایش', 'themsah' ),
				'label_off'    => __( 'مخفی', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'dot_color',
			[
				'label'     => __( 'رنگ نقطه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slick-dots li' => 'background: {{VALUE}} !important',
				],
                'condition' => [
                        'show_dots' => 'yes'
                ]
			]
		);
		$this->add_control(
			'dot_color_active',
			[
				'label'     => __( 'رنگ نقطه فعال', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slick-dots li.slick-active' => 'background: {{VALUE}} !important',
				],
				'condition' => [
					'show_dots' => 'yes'
				]
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => __( 'اسلاید خودکار', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'بله', 'themsah' ),
				'label_off'    => __( 'خیر', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'loop',
			[
				'label'        => __( 'حلقه', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'بله', 'themsah' ),
				'label_off'    => __( 'خیر', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);


		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>
		<?php if ( $settings['list'] ) { ?>
            <div class="customer-logo-slider">
				<?php foreach ( $settings['list'] as $item ) { ?>
                    <a href="<?php echo $item['brand-link']['url']; ?>" class="logo-box">
                        <span><?php echo $item['brand-name']; ?></span>
                        <img src="<?php echo $item['brand-image']['url']; ?>" alt="">
                    </a>
				<?php } ?>
            </div>
		<?php }
		if ( $settings['show_dots'] == 'yes' ) {
			$dots = 'true';
		} else {
			$dots = 'false';
		}
		if ( $settings['autoplay'] == 'yes' ) {
			$autoplay = 'true';
		} else {
			$autoplay = 'false';
		}
		if ( $settings['loop'] == 'yes' ) {
			$loop = 'true';
		} else {
			$loop = 'false';
		} ?>
        <script>
            $(document).ready(function () {
                $('.customer-logo-slider').slick({
                slidesToShow: <?php echo $settings['slidesToShow']; ?>,
                slidesToScroll: 1,
                dots: <?php echo $dots; ?>,
                autoplay: <?php echo $autoplay; ?>,
                infinite: <?php echo $loop; ?>,
                rtl: <?php echo is_rtl() ? 'true' : 'false'; ?>,
                nav: false,
                responsive: [
                    {
                        breakpoint: 992,
                        settings: {
                            slidesToShow: 3,
                        }
                    },
                    {
                        breakpoint: 768,
                        settings: {
                            slidesToShow: 2,
                        }
                    },
                    {
                        breakpoint: 480,
                        settings: {
                            slidesToShow: 1,
                        }
                    }
                ]
            });
            });
        </script>
	<?php }


	protected function _content_template() {
    }
}
