<?php

namespace ThemsahAddons\Widgets;

use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Breadcrumb extends Widget_Base
{

    public function get_name()
    {
        return 'Breadcrumb';
    }

    public function get_title()
    {
        return __('مسیر پبمایش صفحات', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-product-breadcrumbs';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('محتوا', 'themsah'),
            ]
        );
        $this->add_control(
            'home-title',
            [
                'label' => __('عنوان صفحه اصلی', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'themsah'),
            ]
        );

        $this->add_control(
            'search-title',
            [
                'label' => __('عنوان صفحه جستجو', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('نتایج یافت شده برای', 'themsah'),
            ]
        );

        $this->add_control(
            'error-title',
            [
                'label' => __('عنوان صفحه خطای 404', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('خطای 404', 'themsah'),
            ]
        );

        $this->add_control(
            'page-nav-title',
            [
                'label' => __('عنوان صفحه بندی', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('صفحه', 'themsah'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' => __('استایل', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__('چینش افقی', 'themsah'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-end' => [
                        'title' => esc_html__('انتها', 'themsah'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('وسط', 'themsah'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-start' => [
                        'title' => esc_html__('ابتدا', 'themsah'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .breadcrumbs' => 'justify-content:{{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'this_title_color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .site-breadcrumb span' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .site-breadcrumb span a' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography3',
                'label' => __('تایپوگرافی متن', 'themsah'),
                'selector' => '{{WRAPPER}} .site-breadcrumb span',
            ]
        );
        $this->add_control(
            'sep_color',
            [
                'label' => __('رنگ جداکننده', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .site-breadcrumb svg g path' => 'fill: {{VALUE}} !important',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>
        <nav class="site-breadcrumb">
            <?php if ($settings['home-title'] == false) {
                $home_text = '<i class="fas fa-home" aria-hidden="true"></i>';
            } else {
                $home_text = $settings['home-title'];
            } ?>
            <?php site_breadcrumb($home_text, $settings['search-title'], $settings['error-title'], $settings['page-title']); ?>
        </nav>
    <?php }


    protected function _content_template()
    {
    }
}
