<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Category extends Widget_Base
{

    public function get_name()
    {
        return 'category';
    }

    public function get_title()
    {
        return __('لیست دسته بندی مقالات', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-bullet-list';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content5',
            [
                'label' => __('تنظیمات محتوای باکس', 'themsah'),
            ]
        );
        $this->add_control(
            'cat_type',
            [
                'label' => __( 'نوع دسته بندی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'post',
                'options' => [
                    'portfolio'  => __( 'نمونه کار ها', 'themsah' ),
                    'post' => __( 'مقالات', 'themsah' ),
                    'product' => __( 'محصولات', 'themsah' ),

                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'item-style',
            [
                'label' => __('استایل آیتم ها', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
        'title_color',
        [
          'label' => __( 'رنگ متن', 'themsah' ),
          'type' => \Elementor\Controls_Manager::COLOR,
          
          'selectors' => [
            '{{WRAPPER}} .themsah-categories ul li a' => 'color: {{VALUE}} !important',
            '{{WRAPPER}} .themsah-categories ul li' => 'color: {{VALUE}} !important'
          ],
        ]
        );
        $this->add_control(
        'title_color_hover',
        [
          'label' => __( 'رنگ هاور متن', 'themsah' ),
          'type' => \Elementor\Controls_Manager::COLOR,
          
          'selectors' => [
            '{{WRAPPER}} .themsah-categories ul li:hover a' => 'color: {{VALUE}} !important',
            '{{WRAPPER}} .themsah-categories ul li:hover' => 'color: {{VALUE}} !important'
          ],
        ]
        );

        $this->add_control(
        'title_color_active',
        [
          'label' => __( 'رنگ فعال متن', 'themsah' ),
          'type' => \Elementor\Controls_Manager::COLOR,
          
          'selectors' => [
            '{{WRAPPER}} .themsah-categories ul li.current-cat a' => 'color: {{VALUE}} !important',
          ],
        ]
        );
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'text-typography',
				'label' => __( 'تایپو گرافی متن ها', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .themsah-categories ul li',
			]
		);

	    $this->add_control(
		    'item-border',
		    [
			    'label' => __( 'رنگ خط بین آیتم ها', 'themsah' ),
			    'type' => \Elementor\Controls_Manager::COLOR,
			    
			    'selectors' => [
				    '{{WRAPPER}} .themsah-categories ul li' => 'border-bottom-color: {{VALUE}} !important',
			    ],
		    ]
	    );
	    
	       $this->add_control(
		    'before-border',
		    [
			    'label' => __( 'رنگ خط هاور متن', 'themsah' ),
			    'type' => \Elementor\Controls_Manager::COLOR,
			    
			    'selectors' => [
				    '{{WRAPPER}} .themsah-categories ul li a::before' => 'background: {{VALUE}} !important',
			    ],
		    ]
	    );

        $this->end_controls_section();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $cat_types=$settings['cat_type'];
        switch ($cat_types) {
        case 'post':?>
            <div class="themsah-categories">

                <ul>
                    <?php wp_list_categories( array(
                        'post_type' => 'post',
                        'orderby'    => 'name',
                        'show_count' => true,
                        'title_li' => '',
                    ) ); ?>
                </ul>
            </div>
        <?php  break;
    case 'portfolio':?>
        <div class="themsah-categories">
            <ul>
                <?php wp_list_categories( array(
                    'post_type' => 'portfolio',
                      'taxonomy' => 'portfolio_cat',
                    'orderby'    => 'name',
                    'show_count' => true,
                    'title_li' => '',
                ) ); ?>
            </ul>
        </div>
                <?php

    break;

        case 'product':?>
        <div class="themsah-categories">
            <ul>
			    <?php wp_list_categories( array(
				    'post_type' => 'product',
				    'taxonomy' => 'product_cat',
				    'orderby'    => 'name',
				    'show_count' => true,
				    'title_li' => '',
			    ) ); ?>
            </ul>
        </div>
	    <?php

	    break; }

          }


    protected function _content_template()
    {
    }
}
