<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Cf7_Form extends Widget_Base
{

    public function get_name()
    {
        return 'cf7-form';
    }

    public function get_title()
    {
        return __('فرم تماس 7', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-form-horizontal';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('محتوا', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'select-form',
            [
                'label' => __('انتخاب فرم', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => cf7_forms(),
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'style_section',
            [
                'label' => __('محتوا', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'padding',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input,{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'margin',
            [
                'label' => __('فاصله خارجی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input,{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'inputs_border_radius',
            [
                'label' => __('انحنای حاشیه ها', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input,{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'      => 'labels_typography',
                'label'     => __( 'تایپوگرافی برچسب ها', 'themsah' ),
                
                'selector'  => '{{WRAPPER}} .themsah-form label',

            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'      => 'inputs_typography',
                'label'     => __( 'تایپوگرافی ورودی متن', 'themsah' ),
                
                'selector'  => '{{WRAPPER}} .themsah-form input,{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select',

            ]
        );

        $this->start_controls_tabs(
            'style_contact'
        );
        $this->start_controls_tab(
            'style_contact_form_normal',
            [
                'label' => __('عادی', 'plugin-name'),
            ]
        );
        $this->add_control(
            'label_form_color',
            [
                'label' => __('رنگ برچسب ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-form label' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'input_placeholder_color',
            [
                'label' => __('رنگ متن نگهدارنده', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input:not([type="submit"])::placeholder,{{WRAPPER}} .themsah-form textarea::placeholder' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'input_background_color',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input,{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'input_text_color',
            [
                'label' => __(' رنگ متن فیلدها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input:not([type="submit"]),{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .themsah-form input:not([type="submit"]),{{WRAPPER}} .themsah-form textarea,{{WRAPPER}} .themsah-form select',
            ]
        );


        $this->end_controls_tab();
        $this->start_controls_tab(
            'style_contact_form_hover',
            [
                'label' => __('فعال', 'plugin-name'),
            ]
        );
        $this->add_control(
            'input_background_color_hover',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-form input:focus , {{WRAPPER}} .themsah-form input:focus-within' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .themsah-form textarea:focus , {{WRAPPER}} .themsah-form textarea:focus-within' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .themsah-form select:focus , {{WRAPPER}} .themsah-form select:focus-within' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-focus',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .themsah-form input:not([type="submit"]):focus,{{WRAPPER}} .themsah-form textarea:focus,{{WRAPPER}} .themsah-form select:focus,{{WRAPPER}} .themsah-form input:not([type="submit"]):focus-within,{{WRAPPER}} .themsah-form textarea:focus-within,{{WRAPPER}} .themsah-form select:focus-within',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
        $this->start_controls_section(
            'style_section_button',
            [
                'label' => __('دکمه', 'plugin-name'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'button_tabs'
        );
        $this->start_controls_tab(
            'style_button_tab_normal',
            [
                'label' => __('عادی', 'plugin-name'),
            ]
        );
        $this->add_control(
            'text_button_color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .themsah-form *[type=submit] ' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'button_background_color',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient', 'video'],
                'selector' => '{{WRAPPER}} .themsah-form *[type=submit]',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-btn',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .themsah-form *[type=submit]',
            ]
        );

        $this->add_responsive_control(
            'button_border_radius',
            [
                'label' => __('گردی لبه ها', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form *[type=submit]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab(
            'style_button_tab_hover',
            [
                'label' => __('هاور', 'plugin-name'),
            ]
        );

        $this->add_control(
            'text_button_color_hover',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}  .wpcf7-submit:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'button_background_color_hover',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient', 'video'],
                'selector' => '{{WRAPPER}} .themsah-form input[type=submit]:hover',
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-btn-hover',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .themsah-form *[type=submit]:hover',
            ]
        );

        $this->add_responsive_control(
            'button_border_radius_hover',
            [
                'label' => __('گردی لبه ها', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form *[type=submit]:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_responsive_control(
            'button_padding',
            [
                'label' => __('فاصله داخلی دکمه', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .themsah-form *[type=submit]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        echo '<div class="themsah-form contact-demo">';
        echo do_shortcode('[contact-form-7 id="' . $settings['select-form'] . '" title=""]');
        echo '</div>';
    }


    protected function _content_template()
    {
    }
}
