<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Comment_Slider extends Widget_Base {

	public function get_name() {
		return 'comment-slider';
	}

	public function get_title() {
		return __( 'اسلایدر نظرات مشتریان', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-testimonial-carousel';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}


	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);
        $this->add_control(
            'select-box',
            [
                'label' => esc_html__( 'نوع باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'column',
                'options' => [
                    'column'  => esc_html__( 'نوع اول', 'plugin-name' ),
                    'column-reverse' => esc_html__( 'نوع دوم', 'plugin-name' ),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .customer-comment .comment-box' => 'flex-direction: {{VALUE}} !important;',
                ],
            ]
        );


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'user-name', [
				'label'       => __( 'نام کاربر', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'نام کاربر', 'themsah' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'user-type', [
				'label'       => __( 'سمت کاربر', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'سمت کاربر', 'themsah' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'user-image',
			[
				'label'   => __( 'تصویر کاربر', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'user-comment', [
				'label'   => __( 'متن نظر کاربر', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'کامنت کاربر', 'themsah' ),
			]
		);

		$this->add_control(
			'list',
			[
				'label'   => __( 'Repeater List', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => [
					[
						'user-name' => __( 'پیمان جلیلی', 'themsah' ),
						'user-type' => __( 'برنامه نویس', 'themsah' ),
					],
					[
						'user-name' => __( 'اسماعیل میرقائد', 'themsah' ),
						'user-type' => __( 'مدیرعامل', 'themsah' ),
					],
				],
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'box_setting',
			[
				'label' => __( 'تنظیمات باکس', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background_color',
                'label' => esc_html__( 'رنگ بکگراند باکس', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .customer-comment .comment-box',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .customer-comment .comment-box',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow',
                'label'    => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .customer-comment .comment-box',
            ]
        );

        $this->add_responsive_control(
            'box-border-radius',
            [
                'label'      => __( 'گردی گوشه ها', 'plugin-domain' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .customer-comment .comment-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'box-padding',
            [
                'label'      => __( 'فاصله داخلی', 'plugin-domain' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .customer-comment .comment-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'box-height',
            [
                'label'      => __( 'ارتفاع باکس', 'plugin-domain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 500,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 250,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .customer-comment .comment-box' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'hover_background_color',
                'label' => esc_html__( 'رنگ بکگراند باکس', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .customer-comment .comment-box:hover',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'hover-border',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .customer-comment .comment-box:hover',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'hover-box_shadow',
                'label'    => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .customer-comment .comment-box:hover',
            ]
        );

        $this->add_responsive_control(
            'hover-box-border-radius',
            [
                'label'      => __( 'گردی گوشه ها', 'plugin-domain' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .customer-comment .comment-box:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'hover-top-value',
            [
                'label' => __( 'مقدار پرش به بالا', 'themsah' ),
                'type'  => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .customer-comment .comment-box:hover' => 'transform: translateY(-{{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} .customer-comment .comment-box' => 'margin-top: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

		$this->end_controls_section();



		$this->start_controls_section(
			'customer_setting',
			[
				'label' => __( 'تنظیمات محتوای باکس', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);

		$this->add_responsive_control(
			'image-size',
			[
				'label'      => __( 'سایز تصویر', 'plugin-domain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 30,
						'max'  => 150,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 80,
				],
				'selectors'  => [
					'{{WRAPPER}} .customer-comment .commenter-info img' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_responsive_control(
			'image-border-radius',
			[
				'label'      => __( 'گردی گوشه های تصویر', 'plugin-domain' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .customer-comment .commenter-info img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'image-spacing',
			[
				'label'      => __( 'فاسله تصویر', 'plugin-domain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 10,
				],
				'selectors'  => [
					'{{WRAPPER}} .customer-comment .commenter-info img' => 'margin-inline-end:{{SIZE}}{{UNIT}};',
				],
				'separator'  => 'after',
			]
		);


		$this->add_control(
			'name_color',
			[
				'label'     => __( 'رنگ نام کاربر', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-comment .commenter-info .name' => 'color: {{VALUE}} !important',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'      => 'content_typography',
				'label'     => __( 'تایپوگرافی نام', 'themsah' ),
				
				'selector'  => '{{WRAPPER}} .customer-comment .commenter-info .name',
				'separator' => 'after',

			]
		);
		$this->add_control(
			'type_color',
			[
				'label'     => __( 'رنگ سمت کاربر', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-comment .commenter-info span:not(.name)' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'      => 'content_typography1',
				'label'     => __( 'تایپو گرافی سمت', 'themsah' ),
				
				'selector'  => '{{WRAPPER}} .customer-comment .commenter-info span:not(.name)',
				'separator' => 'after',

			]
		);
		$this->add_control(
			'comment_color',
			[
				'label'     => __( 'رنگ متن کامنت', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .customer-comment p' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography2',
				'label'    => __( 'تایپوگرافی متن نظر', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .customer-comment p',
			]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'content_sections1',
			[
				'label' => __( 'تنظیمات اسلایدر', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'slidesToShow', [
				'label'   => __( 'تعداد اسلاید در صفحه', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'default' => __( '2', 'themsah' ),
			]
		);

		$this->add_responsive_control(
			'slide-spacing',
			[
				'label' => __( 'فاصله اسلایدها', 'themsah' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .customer-comment .comment-box' => 'margin-right: calc({{SIZE}}{{UNIT}} / 2);margin-left: calc({{SIZE}}{{UNIT}} / 2)',
				],
			]
		);

		$this->add_control(
			'show_dots',
			[
				'label'        => __( 'نمایش نقطه ها', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'نمایش', 'themsah' ),
				'label_off'    => __( 'مخفی', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'dot_color',
			[
				'label'     => __( 'رنگ نقطه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slick-dots li' => 'background: {{VALUE}} !important',
				],
				'condition' => [
					'show_dots' => 'yes'
				]
			]
		);
		$this->add_control(
			'dot_color_active',
			[
				'label'     => __( 'رنگ نقطه فعال', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slick-dots li.slick-active' => 'background: {{VALUE}} !important',
				],
				'condition' => [
					'show_dots' => 'yes'
				]
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => __( 'اسلاید خودکار', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'بله', 'themsah' ),
				'label_off'    => __( 'خیر', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'loop',
			[
				'label'        => __( 'حلقه', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'بله', 'themsah' ),
				'label_off'    => __( 'خیر', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

        $this->add_control(
			'arrows',
			[
				'label'        => __( 'ناوبری', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'بله', 'themsah' ),
				'label_off'    => __( 'خیر', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);
        $this->add_control(
            'arrows_color',
            [
                'label'     => __( 'رنگ پیکان ها', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-prev svg path,{{WRAPPER}} .slick-next svg path' => 'fill: {{VALUE}} !important',
                ],
                'condition' => [
                    'arrows' => 'yes'
                ]
            ]
        );
        $this->add_control(
            'arrows_color_hover',
            [
                'label'     => __( 'رنگ هاور پیکان ها', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-prev:hover svg path,{{WRAPPER}} .slick-next:hover svg path' => 'fill: {{VALUE}} !important',
                ],
                'condition' => [
                    'arrows' => 'yes'
                ]
            ]
        );
		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>
		<?php if ( $settings['list'] ) { ?>
            <div class="customer-comment">
				<?php foreach ( $settings['list'] as $item ) { ?>
                    <div class="comment-box">
                        <div class="commenter-info mb-4 d-flex align-items-center">
                            <img src="<?php echo $item['user-image']['url']; ?>" alt="">
                            <div class="meta">
                                <span class="d-block name"><?php echo $item['user-name']; ?></span>
                                <span><?php echo $item['user-type']; ?></span>
                            </div>
                        </div>
                        <p class="mb-0"><?php echo $item['user-comment']; ?></p>
                    </div>
				<?php } ?>
            </div>
		<?php } ?>
		<?php
		if ( $settings['show_dots'] == 'yes' ) {
			$dots = 'true';
		} else {
			$dots = 'false';
		}
		if ( $settings['autoplay'] == 'yes' ) {
			$autoplay = 'true';
		} else {
			$autoplay = 'false';
		}
		if ( $settings['loop'] == 'yes' ) {
			$loop = 'true';
		} else {
			$loop = 'false';
		}
        if ( $settings['arrows'] == 'yes' ){
            $arrows = 'true';
        }else{
            $arrows = 'false';
        }
        ?>
        <script>
            $(document).ready(function () {
                $('.customer-comment').slick({
                    slidesToShow: <?php echo $settings['slidesToShow']; ?>,
                    slidesToScroll: 1,
                    dots: <?php echo $dots; ?>,
                    autoplay: <?php echo $autoplay; ?>,
                    infinite: <?php echo $loop; ?>,
                    rtl: <?php echo is_rtl() ? 'true' : 'false'; ?>,
                    arrows: <?php echo $arrows; ?>,
                    nextArrow : '<button type="button" class="slick-next">' +
                        '<svg xmlns="http://www.w3.org/2000/svg" width="11.241" height="21.272" viewBox="0 0 11.241 21.272">' +
                        '<g id="_002-back" data-name="002-back" transform="translate(123.754 21.272) rotate(180)">' +
                        '<path id="Path_42" data-name="Path 42" d="M113.97,10.636l9.607-9.607a.6.6,0,1,0-.851-.851L112.69,10.212a.6.6,0,0,0,0,.851l10.035,10.03a.606.606,0,0,0,.424.178.587.587,0,0,0,.424-.178.6.6,0,0,0,0-.851Z" fill="#fff"/>' +
                        '</g>' +
                        '</svg>' +
                        '</button>',
                    prevArrow : '<button type="button" class="slick-prev">' +
                        '<svg xmlns="http://www.w3.org/2000/svg" width="11.241" height="21.272" viewBox="0 0 11.241 21.272">' +
                        '<g id="_002-back" data-name="002-back" transform="translate(-112.513)">' +
                        '<path id="Path_42" data-name="Path 42" d="M113.97,10.636l9.607-9.607a.6.6,0,1,0-.851-.851L112.69,10.212a.6.6,0,0,0,0,.851l10.035,10.03a.606.606,0,0,0,.424.178.587.587,0,0,0,.424-.178.6.6,0,0,0,0-.851Z" fill="#fff"/>' +
                        '</g></svg></button>',
                    responsive: [
                        {
                            breakpoint: 992,
                            settings: {
                                slidesToShow: 2,
                            }
                        },
                        {
                            breakpoint: 768,
                            settings: {
                                slidesToShow: 1,
                            }
                        },
                        {
                            breakpoint: 480,
                            settings: {
                                slidesToShow: 1,
                            }
                        }
                    ]
                });
            });
        </script>
	<?php }


	protected function _content_template() {
	}
}
