<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Comment extends Widget_Base
{

    public function get_name()
    {
        return 'comment';
    }

    public function get_title()
    {
        return __('ارسال نظرات', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-comments';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {
        $this->start_controls_section(
            'style_section',
            [
                'label' => __( 'محتوا', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'titles_color',
            [
                'label'     => __( 'رنگ عنوان ها', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-author.vcard a.url' => 'color: {{VALUE}}',
                    '{{WRAPPER}} h3#comments' => 'color: {{VALUE}}',
                    '{{WRAPPER}} h3#reply-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} #cancel-comment-reply-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'titles_typography',
                'label'    => __( 'تایپوگرافی عنوان ها', 'plugin-domain' ),
                'selector' => '{{WRAPPER}} #cancel-comment-reply-link,{{WRAPPER}} .comment-author.vcard a.url,{{WRAPPER}} h3#comments,{{WRAPPER}} h3#reply-title',
            ]
        );

        $this->add_control(
            'text-color',
            [
                'label'     => __( 'رنگ متن ها', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ol.commentlist li .comment-body p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} ol.commentlist li .comment-body .comment-metadata a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .logged-in-as' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .logged-in-as a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-form-comment textarea' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .woocommerce-review__verified' => 'color: {{VALUE}}',
                    '{{WRAPPER}} #review_form #respond p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-notes span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-form label' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-form-comment input[type=text]' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-form-comment input[type=email]' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .comment-form-comment input[type=url]' => 'color: {{VALUE}}',
                ],
                'separator'=>'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'text_typography',
                'label'    => __( 'تایپوگرافی متن ها', 'plugin-domain' ),
                'selector' => '{{WRAPPER}} .comment-notes span,{{WRAPPER}} ol.commentlist li .comment-body p,{{WRAPPER}} ol.commentlist li .comment-body .comment-metadata a,{{WRAPPER}} .logged-in-as,{{WRAPPER}} .logged-in-as a,{{WRAPPER}} .comment-form-comment textarea,{{WRAPPER}} .woocommerce-review__verified,{{WRAPPER}} #review_form #respond p,{{WRAPPER}} .comment-notes,{{WRAPPER}} .comment-form label,{{WRAPPER}} .comment-form-comment input[type=text],{{WRAPPER}} .comment-form-comment input[type=email],{{WRAPPER}} .comment-form-comment input[type=url]',
            ]
        );


        $this->add_control(
            'comment-bac',
            [
                'label'     => __( 'رنگ پس زمینه باکس نطرات', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ol.commentlist li .comment-body' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_responsive_control(
            'comment-border-radius',
            [
                'label' => __( 'گردی گوشه های باکس نطرات', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} ol.commentlist li .comment-body' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important',
                ],
                'separator'=>'after'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'reply-typography',
                'label'    => __( 'تایپوگرافی پاسخ', 'themsah' ),
                'selector' => '{{WRAPPER}} .comment-reply-link',
            ]
        );

        $this->add_responsive_control(
            'reply-border-radius',
            [
                'label' => __( 'گردی گوشه ها پاسخ', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .comment-reply-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-reply-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'reply-color',
            [
                'label'     => __( 'رنگ متن پاسخ', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-reply-link' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'reply-background',
                'label'    => __( 'پس زمینه پاسخ', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .comment-reply-link',
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab(
            'hover-reply-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'reply-hover-color',
            [
                'label'     => __( 'هاور رنگ متن پاسخ', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-reply-link:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'reply-hover-background',
                'label'    => __( 'هاور پس زمینه پاسخ', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .comment-reply-link:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->add_responsive_control(
            'inputt-border-radius',
            [
                'label' => __( 'گردی گوشه های ورودی ها', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} #comment,{{WRAPPER}} input:not([type=submit]):not([type=checkbox])' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important',
                ],
                'separator'=>'before'
            ]
        );
        $this->add_control(
            'input-active-color',
            [
                'label'     => __( 'رنگ فعال حاشیه ورودی متن ها', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .comment-form-comment textarea.active,{{WRAPPER}} .comment-form-author input.active, {{WRAPPER}} .comment-form-email input.active,.comment-form-url input.active' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'style_submit',
            [
                'label' => __( 'دکمه ارسال', 'plugin-name' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'submit-typography',
                'label'    => __( 'تایپوگرافی', 'themsah' ),
                'selector' => '{{WRAPPER}} #submit',
            ]
        );

        $this->add_responsive_control(
            'submit-border-radius',
            [
                'label' => __( 'گردی گوشه های دکمه ارسال', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'submit-color',
            [
                'label'     => __( 'رنگ متن', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'submit-background',
                'label'    => __( 'پس زمینه', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} #submit',
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'submit-hover-color',
            [
                'label'     => __( 'رنگ متن', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'submit-hover-background',
                'label'    => __( 'پس زمینه', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} #submit:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
            $post_meta = get_post_meta(get_the_ID());
            if ($post_meta['themsah-select-template'][0] == 'post_single') {
                global $post;
                $post = themsah_get_preview_post(); // phpcs:ignore
                setup_postdata($post);
                comments_template();
                wp_reset_postdata();
            }elseif ($post_meta['themsah-select-template'][0] == 'portfolio_single') {
                global $post;
                $post = themsah_get_preview_portfolio(); // phpcs:ignore
                setup_postdata($post);
                comments_template();
                wp_reset_postdata();
            } else {
                comments_template();
            }
        } else {
            comments_template();
        }
    }


    protected function _content_template()
    {
    }
}
