<?php

namespace ThemsahAddons\Widgets;

use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly


class Themsah_Image extends Widget_Base {

    public function get_name() {
        return 'themsah-image';
    }

    public function get_title() {
        return __( 'تصویر', 'themsah' );
    }


    public function get_icon() {
        return 'eicon-youtube';
    }


    public function get_categories() {
        return [ 'themsah_cat' ];
    }


    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'image',
            [
                'label'   => __( 'تصویر', 'themsah' ),
                'type'    => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image_size', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
                'default' => 'large',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'video-link',
            [
                'label' => __( 'لینک ویدئو', 'themsah' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => true,
                ],
            ]
        );

        $this->add_control(
            'icon',
            [
                'label' => __( 'آیکن پخش', 'text-domain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-play',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'icon2',
            [
                'label' => __( 'آیکن توقف', 'text-domain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-pause',
                    'library' => 'solid',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'style_section_image',
            [
                'label' => __( 'تصویر', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'     => 'border',
                'label'    => __( 'حاشیه تصویر', 'themsah' ),
                'selector' => '{{WRAPPER}} .themsah-image-wrapper',
            ]
        );

        $this->add_responsive_control(
            'border-radius-images',
            [
                'label'      => __( 'گردی لبه های تصویر', 'themsah' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .themsah-image-wrapper img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'image-height',
            [
                'label'      => __( 'ارتفاع تصویر', 'themsah' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1000,
                        'step' => 1,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 400,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .themsah-image-wrapper' => 'height:{{SIZE}}{{UNIT}} !important',
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'style_icon_section',
            [
                'label' => __( 'آیکن', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'play-icon' );
        $this->start_controls_tab( 'normal-play-icon', [ 'label' => __( 'عادی', 'themsah' ) ] );

        $this->add_control(
            'play-icon-color',
            [
                'label'     => __( 'رنگ آیکن', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper span i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'play-icon-bac',
            [
                'label'     => __( 'رنگ پس زمینه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper span' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'play-icon-dimensions',
            [
                'label' => __( 'ابعاد آیکن', 'plugin-domain' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper span' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-play-icon',
            [
                'label'      => __( 'گردی لبه ها', 'themsah' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .themsah-image-wrapper span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box-shadow-play-icon',
                'label'    => __( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .themsah-image-wrapper span',
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab( 'hover-play-icon', [ 'label' => __( 'هاور', 'themsah' ) ] );

        $this->add_control(
            'play-icon-hover-color',
            [
                'label'     => __( 'رنگ آیکن', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper span:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'play-icon-hover-back',
            [
                'label'     => __( 'رنگ پس زمینه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper span:hover' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_responsive_control(
            'play-icon-hover-dimensions',
            [
                'label' => __( 'ابعاد آیکن', 'plugin-domain' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .themsah-image-wrapper:hover span' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-hover-play-icon',
            [
                'label'      => __( 'گردی لبه ها', 'themsah' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .themsah-image-wrapper span:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box-shadow-hover-play-icon',
                'label'    => __( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .themsah-image-wrapper span:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->end_controls_section();


    }


    protected function render() {

        $settings = $this->get_settings_for_display();?>
       <div class="themsah-image-wrapper">
           <video controls src="<?= $settings['video-link']['url']; ?>"></video>
           <img id="themsah-image" src="<?= Group_Control_Image_Size::get_attachment_image_src($settings['image']['id'], 'image_size', $settings);?>" alt="">
           <span id="play"><?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true'  ] ); ?></span>
           <span id="pause"><?php \Elementor\Icons_Manager::render_icon( $settings['icon2'], [ 'aria-hidden' => 'true'  ] ); ?></span>
       </div>
        <script>
            /* Store the element in el */
            let el = document.getElementById('themsah-image')

            /* Get the height and width of the element */
            const height = el.clientHeight
            const width = el.clientWidth

            /*
              * Add a listener for mousemove event
              * Which will trigger function 'handleMove'
              * On mousemove
              */
            el.addEventListener('mousemove', handleMove)

            /* Define function a */
            function handleMove(e) {
                /*
                  * Get position of mouse cursor
                  * With respect to the element
                  * On mouseover
                  */
                /* Store the x position */
                const xVal = e.layerX
                /* Store the y position */
                const yVal = e.layerY

                /*
                  * Calculate rotation valuee along the Y-axis
                  * Here the multiplier 20 is to
                  * Control the rotation
                  * You can change the value and see the results
                  */
                const yRotation = 10 * ((xVal - width / 2) / width)

                /* Calculate the rotation along the X-axis */
                const xRotation = -10 * ((yVal - height / 2) / height)

                /* Generate string for CSS transform property */
                const string = 'perspective(500px) scale(1) rotateX(' + xRotation + 'deg) rotateY(' + yRotation + 'deg)'

                /* Apply the calculated transformation */
                el.style.transform = string
            }

            /* Add listener for mouseout event, remove the rotation */
            el.addEventListener('mouseout', function() {
                el.style.transform = 'perspective(500px) scale(1) rotateX(0) rotateY(0)'
            })

            /* Add listener for mousedown event, to simulate click */
            el.addEventListener('mousedown', function() {
                el.style.transform = 'perspective(500px) scale(1) rotateX(0) rotateY(0)'
            })

            /* Add listener for mouseup, simulate release of mouse click */
            el.addEventListener('mouseup', function() {
                el.style.transform = 'perspective(500px) scale(1) rotateX(0) rotateY(0)'
            })
        </script>
    <?php }

    protected function _content_template() {
    }
}
