<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class Information extends Widget_Base
{

    public function get_name()
    {
        return 'Information';
    }

    public function get_title()
    {
        return __('اطلاعات پست', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-post-info';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('محتوا', 'themsah'),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'information_case',
            [
                'label' => __('نوع را انتخاب کنید', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    'views' => __('بازدید', 'themsah'),
                    'category' => __('دسته بندی', 'themsah'),
                    'author' => __('نویسنده', 'themsah'),
                    'date' => __('تاریخ', 'themsah'),
                    'tag' => __('برجسب')
                ],
            ]
        );
        $repeater->add_control(
            'icon',
            [
                'label' => __('آیکون', 'text-domain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-star',
                    'library' => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'item_title',
            [
                'label' => esc_html__( 'عنوان', 'themsah' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( '', 'themsah' ),
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => __('آیتم ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'information_case' => 'category',
                    ],
                    [
                        'information_case' => 'author',
                    ],
                    [
                        'information_case' => 'date',
                    ],
                    [
                        'information_case' => 'views',
                    ],
                    [
                        'information_case' => 'tag',
                    ],
                ],
                'title_field' => '{{{ information_case }}}',
            ]
        );


        $this->end_controls_section();
        $this->start_controls_section(
            'style_section',
            [
                'label' => __('استایل', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'item-background',
                'label' => esc_html__( 'پس زمینه ایتم ها', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .info-item',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'item-padding',
            [
                'label' => esc_html__( 'فاصله داخلی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .info-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default'=>[
                    'top' => '2',
                    'right' => '8',
                    'bottom' => '2',
                    'left' => '8',
                    'unit' => 'px',
                ]
            ]
        );

        $this->add_control(
            'item-border-radius',
            [
                'label' => esc_html__( 'گردی حاشیه', 'themsah' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .info-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'item-box_shadow',
                'label' => esc_html__( 'سایه', 'themsah' ),
                'selector' => '{{WRAPPER}} .info-item',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'item-border',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .info-item',
            ]
        );

        $this->add_control(
            'item-space',
            [
                'label' => esc_html__( 'فاصله ایتم ها', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 8,
                ],
                'selectors' => [
                    '{{WRAPPER}} .info-item:not(:last-child)' => 'margin-inline-end: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .all-information > div i' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'icon-size',
            [
                'label' => esc_html__( 'سایز آیکن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 8,
                ],
                'selectors' => [
                    '{{WRAPPER}} .all-information > div i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .all-information > div svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __('رنگ عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .all-information > div span.title' => 'color: {{VALUE}} !important',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .all-information > div span.title',
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .all-information > div span a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .all-information > div span' => 'color: {{VALUE}} !important',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'value_typography',
                'selector' => '{{WRAPPER}} .all-information > div span',
            ]
        );



        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $post_meta = get_post_meta(get_the_ID()); ?>
        <div class="all-information">
            <?php if ($settings['list']) {
                foreach ($settings['list'] as $item) {
                    $favcolor = $item['information_case'];
                    switch ($favcolor) {
                        case "date": ?>
                            <div class="info-item">
                                <?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                <span class="title"><?= $item['item_title']; ?></span>
                                <span><?php
                                    if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                        if ($post_meta['themsah-select-template'][0] == 'post_single') {
                                            global $post;
                                            $post = themsah_get_preview_post(); // phpcs:ignore
                                            setup_postdata($post);

                                            echo get_the_date();

                                            wp_reset_postdata();
                                        } else {
                                            echo get_the_date();
                                        }
                                    } else {
                                        echo get_the_date();
                                    }
                                    ?>
                                </span>
                            </div>
                            <?php
                            break;
                        case "author":
                            if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                if ($post_meta['themsah-select-template'][0] == 'post_single') {
                                    global $post;
                                    $post = themsah_get_preview_post(); // phpcs:ignore
                                    setup_postdata($post);?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_author(); ?></span>
                                    </div>
                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'portfolio_single') {
                                    global $post;
                                    $post = themsah_get_preview_portfolio(); // phpcs:ignore
                                    setup_postdata($post);?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_author(); ?></span>
                                    </div>
                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'product_single') {
                                    global $post;
                                    $post = themsah_get_preview_product(); // phpcs:ignore
                                    setup_postdata($post);?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_author(); ?></span>
                                    </div>
                                    <?php wp_reset_postdata();
                                } else {?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_author(); ?></span>
                                    </div>
                                <?php }
                            } else {?>
                                <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                    <span class="title"><?= $item['item_title']; ?></span>
                                    <span><?php if (have_posts()){while (have_posts()){
                                        the_post();
                                        the_author();
                                        }wp_reset_postdata();} ?></span>
                                </div>
                            <?php }
                            break;
                        case "category":
                            if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                if ($post_meta['themsah-select-template'][0] == 'post_single') {
                                    global $post;
                                    $post = themsah_get_preview_post(); // phpcs:ignore
                                    setup_postdata($post);?>

                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_category(','); ?></span></div>
                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'portfolio_single') {
                                    global $post;
                                    $post = themsah_get_preview_portfolio(); // phpcs:ignore
                                    setup_postdata($post);

                                    if (has_term('', 'portfolio_cat')) {
                                    ?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_portfolio_cat(); ?></span></div>
                                <?php }

                                   wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'product_single') {
                                    global $post;
                                    $post = themsah_get_preview_product(); // phpcs:ignore
                                    setup_postdata($post);

                                    if (has_term('', 'product_cat')) {
                                    ?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_product_cat(); ?></span></div>
                                <?php }

                                   wp_reset_postdata();
                                } else {
                                    the_category();
                                }
                            } else {
                                if (is_singular('post')) {
                                    if (has_category()) { ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_category(','); ?></span></div>
                                    <?php }
                                } elseif (is_singular('portfolio')) {
                                    if (has_term('', 'portfolio_cat')) {
                                        ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_portfolio_cat(); ?></span></div>
                                    <?php }
                                } elseif (is_singular('product')) {
                                    if (has_term('', 'product_cat')) {
                                        ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_product_cat(); ?></span></div>
                                    <?php }
                                }
                            }
                            break;

                        case "views":
                            if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                if ($post_meta['themsah-select-template'][0] == 'post_single') {
                                    global $post;
                                    $post = themsah_get_preview_post(); // phpcs:ignore
                                    setup_postdata($post);?>

                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php echo wpb_get_post_views(get_the_ID()); ?></span>
                                    </div>

                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'portfolio_single') {
                                    global $post;
                                    $post = themsah_get_preview_portfolio(); // phpcs:ignore
                                    setup_postdata($post);?>

                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php echo wpb_get_post_views(get_the_ID()); ?></span>
                                    </div>

                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'product_single') {
                                    global $post;
                                    $post = themsah_get_preview_product(); // phpcs:ignore
                                    setup_postdata($post);?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php echo wpb_get_post_views(get_the_ID()); ?></span>
                                    </div>
                                    <?php wp_reset_postdata();
                                } else {?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php echo wpb_get_post_views(get_the_ID()); ?></span>
                                    </div>
                                <?php }
                            } else { ?>
                                <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                    <span class="title"><?= $item['item_title']; ?></span>
                                    <span><?php echo wpb_get_post_views(get_the_ID()); ?></span>
                                </div>
                            <?php }
                            break;
                        case 'tag':
                            if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
                                if ($post_meta['themsah-select-template'][0] == 'post_single') {
                                    global $post;
                                    $post = themsah_get_preview_post(); // phpcs:ignore
                                    setup_postdata($post);?>
                                    <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                        <span class="title"><?= $item['item_title']; ?></span>
                                        <span><?php the_tags('',', '); ?></span></div>
                                    <?php wp_reset_postdata();
                                }elseif ($post_meta['themsah-select-template'][0] == 'product_single') {
                                    global $post;
                                    $post = themsah_get_preview_product(); // phpcs:ignore
                                    setup_postdata($post);
                                    if (has_term('', 'product_cat')) { ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_product_tag(); ?></span></div>
                                    <?php }
                                    wp_reset_postdata();
                                } else {
                                    the_category();
                                }
                            } else {
                                if (is_singular('post')) {
                                    if (has_tag()) { ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_tags('',', '); ?></span></div>
                                    <?php }
                                }  elseif (is_singular('product')) {
                                    if (has_term('', 'product_tag')) {
                                        ?>
                                        <div class="info-item"><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true']); ?>
                                            <span class="title"><?= $item['item_title']; ?></span>
                                            <span><?php the_product_tag(); ?></span></div>
                                    <?php }
                                }
                            }
                            break;
                    }
                    ?>
                <?php } ?>
            <?php } ?>
        </div>
    <?php }


    protected function _content_template()
    {
    }
}
