<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class Change_Language extends Widget_Base
{

    public function get_name()
    {
        return 'change-language';
    }

    public function get_title()
    {
        return __('تغییر زبان', 'themsah');
    }


    public function get_icon()
    {
        return 'fas fa-language';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {

        $this->start_controls_section(
            'language-content',
            [
                'label' => __('محتوا', 'text-domain'),
            ]
        );

        $this->add_control(
            'show_flags',
            [
                'label' => __('نمایش پرچم', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'your-plugin'),
                'label_off' => __('مخفی', 'your-plugin'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_names',
            [
                'label' => __('نمایش نام زبان', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'your-plugin'),
                'label_off' => __('مخفی', 'your-plugin'),
                'return_value' => 'yes',
                'default' => '',
            ]
        );

        $this->add_control(
            'show_current',
            [
                'label' => __('مخفی کردن پرچم فعلی', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'your-plugin'),
                'label_off' => __('مخفی', 'your-plugin'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_style',
            [
                'label' => __('استایل', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'language-bac',
            [
                'label' => __('رنگ پس زمینه', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'language-hover-bac',
            [
                'label' => __('رنگ پس زمینه هاور', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul li:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );


        $this->add_responsive_control(
            'language-dimensions',
            [
                'label' => __('ابعاد', 'plugin-domain'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 80,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 45,
                ],
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .change-lang ul li' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-language',
            [
                'label' => __('گردی لبه ها', 'plugin-domain'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .change-lang ul li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin-language',
            [
                'label' => __('فاصله', 'plugin-domain'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .change-lang' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'language-text',
            [
                'label' => __('رنگ متن', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul li a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .change-lang ul li a span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_names' => 'yes',
                ]
            ]
        );

        $this->add_control(
            'language-text-hover',
            [
                'label' => __('رنگ متن هاور', 'plugin-domain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .change-lang ul li:hover a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .change-lang ul li:hover a span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_names' => 'yes',
                ]
            ]
        );

        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if ('yes' === $settings['show_flags']) {
            $show_flag = 1;
        } else {
            $show_flag = 0;
        }
        if ('yes' === $settings['show_names']) {
            $show_name = 1;
        } else {
            $show_name = 0;
        }
        if ('yes' === $settings['show_current']) {
            $show_current = 1;
        } else {
            $show_current = 0;
        }
        if (function_exists('pll_the_languages')) { ?>
            <div class="change-lang">
                <div class="inner">
                    <ul><?php pll_the_languages(array('display_names_as' => 'slug', 'show_flags' => $show_flag, 'show_names' => $show_name, 'hide_current' => $show_current)); ?></ul>
                </div>
            </div>
        <?php }
    }


    protected function _content_template()
    {
    }
}
