<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use WP_Query;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Last_Post_Sidebar extends Widget_Base {

	public function get_name() {
		return 'last-post-sidebar';
	}

	public function get_title() {
		return __( 'آخرین پست ها', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-post-list';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}


	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);

		$this->add_control(
			'query_type',
			[
				'label'   => __( 'نوع کوئری', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'post',
				'options' => [
					'portfolio' => __( 'نمونه کار ها', 'themsah' ),
					'post'      => __( 'مقالات', 'themsah' ),
					'product'   => __( 'محصولات', 'themsah' ),

				],
			]
		);


		$this->add_control(
			'post_per',
			[
				'label'   => __( 'تعداد پست در برگه', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 100,
				'step'    => 1,
				'default' => 3,
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item-style',
			[
				'label' => __( 'تنظیمات آیتم ها', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);



		$this->add_responsive_control(
			'image-size',
			[
				'label'      => __( 'سایز تصویر', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 30,
						'max'  => 100,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 80,
				],
				'selectors'  => [
					'{{WRAPPER}} .last-post-side .item img' => 'min-width:{{SIZE}}{{UNIT}};width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .last-post-side .item .thumbnail' => 'min-width:{{SIZE}}{{UNIT}};width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_responsive_control(
			'image-border-radius',
			[
				'label' => __( 'گردی گوشه های تصویر', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .last-post-side .item .thumbnail' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .last-post-side .item .thumbnail .cover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'image-spacing',
			[
				'label'      => __( 'فاسله تصویر', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 15,
				],
				'selectors'  => [
					'{{WRAPPER}} .last-post-side .item .thumbnail' => 'margin-inline-end:{{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'image-cover-bac',
			[
				'label'     => __( 'رنگ هاور روکش تصویر', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item .thumbnail .cover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'image-icon-color',
			[
				'label'     => __( 'رنگ آیکن روی تصویر', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item .thumbnail i' => 'color: {{VALUE}}',
				],
				'separator' => 'after',
			]
		);

		$this->add_control(
			'title-item-color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title-hover-color',
			[
				'label'     => __( 'رنگ هاور عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item:hover h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_post_typography',
				'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .last-post-side .item h3',
			]
		);



		$this->add_control(
			'date-color',
			[
				'label'     => __( 'رنگ متن تاریخ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item span' => 'color: {{VALUE}}',
				],
                'condition' => [
                        'query_type!' => 'product'
                ]
			]
		);

		$this->add_control(
			'price-color',
			[
				'label'     => __( 'رنگ متن قیمت', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item span' => 'color: {{VALUE}}',
				],
				'condition' => [
					'query_type' => 'product'
				]
			]
		);

		$this->add_control(
			'item-border',
			[
				'label' => __( 'رنگ خط بین آیتم ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item' => 'border-bottom-color: {{VALUE}} !important',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'tooltip-style',
			[
				'label' => __( 'استایل تولتیپ', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);
		$this->add_control(
			'name_color',
			[
				'label'     => __( 'رنگ متن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item span.site-tooltip' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'name_bac',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .last-post-side .item span.site-tooltip' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .last-post-side .item span.site-tooltip::before' => 'border-top-color: {{VALUE}} !important',
				],
			]
		);
					$this->add_control(
			'toltip-border-radius',
			[
				'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .site-tooltip ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();
	}


	protected function render() {
		$settings   = $this->get_settings_for_display();
		$query_type = $settings['query_type'];
		switch ( $query_type ) {
			case 'post':
				$post_type = 'post';
				break;
			case 'portfolio' :
				$post_type = 'portfolio';
				break;
			case 'product':
				$post_type = 'product';
				break;
		}
		$query = new WP_Query( array( 'post_type' => $post_type, 'posts_per_page' => $settings['post_per'] ) );
		if ( $query->have_posts() ) { ?>
            <div class="last-post-side">
				<?php while ( $query->have_posts() ) {
					$query->the_post(); ?>
                    <a href="<?php the_permalink(); ?>" class="item d-flex align-items-center"
                       title="<?php the_title(); ?>">
                        <div class="thumbnail">
							<?php $post_thumbnail = get_the_post_thumbnail_url(); ?>
							<?php if ( $post_thumbnail ) { ?>
                                <img src="<?php the_post_thumbnail_url( 'side_post' ); ?>" alt="<?php the_title(); ?>">
							<?php } else { ?>
                                <img src="<?php echo get_template_directory_uri() . '/img/placeholder.png'; ?>"
                                     alt="<?php the_title(); ?>">
							<?php } ?>
                            <div class="cover"></div>
                            <i class="fas fa-link" aria-hidden="true"></i>
                        </div>
                        <div class="content">
                            <h3><?php echo wp_trim_words( get_the_title(), '5', ' ...' ) ?></h3>
							<?php if ( $query_type == 'product' ) {
								global $product;
								if ( $price_html = $product->get_price_html() ) : ?>
                                    <span class="price"><?php echo $price_html; ?></span>
								<?php endif;
							} else { ?>
                                <span class="date"> <i class="fas fa-calendar-alt"
                                                       aria-hidden="true"></i> <?php echo get_the_date(); ?></span>
							<?php } ?>
                        </div>
                    </a>
				<?php } ?>
            </div>
		<?php wp_reset_postdata(); }
	}


	protected function _content_template() {
	}
}
