<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Login_Form extends Widget_Base
{

    public function get_name()
    {
        return 'login-form';
    }

    public function get_title()
    {
        return __('ورود و عضویت', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-lock-user';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {


        $this->start_controls_section(
            'section_icon',
            [
                'label' => __('آیکن', 'themsah'),
            ]
        );

        $this->add_control(
            'login_icon',
            [
                'label' => __('آیکن ورود و عضویت', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-user',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'close_icon',
            [
                'label' => __('آیکن بستن مودال', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-times',
                    'library' => 'solid',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_submenudetail',
            [
                'label' => __('زیر منو کاربر', 'themsah'),
            ]
        );

        $this->add_control(
            'beforetitle', [
                'label' => __('متن قبل نام کاربر', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('خوش آمدید', 'themsah'),
                'label_block' => true,
            ]
        );


        $this->add_control(
            'usermeta',
            [
                'label' => __('اطلاعات کاربر', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '$current_user->user_login',
                'options' => [
                    'user_login' => __('نام کاریری', 'themsah'),
                    'user_email' => __('ایمیل', 'themsah'),
                    'user_firstname' => __('نام', 'themsah'),
                    'user_lastname' => __('نام خانوادگی', 'themsah'),
                    'display_name' => __('نام نمایشی', 'themsah'),
                ],
            ]
        );

        $this->add_control(
            'aftertitle', [
                'label' => __('متن بعد نام کاربر', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('عزیز', 'themsah'),
                'label_block' => true,
            ]
        );


        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'list_title', [
                'label' => __('عنوان آیتم', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('عنوان', 'themsah'),
                'label_block' => true,
            ]
        );


        $repeater->add_control(
            'list_item_url',
            [
                'label' => __(' لینک آیتم', 'themsah'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('https://your-link.com', 'themsah'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => true,
                ],
            ]
        );


        $repeater->add_control(
            'subitem_icon',
            [
                'label' => __('آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-user',
                    'library' => 'solid',
                ],
            ]
        );


        $this->add_control(
            'item-list',
            [
                'label' => __('آیتم ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ list_title }}}',
            ]
        );

        $this->add_control(
            'show_exit',
            [
                'label' => __('نمایش خروج', 'themsah'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'themsah'),
                'label_off' => __('مخفی', 'themsah'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'exit_text', [
                'label' => __('عنوان خروج', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('', 'themsah'),
                'label_block' => true,
                'condition' => [
                    'show_exit' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'exit_icon',
            [
                'label' => __('آیکن خروج', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-times',
                    'library' => 'solid',
                ],
                'condition' => [
                    'show_exit' => 'yes',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'section_login',
            [
                'label' => __('ورود', 'themsah'),
            ]
        );

        $this->add_control(
            'logintitle',
            [
                'label' => __('Title', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Log in',
            ]
        );

        $this->add_control(
            'usernamelabel',
            [
                'label' => __('User Name Label', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Username or email address',
            ]
        );

        $this->add_control(
            'usernameplaceholder',
            [
                'label' => __('User Name Placeholder', 'themsah'),
                'type' => Controls_Manager::TEXT,

            ]
        );

        $this->add_control(
            'passwordlabel',
            [
                'label' => __('Password Label', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Password',
            ]
        );

        $this->add_control(
            'passwordplaceholder',
            [
                'label' => __('Password Placeholder', 'themsah'),
                'type' => Controls_Manager::TEXT,

            ]
        );

        $this->add_control(
            'rememberme',
            [
                'label' => __('Remember me', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Remember me',

            ]
        );

        $this->add_control(
            'loginbtntext',
            [
                'label' => __('Button Text', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Log in',

            ]
        );

        $this->add_control(
            'loginbtnicon',
            [
                'label' => __('آیکن دکمه', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-user',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
            'lostpassword',
            [
                'label' => __('Lost password', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Lost your password?',

            ]
        );


        $this->end_controls_section();
        $this->start_controls_section(
            'section_register',
            [
                'label' => __('عضویت', 'themsah'),
            ]
        );

        $this->add_control(
            'registertitle',
            [
                'label' => __('Title', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Register',
            ]
        );

        $this->add_control(
            'userregisterlabel',
            [
                'label' => __('برچسب فیلد نام کاربری', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'نام کاربری',
            ]
        );

        $this->add_control(
            'userregisterplaceholder',
            [
                'label' => __('نگهدارنده فیلد نام کاربری', 'themsah'),
                'type' => Controls_Manager::TEXT,

            ]
        );

        $this->add_control(
            'emailregisterlabel',
            [
                'label' => __('برچسب فیلد ایمیل', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'ایمیل',
            ]
        );

        $this->add_control(
            'emailregisterplaceholder',
            [
                'label' => __('نگهدارنده فیلد ایمیل', 'themsah'),
                'type' => Controls_Manager::TEXT,

            ]
        );

        $this->add_control(
            'shortdesc',
            [
                'label' => __('متن توضیح کوتاه', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'یک رمز به نشانی ایمیل شما فرستاده خواهد شد.',
            ]
        );

        $this->add_control(
            'registerbtntext',
            [
                'label' => __('متن دکمه', 'themsah'),
                'type' => Controls_Manager::TEXT,
                'default' => 'عضویت',
            ]
        );
        $this->add_control(
            'registerbtnicon',
            [
                'label' => __('آیکن دکمه', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-user',
                    'library' => 'solid',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'icon_style',
            [
                'label' => __('آیکن ها و تصویر کاربر', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_alignicon',
            [
                'label' => __('چینش', 'themsah'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'right' => [
                        'title' => __('راست', 'themsah'),
                        'icon' => 'fa fa-align-right',
                    ],

                    'center' => [
                        'title' => __('وسط', 'themsah'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'left' => [
                        'title' => __('چپ', 'themsah'),
                        'icon' => 'fa fa-align-left',
                    ],

                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .userbox' => 'text-align: {{VALUE}} !important'
                ]
            ]
        );

        $this->start_controls_tabs('icontabstyle');

        $this->start_controls_tab(
            'tab_loginicon',
            [
                'label' => __('آیکن تاگل', 'themsah'),
            ]
        );

        $this->add_control(
            'loginicon_color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn i' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} #loginmodalbtn svg path' => 'fill: {{VALUE}} !important'
                ]
            ]
        );

        $this->add_control(
            'loginicon_bac',
            [
                'label' => __('رنگ پس زمینه آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'loginiconhover_color',
            [
                'label' => __('رنگ آیکن درحالت هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn:hover i' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} #loginmodalbtn:hover svg path' => 'fill: {{VALUE}} !important'
                ]
            ]
        );

        $this->add_control(
            'loginiconhover_bac',
            [
                'label' => __('رنگ پس زمینه آیکن در حال هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'loginiconsize',
            [
                'label' => __('سایز آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn i' => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} #loginmodalbtn svg' => 'width: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'login-icon-dimensions',
            [
                'label' => __('ابعاد آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 80,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 45,
                ],
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-login-icon',
            [
                'label' => __('گردی لبه های آیکن', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin-login-icon',
            [
                'label' => __('فاصله آیکن', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} #loginmodalbtn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .userprofile' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_closeicon',
            [
                'label' => __('آیکن بستن', 'themsah'),
            ]
        );

        $this->add_control(
            'closeicon_color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .modal-header .close i' => 'color: {{VALUE}} !important'
                ]
            ]
        );

        $this->add_control(
            'closeiconhover_color',
            [
                'label' => __('رنگ آیکن درحالت هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .modal-header .close i:hover' => 'color: {{VALUE}} !important'
                ]
            ]
        );

        $this->add_responsive_control(
            'closeiconsize',
            [
                'label' => __('سایز آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} .modal-header .close i' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_userpicture',
            [
                'label' => __('تصویر کاربر', 'themsah'),
            ]
        );

        $this->add_control(
            'userprofilephotoborder-radius',
            [
                'label' => __('گردی لبه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .userprofile img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'userphotosize',
            [
                'label' => __('سایز تصویر', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 70,
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} .userprofile img' => 'width: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_control(
            'show_photoicon',
            [
                'label' => __('مخفی کردن آیکن کنار تصویر', 'themsah'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('مخفی', 'themsah'),
                'label_off' => __('نمایش', 'themsah'),
                'return_value' => 'none',
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userprofile::before' => 'display: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'photoicon_color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userprofile::before' => 'border-color: {{VALUE}} !important'
                ],
                'condition' => [
                    'show_photoicon' => '',
                ],

            ]
        );

        $this->add_control(
            'photoiconactive_color',
            [
                'label' => __('رنگ آیکن حالت فعال', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userprofile.rotatebefore::before' => 'border-color: {{VALUE}} !important'
                ],
                'condition' => [
                    'show_photoicon' => '',
                ],

            ]
        );


        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->end_controls_section();

        $this->start_controls_section(
            'section_userdropdown',
            [
                'label' => __('زیر منو کاربر', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'topdistance_submenu',
            [
                'label' => __('فاصله', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu' => 'top: calc(110% + {{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} .userbox .opensub-loginmenu' => 'top: calc(100% + {{SIZE}}{{UNIT}});',
                ],

            ]
        );

        $this->add_responsive_control(
            'summenuheaderpadding',
            [
                'label' => __('فاصله داخلی باکس خوشامد گویی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .sub-loginmenu-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'summenuheaderborder',
                'selector' => '{{WRAPPER}} .userbox .sub-loginmenu .sub-loginmenu-header',
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'wellcometext_color',
            [
                'label' => __('رنگ متن خوشامد گویی', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .sub-loginmenu-header p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'wellcometext_typography',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selector' => '{{WRAPPER}} .userbox .sub-loginmenu-header p',
            ]
        );


        $this->add_control(
            'subwidth',
            [
                'label' => __('عرض', 'themsah'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 200,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu' => 'min-width: {{VALUE}}px',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'subbackground',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .userbox .sub-loginmenu',
            ]
        );

        $this->start_controls_tabs('sub_tabs_style');

        $this->start_controls_tab(
            'subtabnormalitem',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'color_item',
            [
                'label' => __('رنگ متن آیتم ها', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'subicon_color',
            [
                'label' => __('رنگ آیکن آیتم ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li a i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a i' => 'color: {{VALUE}}'
                ],

            ]
        );

        $this->add_control(
            'colorexit_text',
            [
                'label' => __('رنگ متن خروج', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a' => 'color: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_control(
            'exiticon_color',
            [
                'label' => __('رنگ آیکن خروج', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a i' => 'color: {{VALUE}} !important'
                ],

            ]
        );

        $this->add_control(
            'exittopborder_color',
            [
                'label' => __('رنگ خط بالای خروج', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box' => 'border-top-color: {{VALUE}} !important'
                ],
                'separator' => 'after',

            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'subtabnormalitemhover',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'color_itemhover',
            [
                'label' => __('رنگ متن آیتم ها در حالت هاور', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li:hover a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'color_exithover',
            [
                'label' => __('رنگ متن خروج در حالت هاور', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'subiconhover_color',
            [
                'label' => __('رنگ آیکن آیتم ها درحالت هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li:hover a i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'exiticonhover_color',
            [
                'label' => __('رنگ آیکن خروج درحالت هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a:hover i' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'baccolor_itemhover',
            [
                'label' => __('رنگ پس زمینه آیتم ها درحالت هاور', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li:hover' => 'background-color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->end_controls_tab();


        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'listitem_typography',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li a',
                    '{{WRAPPER}} .userbox .sub-loginmenu .exit-box a',
                ]

            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dropdown_border',
                'selector' => '{{WRAPPER}} .userbox .sub-loginmenu',
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'submenu_border_radius',
            [
                'label' => __('گردی لبه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .userbox .sub-loginmenu li:first-child a' => 'border-top-left-radius: {{TOP}}{{UNIT}}; border-top-right-radius: {{RIGHT}}{{UNIT}};',
                    '{{WRAPPER}} .userbox .sub-loginmenu li:last-child a' => 'border-bottom-right-radius: {{BOTTOM}}{{UNIT}}; border-bottom-left-radius: {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'submenu_box_shadow',
                'exclude' => [
                    'box_shadow_position',
                ],
                'selector' => '{{WRAPPER}} .userbox .sub-loginmenu',
            ]
        );

        $this->add_responsive_control(
            'padding_horizontal_submenu_item',
            [
                'label' => __('فاصله داخلی افقی', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li a' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}',
                ],
                'separator' => 'before',

            ]
        );

        $this->add_responsive_control(
            'padding_vertical_submenu_item',
            [
                'label' => __('فاصله داخلی عمودی', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .userbox .sub-loginmenu ul li a' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'modalbox_style',
            [
                'label' => __('استایل باکس مودال', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'modaleadius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .modal-dialog .modal-content' => 'overflow:hidden;border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-modalcontent',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .modal-dialog .modal-content',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'tabs_style',
            [
                'label' => __('استایل عنوان تب', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-modalheader',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .modal-header',
            ]
        );

        $this->add_control(
            'paddingmodalheader',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .modal-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->start_controls_tabs('tabstitle_style');

        $this->start_controls_tab(
            'tab_normal',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'tabtitle_color',
            [
                'label' => __('رنگ عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .modal-header .modal-title' => 'color: {{VALUE}} !important'
                ]
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_hover',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'tabtitlehover_color',
            [
                'label' => __('رنگ عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .modal-header .modal-title:hover' => 'color: {{VALUE}} !important;border-bottom-color: {{VALUE}} !important',
                ]
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_active',
            [
                'label' => __('فعال', 'themsah'),
            ]
        );

        $this->add_control(
            'tabtitleactive_color',
            [
                'label' => __('رنگ عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .modal-header .modal-title.active' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .modal-header .nav-link.active' => 'border-bottom-color: {{VALUE}} !important'
                ]
            ]
        );
        $this->end_controls_tab();

        $this->end_controls_tabs();


        $this->end_controls_section();


        $this->start_controls_section(
            'label_style',
            [
                'label' => __('استایل برچسب ها', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'label_color',
            [
                'label' => __('رنگ برچسب فیلد', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .login label' => 'color: {{VALUE}} !important',
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'label_typography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} .login label',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'input_style',
            [
                'label' => __('فیلدهای ورودی متن', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'inputpadding',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit])' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'inputradius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit])' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'inputtypography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} .login input:not([type=submit])',
            ]
        );

        $this->add_control(
            'input_color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit])' => 'color: {{VALUE}} !important',
                ]
            ]
        );

        $this->add_control(
            'inputplaceholder_color',
            [
                'label' => __('رنگ متن نگهدارنده', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit])::placeholder' => 'color: {{VALUE}} !important',
                ]
            ]
        );


        $this->start_controls_tabs('inputhoac_style');

        $this->start_controls_tab(
            'inputnormal',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'input_bac',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit])' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'inputborder',
                'selector' => '{{WRAPPER}} .login input:not([type=submit])',
                'separator' => 'after',
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'niputact',
            [
                'label' => __('فعال', 'themsah'),
            ]
        );

        $this->add_control(
            'input_bacact',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .login input:not([type=submit]):focus' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'inputborderactive',
                'selector' => '{{WRAPPER}} .login input:not([type=submit]):focus',
                'separator' => 'after',
            ]
        );

        $this->end_controls_tab();


        $this->end_controls_tabs();


        $this->end_controls_section();


        $this->start_controls_section(
            'btn_style',
            [
                'label' => __('دکمه', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'btnpadding',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .modal-body *[type=submit]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'btnradius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .modal-body *[type=submit]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btntypography',
                'label' => __('تایپوگرافی', 'themsah'),

                'selector' => '{{WRAPPER}} .modal-body *[type=submit]',
            ]
        );

        $this->add_responsive_control(
            'btniconsize',
            [
                'label' => __('سایز آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],

                'selectors' => [
                    '{{WRAPPER}} .modal-body button i' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'btniconmargin',
            [
                'label' => __('فاصله آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .modal-body button i' => 'margin-inline-start: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->start_controls_tabs('btntab_style');

        $this->start_controls_tab(
            'btnnormal',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'btntextcolor',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .modal-body *[type=submit]' => 'color: {{VALUE}} !important',

                ],
            ]
        );
        $this->add_control(
            'btniconcolor',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .modal-body button i' => 'color: {{VALUE}}',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-button',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]',
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btnbox_shadow',
                'label' => __('سایه', 'themsah'),
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btnborder',
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]',
                'separator' => 'after',
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'btnhover',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'btnhovertextcolor',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .modal-body *[type=submit]:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'btniconhovertextcolor',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .modal-body *[type=submit]:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'btnhoverbackground',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]:hover',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btnhoverbox_shadow',
                'label' => __('سایه', 'themsah'),
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btnborderhover',
                'selector' => '{{WRAPPER}} .modal-body *[type=submit]:hover',
                'separator' => 'after',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


        $this->start_controls_section(
            'other_style',
            [
                'label' => __('متن ها', 'themsah'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'forgottext',
            [
                'label' => __('فراموشی رمز', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'forgottext_typography',
                ';label' => 'تایپو گرافی متن فراموشی رمز',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selector' => '{{WRAPPER}} .login .woocommerce-LostPassword.lost_password a',

            ]
        );

        $this->add_control(
            'forgottextcolor',
            [
                'label' => __('رنگ متن فراموشی رمز', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .login .woocommerce-LostPassword.lost_password a' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'sendemailtext',
            [
                'label' => __('متن ارسال ایمیل', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'emailsendtext_typography',
                ';label' => 'تایپو گرافی متن ارسال ایمیل',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selector' => '{{WRAPPER}} .login .emailsendtext',

            ]
        );

        $this->add_control(
            'emailsendtextcolor',
            [
                'label' => __('رنگ متن ارسال ایمیل', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .login .emailsendtext' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'sendemailtext',
            [
                'label' => __('متن سیاست حریم خصوصی', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'privacytext_typography',
                ';label' => 'تایپو گرافی متن سیاست حریم خصوصی',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selector' => '{{WRAPPER}} .login .woocommerce-privacy-policy-text',

            ]
        );

        $this->add_control(
            'privacytextcolor',
            [
                'label' => __('رنگ متن سیاست حریم خصوصی', 'themsah'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .login .woocommerce-privacy-policy-text' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );


        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>
        <div class="modal fade" id="loginmodal" tabindex="-2" role="dialog" aria-labelledby="exampleModalLabel2"
             aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <ul class="nav nav-tabs" id="myTab" role="tablist">
                            <li class="nav-item">
                                <a class="nav-link active modal-title" id="home-tab" data-toggle="tab"
                                   href="#loginpanel" role="tab" aria-controls="home"
                                   aria-selected="true"><?php echo $settings['logintitle']; ?></a>
                            </li>
                            <?php if ('1' === get_option('users_can_register') || 'yes' === get_option('woocommerce_enable_myaccount_registration') && class_exists('WooCommerce')) : ?>
                                <li class="nav-item">
                                    <a class="nav-link modal-title" id="profile-tab" data-toggle="tab"
                                       href="#registerpanel" role="tab" aria-controls="profile"
                                       aria-selected="false"><?php echo $settings['registertitle']; ?></a>
                                </li>
                            <?php endif; ?>
                        </ul>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true"><?php \Elementor\Icons_Manager::render_icon($settings['close_icon'], ['aria-hidden' => 'true']) ?></span>
                        </button>
                    </div>
                    <div class="modal-body login">
                        <div class="tab-content" id="myTabContent">
                            <div class="tab-pane fade show active" id="loginpanel" role="tabpanel"
                                 aria-labelledby="home-tab">
                                <?php if (class_exists('WooCommerce')) { ?>
                                    <form class="woocommerce-form woocommerce-form-login login mt-3 login-form"
                                          method="post" action="<?= site_url(); ?>/wp-login.php">

                                        <?php do_action('woocommerce_login_form_start'); ?>

                                        <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                                            <label for="username"><?php esc_html_e($settings['usernamelabel'], 'woocommerce'); ?>
                                                &nbsp;<span class="required">*</span></label>
                                            <input placeholder="<?php echo $settings['usernameplaceholder']; ?>"
                                                   type="text"
                                                   class="woocommerce-Input woocommerce-Input--text input-text"
                                                   name="username" id="username" autocomplete="username"
                                                   value="<?php echo (!empty($_POST['username'])) ? esc_attr(wp_unslash($_POST['username'])) : ''; ?>"/><?php // @codingStandardsIgnoreLine
                                            ?>
                                        </p>
                                        <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                                            <label for="password"><?php esc_html_e($settings['passwordlabel'], 'woocommerce'); ?>
                                                &nbsp;<span class="required">*</span></label>
                                            <input placeholder="<?php echo $settings['passwordplaceholder']; ?>"
                                                   class="woocommerce-Input woocommerce-Input--text input-text"
                                                   type="password" name="password" id="password"
                                                   autocomplete="current-password"/>
                                        </p>

                                        <?php do_action('woocommerce_login_form'); ?>

                                        <p class="form-row">
                                            <label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
                                                <input class="woocommerce-form__input woocommerce-form__input-checkbox"
                                                       name="rememberme" type="checkbox" id="rememberme"
                                                       value="forever"/>
                                                <span><?php esc_html_e($settings['rememberme'], 'woocommerce'); ?></span>
                                            </label>
                                            <?php wp_nonce_field('woocommerce-login', 'woocommerce-login-nonce'); ?>
                                            <button type="submit"
                                                    class="woocommerce-form-login__submit"
                                                    name="login"
                                                    value="<?php esc_attr_e($settings['loginbtntext'], 'woocommerce'); ?>"><?php esc_html_e($settings['loginbtntext'], 'woocommerce'); ?><?php \Elementor\Icons_Manager::render_icon($settings['loginbtnicon'], ['aria-hidden' => 'true']) ?></button>
                                        </p>
                                        <p class="woocommerce-LostPassword lost_password">
                                            <a href="<?php echo esc_url(wp_lostpassword_url()); ?>"><?php esc_html_e($settings['lostpassword'], 'woocommerce'); ?></a>
                                        </p>

                                        <?php do_action('woocommerce_login_form_end'); ?>

                                    </form>
                                <?php } else {
                                    $args = array(
                                        'echo' => true,
                                        // Default 'redirect' value takes the user back to the request URI.
                                        'redirect' => (is_ssl() ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'],
                                        'form_id' => 'wploginform',
                                        'label_username' => __($settings['usernamelabel'], 'woocommerce'),
                                        'label_password' => __($settings['passwordlabel'], 'woocommerce'),
                                        'label_remember' => __($settings['rememberme'], 'woocommerce'),
                                        'label_log_in' => __($settings['loginbtntext'], 'woocommerce'),
                                        'id_username' => 'user_login',
                                        'id_password' => 'user_pass',
                                        'id_remember' => 'rememberme',
                                        'id_submit' => 'wp-submit',
                                        'remember' => true,
                                        'value_username' => '',
                                        // Set 'value_remember' to true to default the "Remember me" checkbox to checked.
                                        'value_remember' => false,
                                    );
                                    wp_login_form($args);
                                } ?>
                            </div>
                            <?php if ('1' === get_option('users_can_register') || class_exists('WooCommerce') && 'yes' === get_option('woocommerce_enable_myaccount_registration')) : ?>
                                <div class="tab-pane fade" id="registerpanel" role="tabpanel"
                                     aria-labelledby="profile-tab">
                                    <?php if (class_exists('WooCommerce') && 'yes' === get_option('woocommerce_enable_myaccount_registration')) { ?>
                                        <form method="post"
                                              class="mt-3 woocommerce-form woocommerce-form-register register" <?php do_action('woocommerce_register_form_tag'); ?> >
                                            <?php do_action('woocommerce_register_form_start'); ?>

                                            <?php if ('no' === get_option('woocommerce_registration_generate_username')) : ?>

                                                <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                                                    <label for="reg_username"><?php esc_html_e($settings['userregisterlabel'], 'woocommerce'); ?>
                                                        &nbsp;<span class="required">*</span></label>
                                                    <input placeholder="<?php echo $settings['userregisterlabel']; ?>"
                                                           type="text"
                                                           class="woocommerce-Input woocommerce-Input--text input-text"
                                                           name="username" id="reg_username" autocomplete="username"
                                                           value="<?php echo (!empty($_POST['username'])) ? esc_attr(wp_unslash($_POST['username'])) : ''; ?>"/><?php // @codingStandardsIgnoreLine ?>
                                                </p>

                                            <?php endif; ?>

                                            <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                                                <label for="reg_email"><?php esc_html_e($settings['emailregisterlabel'], 'woocommerce'); ?>
                                                    &nbsp;<span class="required">*</span></label>
                                                <input placeholder="<?php echo $settings['emailregisterplaceholder']; ?>"
                                                       type="email"
                                                       class="woocommerce-Input woocommerce-Input--text input-text"
                                                       name="email" id="reg_email" autocomplete="email"
                                                       value="<?php echo (!empty($_POST['email'])) ? esc_attr(wp_unslash($_POST['email'])) : ''; ?>"/><?php // @codingStandardsIgnoreLine ?>
                                            </p>

                                            <?php if ('no' === get_option('woocommerce_registration_generate_password')) : ?>

                                                <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                                                    <label for="reg_password"><?php esc_html_e('Password', 'woocommerce'); ?>
                                                        &nbsp;<span class="required">*</span></label>
                                                    <input type="password"
                                                           class="woocommerce-Input woocommerce-Input--text input-text"
                                                           name="password" id="reg_password"
                                                           autocomplete="new-password"/>
                                                </p>

                                            <?php else : ?>

                                                <p class="emailsendtext"><?php esc_html_e($settings['shortdesc'], 'woocommerce'); ?></p>

                                            <?php endif; ?>

                                            <?php do_action('woocommerce_register_form'); ?>

                                            <p class="woocommerce-form-row form-row">
                                                <?php wp_nonce_field('woocommerce-register', 'woocommerce-register-nonce'); ?>
                                                <button type="submit"
                                                        class="woocommerce-form-register__submit"
                                                        name="register"
                                                        value="<?php esc_attr_e($settings['registerbtntext'], 'woocommerce'); ?>"><?php esc_html_e($settings['registerbtntext'], 'woocommerce'); ?><?php \Elementor\Icons_Manager::render_icon($settings['registerbtnicon'], ['aria-hidden' => 'true']) ?></button>
                                            </p>

                                            <?php do_action('woocommerce_register_form_end'); ?>

                                        </form>
                                    <?php } elseif ('1' === get_option('users_can_register')) { ?>
                                        <form class="register" name="registerform" id="registerform"
                                              action="<?php echo esc_url(site_url('wp-login.php?action=register', 'login_post')); ?>"
                                              method="post" novalidate="novalidate">
                                            <p>
                                                <label for="user_login"><?php _e('Username'); ?></label>
                                                <input type="text" name="user_login" id="user_login" class="input"
                                                       value="<?php echo esc_attr(wp_unslash($user_login)); ?>"
                                                       size="20" autocapitalize="off"/>
                                            </p>
                                            <p>
                                                <label for="user_email"><?php _e('Email'); ?></label>
                                                <input type="email" name="user_email" id="user_email" class="input"
                                                       value="<?php echo esc_attr(wp_unslash($user_email)); ?>"
                                                       size="25"/>
                                            </p>
                                            <?php

                                            /**
                                             * Fires following the 'Email' field in the user registration form.
                                             *
                                             * @since 2.1.0
                                             */
                                            do_action('register_form');

                                            ?>
                                            <p id="reg_passmail">
                                                <?php _e('Registration confirmation will be emailed to you.'); ?>
                                            </p>
                                            <br class="clear"/>
                                            <input type="hidden" name="redirect_to"
                                                   value="<?php echo esc_attr($redirect_to); ?>"/>
                                            <p class="submit">
                                                <input type="submit" name="wp-submit" id="wp-submit"
                                                       class="button button-primary button-large"
                                                       value="<?php esc_attr_e('Register'); ?>"/>
                                            </p>
                                        </form>
                                    <?php } ?>
                                </div>
                            <?php endif; ?>
                        </div>


                    </div>

                </div>
            </div>
        </div>


        <div class="userbox">
            <?php
            if (\Elementor\Plugin::$instance->editor->is_edit_mode()) { ?>
                <a href="#" data-toggle="modal" data-target="#loginmodal"
                   id="loginmodalbtn"><?php \Elementor\Icons_Manager::render_icon($settings['login_icon'], ['aria-hidden' => 'true']) ?></a>
            <?php }
            global $user_ID;
            if ($user_ID) {
                if (is_user_logged_in()) {
                    $current_user = wp_get_current_user(); ?>
                    <a class="userprofile" href="#"><img src="<?php echo get_avatar_url($current_user->ID, 90); ?>"
                                                         class="u-avatar"></a>
                <?php }

            } else { ?>
                <a href="#" data-toggle="modal" data-target="#loginmodal"
                   id="loginmodalbtn"><?php \Elementor\Icons_Manager::render_icon($settings['login_icon'], ['aria-hidden' => 'true']) ?></a>
                <?php
            } ?>


            <div class="sub-loginmenu">
                <div class="sub-loginmenu-header">
                    <p class="m-0">

                        <?php
                        echo $settings['beforetitle'];
                        $username = $settings['usermeta'];
                        echo $current_user->$username;
                        echo $settings['aftertitle'];
                        ?>

                    </p>
                </div>
                <?php if ($settings['item-list']) { ?>
                    <ul>
                        <?php foreach ($settings['item-list'] as $item) {
                            ?>
                            <li class="sublogin-listitem">
                                <a href="<?php echo $item['list_item_url']['url']; ?>">
                                    <?php \Elementor\Icons_Manager::render_icon($item['subitem_icon'], ['aria-hidden' => 'true']); ?>
                                    <span><?php echo $item['list_title']; ?></span>
                                </a>
                            </li>
                        <?php } ?>
                    </ul>
                <?php }
                $exit = $settings['exit_text'];
                if ($exit != false) {
                    ?>
                    <div class="exit-box p-3">
                        <p>
                            <a href="<?php echo wp_logout_url(home_url()); ?>">
                                <?php \Elementor\Icons_Manager::render_icon($settings['exit_icon'], ['aria-hidden' => 'true']); ?>
                                <?php echo $settings['exit_text']; ?>
                            </a>

                        </p>
                    </div>
                <?php } ?>
            </div>
        </div>

    <?php }


    protected function _content_template()
    {
    }
}


