<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class Menu extends Widget_Base
{

    public function get_name()
    {
        return 'menu';
    }

    public function get_title()
    {
        return __('منو', 'themsah');
    }

    public function get_icon()
    {
        return 'eicon-nav-menu';
    }

    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('محتوا', 'themsah'),
            ]
        );

        $this->add_control(
            'menu_list',
            [
                'label' => __('انتخاب منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => themsah_menu(),
            ]
        );
        $this->add_control(
            'menu_type',
            [
                'label' => __('جهت منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'horizontal',
                'options' => [
                    'horizontal' => __('افقی', 'themsah'),
                    'vertical' => __('عمودی', 'themsah'),
                ],
            ]
        );
        $this->add_responsive_control(
            'menu-height',
            [
                'label' => __('ارتفاع منو', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 150,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .horizontal.main-menu > ul' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_control(
            'hover_type',
            [
                'label' => __('نوع هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'underline-hover',
                'options' => [
                    '' => __('فقط رنگ', 'themsah'),
                    'underline-hover' => __('خط زیر', 'themsah'),
                    'background-hover' => __('پس زمینه', 'themsah'),
                ],
                'condition' => [
                    'menu_type' => 'horizontal',
                ]
            ]
        );

        $this->add_control(
            'v_hover_type',
            [
                'label' => __('نوع هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'sideline-hover',
                'options' => [
                    'side-flush' => __('فلش کنار', 'themsah'),
                    'sideline-hover' => __('خط کنار', 'themsah'),
                ],
                'condition' => [
                    'menu_type' => 'vertical',
                ]
            ]
        );

        $this->add_control(
            'image-position',
            [
                'label' => __('جایگاه تصویر / آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('پیش فرض', 'themsah'),
                    'top-image' => __('بالا', 'themsah'),
                ],
                'condition' => [
                    'menu_type' => 'horizontal',
                ]
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('تنظیمات منو', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs('menu-item');

        $this->start_controls_tab(
            'normal-menu',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => __('رنگ منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu ul li a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .main-menu.vertical ul li.menu-item-has-children::after' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
            'hover-menu',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );
        $this->add_control(
            'title_color_hover',
            [
                'label' => __('رنگ هاور منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu > ul > li:hover > a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .main-menu.vertical > ul > li.menu-item-has-children:hover::after' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .main-menu.vertical.sideline-hover ul li a::before' => 'background-color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'border_ho_color',
            [
                'label' => __('رنگ خط زیر', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .horizontal.main-menu > ul > li::before' => 'background: {{VALUE}} !important',
                    '{{WRAPPER}} .horizontal.main-menu > ul > li::after' => 'background: {{VALUE}} !important',
                ],
                'condition' => [
                    'menu_type' => 'horizontal',
                    'hover_type' => 'underline-hover'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background_item_hover_color',
                'label' => esc_html__('پس زمینه هاور', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .main-menu.background-hover:not(.vertical) > ul > li > a::before',
                'condition' => [
                    'menu_type' => 'horizontal',
                    'hover_type' => 'background-hover'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
            'active-menu',
            [
                'label' => __('فعال', 'themsah'),
            ]
        );
        $this->add_control(
            'title_color_active',
            [
                'label' => __('رنگ منو فعال', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu.horizontal ul li.current-menu-item > a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .main-menu.horizontal ul li.current_page_item > a' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->end_controls_tabs();


        $this->add_responsive_control(
            'menu-spacing',
            [
                'label' => __('فاصله بین آبتم ها', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 150,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-menu > ul > li' => 'margin-right: calc({{SIZE}}{{UNIT}} / 2);margin-left: calc({{SIZE}}{{UNIT}} / 2)',
                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __('تایپوگرافی منو', 'themsah'),
                
                'selector' => '{{WRAPPER}} .main-menu ul li a',
            ]
        );

        $this->add_responsive_control(
            'item_border_radius',
            [
                'label' => __('گردی گوشه های ایتم ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .main-menu.background-hover:not(.vertical) > ul > li > a::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'menu_type' => 'horizontal',
                    'hover_type' => 'background-hover'
                ]
            ]
        );

        $this->add_responsive_control(
            'menu-image-height',
            [
                'label' => __('ارتفاع تصویر', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 80,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-menu.top-image > ul > li > a img' => 'max-height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_responsive_control(
            'menu-image-width',
            [
                'label' => __('عرض تصویر', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-menu.top-image > ul > li > a img' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_responsive_control(
            'menu-icon-width',
            [
                'label' => __('سایز آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '22',
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-menu.top-image > ul > li > a i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'content_section3',
            [
                'label' => __('تنظیمات زیر منو', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,

            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'submenu-background',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .horizontal.main-menu ul > li > ul',
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => __('خط حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} .horizontal.main-menu ul > li > ul',
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __('سایه کادر', 'themsah'),
                'selector' => '{{WRAPPER}} .horizontal.main-menu ul > li > ul',
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );

        $this->add_control(
            'title_colorse',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu ul > li > ul > li a' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'title_colorse_hover',
            [
                'label' => __('رنگ هاور متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu ul > li > ul > li:hover > a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .main-menu ul > li > ul > li::before' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'border-bottom-color',
            [
                'label' => __('رنگ جداکننده ', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .main-menu > ul li ul li a' => 'border-bottom-color: {{VALUE}} !important',

                ],
            ]
        );

        $this->add_responsive_control(
            'menu_border_radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sub-menu' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                ],
                'condition' => [
                    'menu_type' => 'horizontal'
                ]
            ]
        );


        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>
        <div class="main-menu <?php echo $settings['menu_type'] . ' ' . $settings['hover_type'].' '.$settings['image-position'].' '.$settings['v_hover_type']; ?>">

            <?php if ($settings['menu_type'] == 'horizontal') {
                $walker = new \IW_Nav_Walker;
            } else {
                $walker = new \Walker_Nav_Menu;
            }
            $nav_menu = $settings['menu_list'];
            $nav_menu_args = array(
                'fallback_cb' => '',
                'menu' => $nav_menu,
                'container' => ' ',
                'menu_class' => 'themsah-nav-menu',
                'walker' => $walker,
                'link_before' => '<span class="thm-nav-text">',
                'link_after' => '</span>',
            );
            wp_nav_menu($nav_menu_args); ?>
        </div>
    <?php }

    protected function _content_template()
    {
    }
}
