<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Mini_Cart extends Widget_Base {

	public function get_name() {
		return 'mini-cart';
	}

	public function get_title() {
		return __( 'سبد خرید', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-cart';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}


	protected function _register_controls() {

		$this->start_controls_section(
			'side-cart',
			[
				'label' => __( 'محتوای باکس', 'themsah' ),
			]
		);

        $this->add_control(
            'icon',
            [
                'label' => __('آیکون', 'themsah'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-shopping-cart',
                    'library' => 'solid',
                ],
            ]
        );

        $this->add_control(
			'box-title',
			[
				'label' => __( 'عنوان', 'themsah' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'سبد خرید', 'themsah' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'آیکن تاگل', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'cart-icon' );
		$this->start_controls_tab( 'normal-cart-icon', [ 'label' => __( 'عادی', 'thensah' ) ] );

		$this->add_control(
			'cart-icon-color',
			[
				'label'     => __( 'رنگ آیکن تاگل', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .cart-icon i' => 'color: {{VALUE}}',
					'{{WRAPPER}} .cart-icon svg path' => 'fill: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'background',
			[
				'label'     => __( 'رنگ پس زمینه تعداد', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .cart-count' => 'background: {{VALUE}} !important',
				],
			]
		);
		
			$this->add_control(
			'cart-icon-bac',
			[
				'label'     => __( 'رنگ پس زمینه آیکن تاگل', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .cart-icon' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		$this->start_controls_tab( 'hover-cart-icon', [ 'label' => __( 'هاور', 'thensah' ) ] );

		$this->add_control(
			'cart-icon-hover-color',
			[
				'label'     => __( 'رنگ آیکن تاگل', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .cart-icon:hover i' => 'color: {{VALUE}}',
					'{{WRAPPER}} .cart-icon:hover svg path' => 'fill: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'cart-icon-hover-bac',
			[
				'label'     => __( 'رنگ پس زمینه آیکن تاگل', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .cart-icon:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_responsive_control(
			'cart-icon-size',
			[
				'label' => __( 'سایز آیکن', 'themsah' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
						'step' => 1,
					],

				],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .cart-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .cart-icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'cart-icon-dimensions',
			[
				'label' => __( 'ابعاد آیکن', 'themsah' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 30,
						'max' => 80,
						'step' => 1,
					],

				],
				'default' => [
					'unit' => 'px',
					'size' => 45,
				],
				'selectors' => [
					'{{WRAPPER}} .cart-icon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'border-radius-cart-icon',
			[
				'label' => __( 'گردی لبه های آیکن', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .cart-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin-cart-icon',
			[
				'label' => __( 'فاصله آیکن', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .cart-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'cart-box-style',
			[
				'label' => __( 'تنظیمات باکس', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'list-typography',
				'label' => __( 'تایپوگرافی متن عنوان', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .sidecart h4',
			]
		);

		$this->add_control(
			'title-box-color',
			[
				'label'     => __( 'رنگ متن عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .sidecart h4' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'title-box-line-color',
			[
				'label'     => __( 'رنگ خط زیر عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .sidecart .is-divider' => 'background: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'cart-box-background',
				'label' => __( 'پس زمینه باکس', 'themsah' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sidecart',

                ]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'cart-items',
			[
				'label' => __( 'آیتم های سبد خرید', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'image-size',
			[
				'label'      => __( 'سایز تصویر', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 30,
						'max'  => 150,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 55,
				],
				'selectors'  => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li img' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_control(
			'image-border-radius',
			[
				'label' => __( 'گردی گوشه های تصویر', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'image-spacing',
			[
				'label'      => __( 'فاصله تصویر', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 15,
				],
				'selectors'  => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li img' => 'margin-inline-end:{{SIZE}}{{UNIT}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_product_typography',
				'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li a:not(.remove)',
			]
		);

		$this->add_control(
			'title-product-color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li a:not(.remove)' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'price_product_typography',
				'label'    => __( 'تایپوگرافی قیمت', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li .quantity',
			]
		);

		$this->add_control(
			'price-product-color',
			[
				'label'     => __( 'رنگ قیمت', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li .quantity' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'product-line-color',
			[
				'label'     => __( 'رنگ خط بین آیتم ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .woocommerce-mini-cart.cart_list.product_list_widget li' => 'border-bottom-color: {{VALUE}} !important',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'total-btns',
			[
				'label' => __( 'جمع کل و دکمه ها', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'total-background',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .widget_shopping_cart_content > p'=>'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'total-bt-color',
			[
				'label'     => __( 'رنگ خط بالا', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .woocommerce-mini-cart__total.total' => 'border-top-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'total-text-color',
			[
				'label'     => __( 'رنگ متن جمع کل', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .widget_shopping_cart_content > p.woocommerce-mini-cart__total.total' => 'color: {{VALUE}}',
				],
				'separator' => 'before'
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'total-text-typography',
				'label'    => __( 'تایپوگرافی متن جمع کل', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .widget_shopping_cart_content > p.woocommerce-mini-cart__total.total',
			]
		);

		$this->add_control(
			'total-btns-color',
			[
				'label'     => __( 'رنگ متن دکمه ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .widget_shopping_cart_content > p a' => 'color: {{VALUE}}',
				],
                'separator' => 'before'
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'total-btns-background',
				'label' => __( 'پس زمینه دکمه ها', 'themsah' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .widget_shopping_cart_content > p a',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'total-btns-typography',
				'label'    => __( 'تایپوگرافی دکمه ها', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .widget_shopping_cart_content > p a',
			]
		);

		$this->add_control(
			'total-btns-border-radius',
			[
				'label' => __( 'گردی گوشه های دکمه ها', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .widget_shopping_cart_content > p a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		if (  class_exists( 'WooCommerce' ) ) {?>
                <span class="cart-icon">
                    <?php \Elementor\Icons_Manager::render_icon($settings['icon'], ['aria-hidden' => 'true']); ?>
                    <span id="mini-cart-count" class="cart-count"></span>
                </span>

            <div class="close-side-menu"></div>
            <div class="sidecart woocommerce">
                <div class="cart-popup-title text-center">
                    <h4 class="uppercase"><?php echo $settings['box-title']; ?></h4>
                    <div class="is-divider"></div>
                </div>
                <div class="widget_shopping_cart_content">
					<?php
					global $product;
					if ( is_a( $product, 'WC_Product' ) ) {
						woocommerce_mini_cart();
					} ?>
                </div>
            </div>

		<?php }
	}


	protected function _content_template() {
	}
}
