<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Mobile_Menu extends Widget_Base
{

    public function get_name()
    {
        return 'mobile-menu';
    }

    public function get_title()
    {
        return __('منو موبایل', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-table-of-contents';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('محتوا', 'themsah'),
            ]
        );
        $this->add_control(
            'menu_list',
            [
                'label' => __('انتخاب منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => themsah_menu(),
            ]
        );
        $this->add_control(
            'logo-image',
            [
                'label' => __('تصویر لوگو', 'themsah'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->end_controls_section();
        $this->start_controls_section(
            'box-style',
            [
                'label' => __('باکس کلی', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'box_background',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile-side-menu' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'logo_box_background',
            [
                'label' => __('رنگ پس زمینه لوگو', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile-side-menu .logo-box' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_item_color',
            [
                'label' => __('رنگ متن منو', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile-side-menu ul li a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .mobile-side-menu ul li.menu-item-has-children::after' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'menu_item_color_active',
            [
                'label' => __('رنگ متن منو فعال', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mobile-side-menu ul li.menu-item-has-children.open-sub-menu > a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .mobile-side-menu ul li.current-menu-item > a' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .mobile-side-menu ul li.menu-item-has-children.open-sub-menu::after' => 'color: {{VALUE}} !important',
                    '{{WRAPPER}} .mobile-side-menu ul li.current-menu-item::after' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_typography',
                'label' => __('تایپوگرافی منو', 'themsah'),

                'selector' => '{{WRAPPER}} .mobile-side-menu ul li a',
            ]
        );

        $this->add_control(
            'close-icon-bac',
            [
                'label' => __('پس زمینه آیکن بستن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-close' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'close-icon-color',
            [
                'label' => __('رنگ آیکن بستن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-close::before' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'toggle-icon-style',
            [
                'label' => __('آیکن تاگل', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,

            ]
        );


        $this->add_control(
            'toggle-icon-background',
            [
                'label' => __('رنگ بکگراند ایکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .side-menu-icon-box i' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'toggle-icon-color',
            [
                'label' => __('رنگ ایکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .side-menu-icon-box i' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_responsive_control(
            'toggle-icon-size',
            [
                'label' => __('سایز آیکن', 'plugin-domain'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 50,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .side-menu-icon-box i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'cart-icon-dimensions',
            [
                'label' => __('ابعاد آیکن', 'plugin-domain'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 80,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 40,
                ],
                'selectors' => [
                    '{{WRAPPER}} .side-menu-icon-box i' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-toggle-icon',
            [
                'label' => __('گردی لبه های آیکن', 'plugin-domain'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .side-menu-icon-box i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>
        <div class="side-menu-icon-box d-flex">
            <i class="fas fa-bars side-menu-icon" aria-hidden="true"></i>
            <div class="close-side-menu">
                <span class="menu-close"></span>
            </div>
        </div>

        <div class="mobile-side-menu elementor-side-menu">
            <div class="logo-box">
                <a href="<?php echo bloginfo('url'); ?>">
                    <img src="<?php echo $settings['logo-image']['url']; ?>" alt="<?php echo bloginfo('name'); ?>">
                </a>
            </div>
            <?php
            $nav_menu = $settings['menu_list'];
            $nav_menu_args = array(
                'fallback_cb' => '',
                'menu' => $nav_menu,
                'container' => ' ',
            );
            wp_nav_menu($nav_menu_args); ?>
            <div class="custom-e"></div>
        </div>
    <?php }

    protected function _content_template()
    {
    }
}
