<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class PRODUCTIMAGE extends Widget_Base
{

    public function get_name()
    {
        return 'PRODUCTIMAGE';
    }

    public function get_title()
    {
        return __('تصویر محصول', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-product-images';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('محتوا', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'important_note',
            [
                'label' => __('', 'themsah'),
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => __('این صرفا یک پیش نمایش از چینش تصاویر محصول برای استایل دهی است.', 'themsah'),
                'content_classes' => 'info-text-controller',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'style_section',
            [
                'label' => __('تصاویر', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => __('حاشیه تصاویر', 'themsah'),
                'selector' => '{{WRAPPER}} ol.flex-control-nav.flex-control-thumbs li img,{{WRAPPER}} .flex-viewport,.single-elementor_library {{WRAPPER}} .woocommerce-product-gallery__image',
            ]
        );

        $this->add_responsive_control(
            'border-radius-images',
            [
                'label' => __('گردی لبه های تصاویر', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .flex-viewport' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} ol.flex-control-nav.flex-control-thumbs li img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '.single-elementor_library {{WRAPPER}} .woocommerce-product-gallery__image:not(:first-child)' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '.single-elementor_library {{WRAPPER}} .woocommerce-product-gallery__image:first-child' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'small-image-size',
            [
                'label' => __('سایز تصاویر کوچک', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 150,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 85,
                ],
                'selectors' => [
                    '{{WRAPPER}} ol.flex-control-nav.flex-control-thumbs li img' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
                    '.single-elementor_library {{WRAPPER}} .woocommerce-product-gallery__image:not(:first-child)' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'bubble-style_section',
            [
                'label' => __('حباب تخفیف', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'onsale-text-size',
            [
                'label' => __('سایز متن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 16,
                ],
                'selectors' => [
                    '{{WRAPPER}} .onsale' => 'font-size: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'onsale-dimensions',
            [
                'label' => __('ابعاد حباب', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 100,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 45,
                ],
                'selectors' => [
                    '{{WRAPPER}} .onsale' => 'width: {{SIZE}}{{UNIT}} !important;height: {{SIZE}}{{UNIT}} !important;margin-bottom:-{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-onsale',
            [
                'label' => __('گردی لبه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .onsale' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_control(
            'onsale-color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,

                'selectors' => [
                    '{{WRAPPER}} .onsale' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'onsale-bac',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,

                'selectors' => [
                    '{{WRAPPER}} .onsale' => 'background-color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_section();
    }


    protected function render()
    {

        if (\Elementor\Plugin::$instance->editor->is_edit_mode()) {
            global $post;
            $post = themsah_get_preview_product(); // phpcs:ignore
            setup_postdata($post);
        }
//        do_action('woocommerce_before_single_product_summary');
        woocommerce_show_product_images();

        wp_reset_postdata();
    }

    protected function _content_template()
    {
    }
}
