<?php

namespace ThemsahAddons\Widgets;

use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class PRODUCTTABS extends Widget_Base {

	public function get_name() {
		return 'PRODUCTTABS';
	}

	public function get_title() {
		return __( 'تب های صفحه محصول', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-product-tabs';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'محتوا', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'important_note',
			[
				'label'           => __( '', 'themsah' ),
				'type'            => \Elementor\Controls_Manager::RAW_HTML,
				'raw'             => __( 'این صرفا یک پیش نمایش از چینش تب های محصول برای استایل دهی است.', 'themsah' ),
				'content_classes' => 'info-text-controller',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'tab-style',
			[
				'label' => __( 'تنظیمات تب های بالای', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'text_align',
			[
				'label'   => __( 'چینش', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'flex-end'    => [
						'title' => __( 'پایان', 'themsah' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon'  => 'fa fa-align-center',
					],
					'flex-start'  => [
						'title' => __( 'آغاز', 'themsah' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'default' => 'start',
				'toggle'  => false,
				'selectors'  => [
					'{{WRAPPER}} .tabs.wc-tabs' => 'justify-content:{{VALUE}} !important;',
				],
			]
		);

		$this->add_responsive_control(
			'tab-spacing',
			[
				'label'      => __( 'فاصله تب از پایین', 'themsah' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					]
				],
				'default'    => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors'  => [
					'{{WRAPPER}} .tabs.wc-tabs' => 'margin-bottom:{{SIZE}}{{UNIT}} !important;',
				],
			]
		);




		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'tab-item-typography',
				'label'    => __( 'تایپوگرافی', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .tabs.wc-tabs li a',
			]
		);

        $this->add_responsive_control(
            'tab-border-radius',
            [
                'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tabs.wc-tabs li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important',
                ],
            ]
        );

		$this->start_controls_tabs( 'tabs' );
		$this->start_controls_tab( 'normal-tabs-item', [ 'label' => __( 'عادی', 'themsah' ) ] );
		$this->add_control(
			'tab-color',
			[
				'label'     => __( 'رنگ عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'tab-bac',
			[
				'label'     => __( 'رنگ پس زمینه عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li a' => 'background: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab( 'hover-tabs-item', [ 'label' => __( 'هاور', 'themsah' ) ] );
		$this->add_control(
			'tab-color-hover',
			[
				'label'     => __( 'رنگ عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li a:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'tab-hover-bac',
			[
				'label'     => __( 'رنگ پس زمینه عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li:hover a' => 'background: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab( 'active-tabs-item', [ 'label' => __( 'فعال', 'themsah' ) ] );
		$this->add_control(
			'tab-color-active',
			[
				'label'     => __( 'رنگ عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li.active a'  => 'color: {{VALUE}} !important',
				],
			]
		);
		$this->add_control(
			'tab-active-bac',
			[
				'label'     => __( 'رنگ پس زمینه عنوان تب ', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs.wc-tabs li.active a' => 'background: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->end_controls_section();

		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'محتوا', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'titles_color',
			[
				'label'     => __( 'رنگ عنوان ها', 'plugin-domain' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .woocommerce-tabs.wc-tabs-wrapper h2' => 'color: {{VALUE}}',
					'{{WRAPPER}} #reply-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-product-attributes-item__label' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-review__author' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'titles_typography',
				'label'    => __( 'تایپوگرافی عنوان ها', 'plugin-domain' ),
				
				'selector' => '{{WRAPPER}} .woocommerce-review__author,{{WRAPPER}} .woocommerce-product-attributes-item__label,{{WRAPPER}} #reply-title,{{WRAPPER}} .woocommerce-tabs.wc-tabs-wrapper h2',
			]
		);

		$this->add_control(
			'text-color',
			[
				'label'     => __( 'رنگ متن ها', 'plugin-domain' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .woocommerce-Tabs-panel--description p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-product-attributes p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-product-attributes-item__value' => 'color: {{VALUE}}',
					'{{WRAPPER}} ol.commentlist li .comment_container .description p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-review__published-date' => 'color: {{VALUE}}',
					'{{WRAPPER}} .woocommerce-review__verified' => 'color: {{VALUE}}',
					'{{WRAPPER}} #review_form #respond p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .comment-notes' => 'color: {{VALUE}}',
					'{{WRAPPER}} #commentform label' => 'color: {{VALUE}}',
					'{{WRAPPER}} #email-notes' => 'color: {{VALUE}}',
					'{{WRAPPER}} #review_form #respond textarea' => 'color: {{VALUE}}',
					'{{WRAPPER}} .comment-form .author-meta input' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'text_typography',
				'label'    => __( 'تایپوگرافی متن ها', 'plugin-domain' ),
				
				'selector' => '{{WRAPPER}} #review_form #respond textarea,{{WRAPPER}} #email-notes,{{WRAPPER}} #commentform label,{{WRAPPER}} .comment-notes,{{WRAPPER}} #review_form #respond p,{{WRAPPER}} .woocommerce-review__verified,{{WRAPPER}} .woocommerce-review__published-date,{{WRAPPER}} ol.commentlist li .comment_container .description p,{{WRAPPER}} .woocommerce-product-attributes p , {{WRAPPER}} .woocommerce-Tabs-panel--description p ,{{WRAPPER}}  .comment-form .author-meta input , {{WRAPPER}} .woocommerce-product-attributes-item__value',
			]
		);

		$this->add_control(
			'input-active-color',
			[
				'label'     => __( 'رنگ فعال حاشیه ورودی متن ها', 'plugin-domain' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .comment-form-comment textarea.active,{{WRAPPER}} .comment-form-author input.active, {{WRAPPER}} .comment-form-email input.active' => 'border-color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'comment-bac',
			[
				'label'     => __( 'رنگ پس زمینه باکس نطرات', 'plugin-domain' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} ol.commentlist li .comment_container' => 'background: {{VALUE}} !important',
				],
			]
		);

        $this->add_responsive_control(
            'comment-border-radius',
            [
                'label' => __( 'گردی گوشه های باکس نطرات', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} ol.commentlist li .comment_container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important',
                ],
            ]
        );

		$this->add_control(
			'stars-color',
			[
				'label'     => __( 'رنگ ستاره ها', 'plugin-domain' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} ol.commentlist li .comment_container .star-rating, ol.commentlist li .comment_container .star-rating::before, .stars a' => 'color: {{VALUE}} !important',
				],
			]
		);
		
			$this->add_responsive_control(
			'inputt-border-radius',
			[
				'label' => __( 'گردی گوشه های ورودی ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} #comment,{{WRAPPER}} input:not([type=submit]):not([type=checkbox])' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important',
				],
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_submit',
			[
				'label' => __( 'دکمه ارسال', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'submit-typography',
                'label'    => __( 'تایپوگرافی', 'themsah' ),
                'selector' => '{{WRAPPER}} #submit',
            ]
        );

        $this->add_responsive_control(
            'submit-border-radius',
            [
                'label' => __( 'گردی گوشه های دکمه ارسال', 'plugin-domain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'submit-color',
            [
                'label'     => __( 'رنگ متن', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'submit-background',
                'label'    => __( 'پس زمینه', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} #submit',
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'submit-hover-color',
            [
                'label'     => __( 'رنگ متن', 'plugin-domain' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #submit:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'submit-hover-background',
                'label'    => __( 'پس زمینه', 'plugin-domain' ),
                'types'    => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} #submit:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

		$this->end_controls_section();
	}


    protected function render() {
        global $post;

        if ( ! is_singular( 'product' ) ) {
            $post = themsah_get_preview_product(); // phpcs:ignore
            setup_postdata( $post );
        }

        themsah_single_product_tabs_template( $this->get_settings_for_display() );

        if ( ! is_singular( 'product' ) ) {
            wp_reset_postdata();
        }
    }


	protected function _content_template() {
	}
}
