<?php

namespace ThemsahAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

class PRODUCTS extends Widget_Base
{


    public function get_name()
    {
        return 'products';
    }

    public function get_title()
    {
        return 'محصولات';
    }

    public function get_icon()
    {
        return 'eicon-products';
    }

    public function get_categories()
    {
        return ['themsah_cat'];
    }


    protected function _register_controls()
    {
        $this->register_general_post_grid_controls();
    }

    protected function register_general_post_grid_controls()
    {


        $this->start_controls_section(
            'section_post_grid',
            [
                'label' => __('کوئری', 'themsah')
            ]
        );

        $this->add_control(
            'category',
            [
                'label' => __('دسته بندی', 'themsah'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => true,
                'options' => themsah_post_type_product_cat(),
            ]
        );

        $this->add_control(
            'product_count',
            [
                'label' => __('تعداد پست ها', 'themsah'),
                'type' => Controls_Manager::NUMBER,
                'default' => '4'
            ]
        );

        $this->add_control(
            'product_order',
            [
                'label' => __('ترتیب', 'themsah'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => __('صعودی', 'themsah'),
                    'desc' => __('نزولی', 'themsah')
                ],
                'default' => 'desc',
                'label_block' => true,


            ]
        );

        $this->add_control(
            'order_by',
            [
                'label' => __('مرتب سازی بر اساس', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'menu_order',
                'label_block' => true,
                'options' => [
                    'date' => __('تاریخ', 'themsah'),
                    'id' => __('شناسه محصول', 'themsah'),
                    'menu_order' => __('پیش فرض', 'themsah'),
                    'popularity' => __('محبوبیت', 'themsah'),
                    'rand' => __('تصادفی', 'themsah'),
                    'rating' => __('امتیاز', 'themsah'),
                    'title' => __('نام', 'themsah'),
                ],
            ]
        );

        $this->add_control(
            'text-button',
            [
                'label' => esc_html__('متن دکمه', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('', 'themsah'),
                'placeholder' => esc_html__('', 'themsah'),
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'str_product',
            [
                'label' => __('ساختار', 'themsah')
            ]
        );

        $this->add_control(
            'column_count',
            [
                'label' => __('تعداد ستون', 'themsah'),
                'type' => Controls_Manager::NUMBER,
                'default' => '4'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'box_sections',
            [
                'label' => __('تنظیمات باکس محصول', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' => __('پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __('سایه باکس', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li',
            ]
        );


        $this->add_responsive_control(
            'box-border-radius',
            [
                'label' => esc_html__('گردی گوشه ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'background_color_hover',
            [
                'label' => __('پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_hover',
                'label' => __('سایه باکس', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li:hover',
            ]
        );

        $this->add_responsive_control(
            'box-border-radius-hover',
            [
                'label' => esc_html__('گردی گوشه ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'box-border-hover',
                'label' => esc_html__('حاشیه', 'themsah'),
                'selector' => '{{WRAPPER}} ul.products li:hover',
            ]
        );

        $this->add_responsive_control(
            'hover-top-value',
            [
                'label' => __('مقدار پرش به بالا', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li:hover' => 'transform: translateY(-{{SIZE}}{{UNIT}});',
                    '{{WRAPPER}} ul.products li' => 'margin-top: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'image-style',
            [
                'label' => __('تصویر', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'badge_heading',
            [
                'label' => esc_html__('بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'badge-typography',
                'label' => __('تایپوگرافی', 'themsah'),
                
                'selector' => '{{WRAPPER}} ul.products li.product .onsale',
            ]
        );

        $this->add_control(
            'bag-bac',
            [
                'label' => __('رنگ پس زمینه بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'background: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'bag-color',
            [
                'label' => __('رنگ متن بج تخفیف', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_responsive_control(
            'onsale-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product .onsale' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'box-content-style',
            [
                'label' => __('تنظیمات محتوای باکس', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_heading',
            [
                'label' => esc_html__('عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('رنگ', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product h3' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'title-color-hover',
            [
                'label' => __('رنگ هاور', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product:hover h2' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title-typography',
                'label' => __('تایپوگرافی عنوان مطلب', 'themsah'),
                
                'selector' => '{{WRAPPER}} ul.products li.product .woocommerce-loop-product__title, {{WRAPPER}} ul.products li.product .woocommerce-loop-product__title, {{WRAPPER}} ul.products li.product h3',
            ]
        );

        $this->add_control(
            'price_heading',
            [
                'label' => esc_html__('قیمت', 'themsah'),
                'type' => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'price-typography',
                'label' => __('تایپوگرافی', 'themsah'),
                
                'selector' => '{{WRAPPER}} .price',
            ]
        );


        $this->add_control(
            'price-color',
            [
                'label' => __('رنگ', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'btn_section',
            [
                'label' => __('دکمه', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'label' => __('تایپوگرافی', 'themsah'),
                
                'selector' => '{{WRAPPER}} ul.products li.product a.button',
            ]
        );


        $this->add_responsive_control(
            'btn-width',
            [
                'label' => esc_html__('نوع باکس', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '100%',
                'options' => [
                    'max-content' => esc_html__('در متن', 'themsah'),
                    '100%' => esc_html__('تمام عرض', 'themsah'),
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'width: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_responsive_control(
            'btn-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-padding',
            [
                'label' => __('فاصله داخلی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-space',
            [
                'label' => __('فاصله', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->start_controls_tabs('box-btn');
        $this->start_controls_tab(
            'normal-btn',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-color-button',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} ul.products li.product a.button',
            ]
        );

        $this->add_control(
            'text-color-button',
            [
                'label' => esc_html__('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product a.button' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-btn',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-hover-color-button',
                'label' => esc_html__('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} ul.products li.product:hover a.button',

            ]
        );

        $this->add_control(
            'text-hover-color-button',
            [
                'label' => esc_html__('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} ul.products li.product:hover a.button' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings();
        ?>

        <style>
            .product .add_to_cart_button i::after {
                content: 'خرید کالا';
                font-family: var(--fontfamily);
                font-size: 15px;
                margin-right: 5px;
            }


        </style>
        <?php

        $product_count = $settings['product_count'];
        $product_order = $settings['product_order'];
        $cat = $settings['category'];
        $order_by = $settings['order_by'];
        $column_count = $settings['column_count'];
        if ($settings['category']) {
            $implode = implode(', ', $cat);
        } else {
            $implode = '';
        };

        echo do_shortcode('[products orderby="' . $order_by . '" limit="' . $product_count . '" order="' . $product_order . '" category="' . $implode . '" columns="' . $column_count . '"]');


    }

    protected function _content_template()
    {


    }
}
