<?php

namespace ThemsahAddons\Widgets;

use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Related_Portfolio extends Widget_Base {

	public function get_name() {
		return 'related-portfolio';
	}

	public function get_title() {
		return __( 'نمونه کارهای مرتبط', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-gallery-justified';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);
		$this->add_control(
			'default-image',
			[
				'label'   => __( 'تصویر شاخص پیشفرض', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'post_per',
			[
				'label'   => __( 'تعداد پست در برگه', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 1,
				'max'     => 20,
				'step'    => 1,
				'default' => 4,
			]
		);

		$this->add_control(
			'count_in_line',
			[
				'label'   => __( 'تعداد در هر ردیف', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '4',
				'options' => [
					'4' => __( '3', 'themsah' ),
					'3' => __( '4', 'themsah' ),

				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'تنظیمات باکس', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'box-border-radius',
			[
				'label'      => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .project-box'          => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .project-box .overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'box_shadow',
				'label'    => __( 'سایه باکس', 'plugin-domain' ),
				'selector' => '{{WRAPPER}} .project-box',
			]
		);

		$this->add_responsive_control(
			'box-height',
			[
				'label'      => __( 'ارتفاع باکس', 'plugin-domain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 1000,
						'step' => 5,
					],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 300,
				],
				'selectors'  => [
					'{{WRAPPER}} .project-box' => 'height: {{SIZE}}{{UNIT}};',
				],
				'separator'  => 'after'
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'     => 'cover-background',
				'label'    => __( 'پس زمینه روکش باکس', 'plugin-domain' ),
				'types'    => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .project-box .overlay .background',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box h3' => 'color: {{VALUE}}',
				],
				'separator' => 'before'
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title-typography',
				'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .project-box h3',
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'     => __( 'رنگ آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box .overlay i' => 'color: {{VALUE}}',
				],
				'separator' => 'before'

			]
		);

		$this->add_control(
			'icon_color_bac',
			[
				'label'     => __( 'رنگ پس زمنیه آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-box .overlay i' => 'background: {{VALUE}}',
				],
			]
		);


		$this->end_controls_section();


	}


	protected function render() {
		$settings = $this->get_settings_for_display();

		$post_per = $settings['post_per'];
		global $post;
		$terms        = get_the_terms( $post->ID, 'portfolio_cat' );
		$term_ids     = wp_list_pluck( $terms, 'term_id' );
		$second_query = new \WP_Query( array(
			'post_type'           => 'portfolio',
			'tax_query'           => array(
				array(
					'taxonomy' => 'portfolio_cat',
					'field'    => 'id',
					'terms'    => $term_ids,
					'operator' => 'IN' //Or 'AND' or 'NOT IN'
				)
			),
			'posts_per_page'      => $post_per,
			'ignore_sticky_posts' => 1,
			'orderby'             => 'date',
			'post__not_in'        => array( $post->ID )
		) );

		if ( $second_query->have_posts() ) { ?>
            <div class="row">
				<?php while ( $second_query->have_posts() ) : $second_query->the_post(); ?>
                    <div class="col-lg-<?php echo $settings['count_in_line']; ?> col-sm-6 col-12">
                        <a href="<?php the_permalink(); ?>" class="project-box">
                            <img src="<?php if ( has_post_thumbnail() ) {
								the_post_thumbnail_url( 'portfolio_box' );
							} else {
								echo $settings['default-image']['url'];
							} ?>" width="282" height="292" alt="">
                            <div class="overlay">
                                <div class="background"></div>
                                <i class="fas fa-link" aria-hidden="true"></i>
                            </div>
                            <h3><?php the_title(); ?></h3>
                        </a>
                    </div>
				<?php endwhile;
				wp_reset_query() ?>
            </div>
		<?php }else {
		    echo esc_html__('Not found','themsah');
        }
	}

	protected function _content_template() {
	}
}
