<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;


if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly


class Search extends Widget_Base
{

    public function get_name()
    {
        return 'search';
    }

    public function get_title()
    {
        return __('باکس سرچ', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-site-search';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_icon',
            [
                'label' => __('محتوا', 'text-domain'),
            ]
        );

        $this->add_control(
            'search_type',
            [
                'label' => __('نوع سرچ', 'themsah'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon-modal',
                'options' => [
                    'icon-modal' => __('آیکن + مودال', 'themsah'),
                    'open' => __('کادر باز', 'themsah'),
                ],
            ]
        );

        $this->add_control(
            'icon',
            [
                'label' => __('آیکن تاگل', 'text-domain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-search',
                    'library' => 'solid',
                ],
                'condition' => [
                    'search_type' => 'icon-modal'
                ]
            ]
        );

        $this->add_control(
            'search-placeholder',
            [
                'label' => __('متن نگهدارنده', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('جستجو کنید', 'themsah'),
            ]
        );

        $this->add_control(
            'show-list',
            [
                'label' => __('نمایش لیست پست تایپ ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'themsah'),
                'label_off' => __('مخفی', 'themsah'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show-cat-list',
            [
                'label' => __('نمایش لیست دسته ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'themsah'),
                'label_off' => __('مخفی', 'themsah'),
                'return_value' => 'yes',
                'default' => '',
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'search-in',
            [
                'label' => __('جستجو در', 'themsah'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'post' => [
                        'title' => __('مقالات', 'themsah'),
                    ],
                    'portfolio' => [
                        'title' => __('نمونه کارها', 'themsah'),
                    ],
                    'product' => [
                        'title' => __('محصولات', 'themsah'),
                    ],
                ],
                'default' => 'post',
                'toggle' => false,
                'condition' => [
                    'show-list' => ''
                ]
            ]
        );

        $this->add_control(
            'search-list-article',
            [
                'label' => __('عنوان مقالات در لیست بازشونده', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('مقالات', 'themsah'),
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'search-list-portfolio',
            [
                'label' => __('عنوان نمونه کارها در لیست بازشونده', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('نمونه کارها', 'themsah'),
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]

        );


        $this->add_control(
            'search-list-products',
            [
                'label' => __('عنوان محصولات در لیست بازشونده', 'themsah'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('محصولات', 'themsah'),
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('آیکن تاگل', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'search_type' => 'icon-modal'
                ]
            ]
        );
        $this->start_controls_tabs('toggle-icon');
        $this->start_controls_tab('normal-toggle-icon', ['label' => __('عادی', 'themsah')]);

        $this->add_control(
            'toggle-icon-color',
            [
                'label' => __('رنگ آیکن تاگل', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .search-icon i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .search-icon svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'toggle-icon-bac',
            [
                'label' => __('رنگ پس زمینه آیکن تاگل', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .search-icon' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab('hover-toggle-icon', ['label' => __('هاور', 'themsah')]);

        $this->add_control(
            'toggle-icon-hover-color',
            [
                'label' => __('رنگ آیکن تاگل', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .search-icon:hover i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .search-icon:hover svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'toggle-icon-hover-bac',
            [
                'label' => __('رنگ پس زمینه آیکن تاگل', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .search-icon:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_responsive_control(
            'toogle-icon-size',
            [
                'label' => __('سایز آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .search-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .search-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'toogle-icon-dimensions',
            [
                'label' => __('ابعاد آیکن', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 80,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 45,
                ],
                'selectors' => [
                    '{{WRAPPER}} .search-icon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border-radius-toogle-icon',
            [
                'label' => __('گردی لبه های آیکن', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .search-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin-search-icon',
            [
                'label' => __('فاصله آیکن', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .search-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_content1',
            [
                'label' => __('تنظیمات باکس سرچ', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'form-box-border-color',
            [
                'label' => __('رنگ کادر', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form input' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .site-search-form select' => 'border-color: {{VALUE}} !important',
                    '{{WRAPPER}} .site-search-form > ul' => 'border-color: {{VALUE}}',
                ],
            ]
        );


        $this->add_control(
            'input-text-color',
            [
                'label' => __('رنگ متن ورودی', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form input' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'input-bac-color',
            [
                'label' => __('رنگ پس زمینه ورودی متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form input' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'input-typography',
                'label' => __('تایپوگرافی متن ورودی', 'themsah'),
                
                'selector' => '{{WRAPPER}} .site-search-form input',
            ]
        );
        $this->add_control(
            'search-border-radius',
            [
                'label' => __(' گردی گوشه ها ورودی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .site-search-form input ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_content5',
            [
                'label' => __('لیست ها', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'select-border-radius',
            [
                'label' => __('گردی گوشه های لیست پست تایپ', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .select-post-type-for-search ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'select-term-border-radius',
            [
                'label' => __('گردی گوشه های لیست دسته بندی', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .select-term ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'list-text-color',
            [
                'label' => __('رنگ متن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form select' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'list-bac-color',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form select' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'list-typography',
                'label' => __('تایپوگرافی', 'themsah'),
                
                'selector' => '{{WRAPPER}} .site-search-form select',
                'condition' => [
                    'show-list' => 'yes'
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_content3',
            [
                'label' => __('آیکن جستجو', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'button-border-radius',
            [
                'label' => __('گردی گوشه ها دکمه', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .site-search-form button  ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('search-icon');
        $this->start_controls_tab('normal-search-icon', ['label' => __('عادی', 'themsah')]);

        $this->add_control(
            'search-icon-color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form button i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .site-search-form button .spinner-border' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search-icon-bac',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab('hover-search-icon', ['label' => __('هاور', 'themsah')]);

        $this->add_control(
            'search-icon-hover-color',
            [
                'label' => __('رنگ آیکن', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form button:hover i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .site-search-form button:hover .spinner-border' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search-icon-hover-back',
            [
                'label' => __('رنگ پس زمینه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form button:hover' => 'background: {{VALUE}} !important',
                ],
            ]
        );


        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->end_controls_section();

        $this->start_controls_section(
            'section_content4',
            [
                'label' => __('تنظیمات باکس نتایج جستجو', 'themsah'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'result-background',
                'label' => __('پس زمینه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .site-search-form > ul',
                'separator' => 'after',
            ]
        );

        $this->add_responsive_control(
            'box-border-radius',
            [
                'label' => __('گردی گوشه ها', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'search-item-bac-color',
            [
                'label' => __('رنگ هاور پس زمینه آیتم ها', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult li:not(.more-result):not(.not-result):hover ' => 'background-color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_responsive_control(
            'image-size',
            [
                'label' => __('سایز تصویر', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 30,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 70,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult a img' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'image-border-radius',
            [
                'label' => __('گردی گوشه های تصویر', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult a img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'image-spacing',
            [
                'label' => __('فاسله تصویر', 'themsah'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 15,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult a img' => 'margin-inline-end:{{SIZE}}{{UNIT}};',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_post_typography',
                'label' => __('تایپوگرافی عنوان', 'themsah'),
                
                'selector' => '{{WRAPPER}} .ajaxsearchresult a h3',
            ]
        );

        $this->add_control(
            'search-title-color',
            [
                'label' => __('رنگ عنوان', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .ajaxsearchresult a h3' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'more-result-color',
            [
                'label' => __('رنگ متن دکمه', 'themsah'),
                'type' => \Elementor\Controls_Manager::COLOR,
                
                'selectors' => [
                    '{{WRAPPER}} .site-search-form.product > ul li:last-child a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'more-result-background',
                'label' => __('پس زمینه دکمه', 'themsah'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .site-search-form.product > ul li:last-child a',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'more-result-typography',
                'label' => __('تایپوگرافی دکمه', 'themsah'),
                
                'selector' => '{{WRAPPER}} .site-search-form.product > ul li:last-child a',
            ]
        );

        $this->add_responsive_control(
            'more-result-border-radius',
            [
                'label' => __('گردی گوشه های دکمه', 'themsah'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .site-search-form.product > ul li:last-child a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['search_type'] == 'icon-modal') { ?>
            <div class="search-icon" data-toggle="modal" data-target="#searchmodal">
                <?php \Elementor\Icons_Manager::render_icon($settings['icon'], ['aria-hidden' => 'true']); ?>
            </div>
            <div class="modal fade" id="searchmodal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
            <div class="modal-dialog" role="document">
            <div class="modal-content">
        <?php } ?>
        <form class="site-search-form <?php if (class_exists('WooCommerce') && 'yes' == $settings['show-list']) {
            echo 'product';
        } else {
            echo $settings['search-in'];
        } ?>" action="<?php echo home_url('/');
        if (function_exists('pll_the_languages') && pll_default_language() != pll_current_language()) {
            echo pll_current_language() . '/';
        } ?>" method="get">
            <?php if ('yes' == $settings['show-list']) { ?>
                <select name="post_type" class="select-post-type-for-search" id="select-post-type-for-search">
                    <?php if (class_exists('WooCommerce')) { ?>
                        <option value="product" <?php if (is_search() && get_post_type() == 'product') {
                            echo 'selected';
                        } ?>><?php echo $settings['search-list-products']; ?></option>
                    <?php } ?>
                    <option value="post" <?php if (is_search() && get_post_type() == 'post') {
                        echo 'selected';
                    } ?>><?php echo $settings['search-list-article']; ?></option>
                    <option value="portfolio" <?php if (is_search() && get_post_type() == 'portfolio') {
                        echo 'selected';
                    } ?>><?php echo $settings['search-list-portfolio']; ?></option>
                </select>
            <?php } else { ?>
                <input type="hidden" name="post_type" value="<?= $settings['search-in']; ?>">
            <?php }

            if ($settings['show-cat-list'] == 'yes' && $settings['show-list'] == 'yes') { ?>
                <div class="select-type">
                    <?php if (class_exists('WooCommerce')) {
                        $taxonomy = 'product_cat';
                    } else {
                        $taxonomy = 'post';
                    }
                    if (is_search() && is_shop() || is_singular('product')) {
                        $taxonomy = 'product_cat';
                    } elseif (is_search() && get_post_type() == 'post') {
                        $taxonomy = 'category';
                    } elseif (is_search() && get_post_type() == 'portfolio') {
                        $taxonomy = 'portfolio_cat';
                    } ?>
                    <select name="<?= $taxonomy; ?>" class="select-term" data-gateway_id="">
                        <option value="" data-gateway_id=""><?= esc_html__('Select category') ?></option>
                        <?php $terms = get_terms(array(
                            'taxonomy' => $taxonomy,
                            'hide_empty' => true,
                        ));
                        if (!empty($terms) && !is_wp_error($terms)) {
                            foreach ($terms as $term) { ?>
                                <option <?php if (get_queried_object()->term_id == $term->term_id) {
                                    echo 'selected';
                                } ?> data-gateway_id="<?= $term->term_id; ?>"
                                     value="<?= $term->slug; ?>"><?= $term->name; ?></option>
                            <?php }
                        } ?>
                    </select>
                </div>
            <?php } ?>

            <input type="text" name="s" value="<?php the_search_query(); ?>"
                   placeholder="<?php echo $settings['search-placeholder']; ?>">
            <button type="submit" name="button"><i class="fas fa-search" aria-hidden="true"></i></button>

            <ul class="search-results text-center ajaxsearchresult"></ul>
        </form>
        <?php if ($settings['search_type'] == 'icon-modal') { ?>
        </div>
        </div>
        </div>
    <?php }
    }


    protected function _content_template()
    {
    }
}
