<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Service extends Widget_Base {

	public function get_name() {
		return 'service';
	}

	public function get_title() {
		return __( 'باکس خدمات', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-gallery-grid';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {


		$this->start_controls_section(
			'item_section',
			[
				'label' => __( 'تنظیمات باکس', 'themsah' ),
			]
		);

        $this->add_control(
            'select-box',
            [
                'label' => esc_html__( 'نوع باکس', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'type-1',
                'options' => [
                    'type-1'  => esc_html__( 'نوع اول', 'themsah' ),
                    'type-2' => esc_html__( 'نوع دوم', 'themsah' ),

                ],
            ]
        );

        $this->add_responsive_control(
            'column-count',
            [
                'label' => __( 'تعداد ستون', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'min' => 1,
                    'max' => 10,
                    'step' => 1,
                ],
                'default' => [
                    'size' => 3,
                ],
                'selectors' => [
                    '{{WRAPPER}} .thm-services .service-col' => 'width:calc(100% / {{SIZE}});',
                ],
            ]
        );

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'image',
			[
				'label' => __( 'تصویر', 'themsah' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'icon',
			[
				'label'   => __( 'آیکن', 'text-domain' ),
				'type'    => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value'   => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'list_title', [
				'label'       => __( 'عنوان', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'ساختمان سازی', 'themsah' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'list_content', [
				'label'      => __( 'توضیحات', 'themsah' ),
				'type'       => \Elementor\Controls_Manager::TEXTAREA,
				'default'    => __( 'توضحیات', 'themsah' ),
				'show_label' => false,
			]
		);

		$repeater->add_control(
			'btn-text', [
				'label'       => __( 'متن دکمه', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'بیشتر بخوانید', 'themsah' ),
				'label_block' => true,
			]
		);

        $repeater->add_control(
            'btn-icon',
            [
                'label' => esc_html__( 'آیکن دکمه', 'themsah' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-chevron-left',
                    'library' => 'solid',
                ],
            ]
        );

		$repeater->add_control(
			'btn-link',
			[
				'label' => __( 'لینک دکمه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'themsah' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],

			]
		);


		$this->add_control(
			'list',
			[
				'label'   => __( 'آیتم ها', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => [
					[
						'list_title'   => __( 'عنوان #1', 'themsah' ),
					],

				],
			]
		);


		$this->end_controls_section();

        $this->start_controls_section(
            'str_section',
            [
                'label' => __( 'ساختار', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'column-spacing',
            [
                'label' => __( 'فاسله بین ستون ها', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .thm-services .service-col' => 'padding-inline: calc({{SIZE}}{{UNIT}}/2);',
                    '{{WRAPPER}} .thm-services' => 'margin-inline: calc(-{{SIZE}}{{UNIT}}/2);',
                ],
            ]
        );

        $this->add_responsive_control(
            'row-spacing',
            [
                'label' => __( 'فاسله بین ردیف ها', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .thm-services .service-col' => 'padding-block: calc({{SIZE}}{{UNIT}}/2);',
                    '{{WRAPPER}} .thm-services' => 'margin-block: calc(-{{SIZE}}{{UNIT}}/2);',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'box_section',
            [
                'label' => __( 'تنظیمات باکس', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'align',
            [
                'label' => esc_html__( 'چینش افقی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'انتها', 'themsah' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'وسط', 'themsah' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'ابتدا', 'themsah' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .content' => 'text-align:{{VALUE}};',
                    '{{WRAPPER}} .service-box-2 .content .title' => 'text-align:{{VALUE}};',
                ],
            ]
        );

        $this->start_controls_tabs('box-tabs');
        $this->start_controls_tab(
            'normal-box',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_responsive_control(
            'box-border-radius',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .service-box-2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'box-padding',
            [
                'label' => __( 'فاصله داخلی', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                    '{{WRAPPER}} .service-box .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box,{{WRAPPER}} .service-box-2',
            ]
        );


        $this->add_responsive_control(
            'image-height',
            [
                'label' => __( 'ارتفاع تصویر', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 250,
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'=> [
                    'select-box' => 'type-1',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content-bac',
                'label' => esc_html__( 'پس زمینه محتوا', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box-2',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_2',
                'label' => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box-2,{{WRAPPER}} .service-box',
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-box',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_responsive_control(
            'box-border-radius-hover',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .service-box-2:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content-bac-hover',
                'label' => esc_html__( 'پس زمینه محتوا', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box .content , {{WRAPPER}} .service-box-2:hover',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-hover',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box:hover,{{WRAPPER}} .service-box-2:hover',
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_2_hover',
                'label' => __( 'سایه باکس', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box-2:hover,{{WRAPPER}} .service-box:hover',
            ]
        );


        $this->add_control(
            'content-b-color',
            [
                'label'     => __( 'رنگ خط بالا', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box:hover .content' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-1',
                ],
            ]
        );

        $this->add_responsive_control(
            'hover-top-value',
            [
                'label' => __( 'مقدار پرش به بالا', 'themsah' ),
                'type'  => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 15,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2:hover' => 'transform: translateY(-{{SIZE}}{{UNIT}});',
                ],
            ]
        );



        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();



		$this->start_controls_section(
			'icon_section',
			[
				'label' => __( 'آیکن', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs('icon-tabs');
        $this->start_controls_tab(
            'normal-icon',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );

        $this->add_control(
            'size-icon',
            [
                'label' => esc_html__( 'سایز آیکون', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .title i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-box .title i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-box-2 .title svg' => 'width: {{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-box .title svg' => 'width: {{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'box-size-icon',
            [
                'label' => esc_html__( 'ابعاد باکس آیکون', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 110,
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .title .icon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_responsive_control(
            'icon-border-radius',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .content .title .icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-icon',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box-2 .content .title .icon',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'bac-icon',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box-2 .content .title .icon',
            ]
        );

        $this->add_control(
            'shadow-icon',
            [
                'label' => esc_html__( 'سایه آیکون', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .content .title .icon' => ';box-shadow:0 0 20px 20px {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label'     => __( 'رنگ آیکون', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 .title i' => 'color: {{VALUE}}', '{{WRAPPER}} .service-box .title i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-box-2 .title svg path' => 'fill: {{VALUE}}', '{{WRAPPER}} .service-box .title svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-icon',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );

        $this->add_control(
            'icon_color_hover',
            [
                'label'     => __( 'رنگ آیکون', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box-2:hover .title i' => 'color: {{VALUE}}', '{{WRAPPER}} .service-box:hover .title i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-box-2:hover .title svg path' => 'fill: {{VALUE}}', '{{WRAPPER}} .service-box:hover .title svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'bac-hover-icon',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box-2:hover .content .title .icon',
            ]
        );

        $this->add_control(
            'shadow-hover-icon',
            [
                'label' => esc_html__( 'سایه آیکون', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box-2:hover .content .title .icon' => ';box-shadow:0 0 20px 20px {{VALUE}}',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon-border-radius-hover',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2:hover .content .title .icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border-icon-hover',
                'label' => esc_html__( 'حاشیه', 'themsah' ),
                'selector' => '{{WRAPPER}} .service-box-2:hover .content .title .icon',
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );


        $this->end_controls_tab();
        $this->end_controls_tabs();




        $this->end_controls_section();
        $this->start_controls_section(
            'texts_section',
            [
                'label' => __( 'متن ها', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
                
                'selector' =>  '{{WRAPPER}} .service-box-2 .title h3,{{WRAPPER}} .service-box .title h3',
            ]
        );
		
		$this->add_control(
			'title_color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .service-box .title h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-box-2 .title h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_color_hover',
			[
				'label'     => __( 'رنگ هاور عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,

				'selectors' => [
					'{{WRAPPER}} .service-box:hover .content .title h3' => 'color: {{VALUE}}',
					'{{WRAPPER}} .service-box-2:hover .content .title h3' => 'color: {{VALUE}}',
				],
			]
		);


        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'paragraph_typography',
                'label'    => __( 'تایپوگرافی توضیحات', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .service-box p , {{WRAPPER}} .service-box-2 p',
                'separator' => 'before'
            ]
        );

		$this->add_control(
			'paragraph_color',
			[
				'label'     => __( 'رنگ متن توضیحات', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-box p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-box-2 p' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
            'paragraph_hover_color',
            [
                'label'     => __( 'رنگ هاور متن توضیحات', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-box:hover p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-box-2:hover p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'btn_section',
            [
                'label' => __( 'دکمه', 'themsah' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'btn_typography',
                'label'    => __( 'تایپوگرافی', 'themsah' ),
                
                'selector' => '{{WRAPPER}} a.btn-service,{{WRAPPER}} a.btn-service',
            ]
        );


        $this->add_responsive_control(
            'btn-width',
            [
                'label' => esc_html__( 'نوع باکس', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '100%',
                'options' => [
                    'max-content'  => esc_html__( 'در متن', 'themsah' ),
                    '100%' => esc_html__( 'تمام عرض', 'themsah' ),
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 a.btn-service' => 'width: {{VALUE}} !important',
                ],
            ]
        );


        $this->add_responsive_control(
            'btn-border-radius',
            [
                'label' => __( 'گردی گوشه ها', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 a.btn-service' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-padding',
            [
                'label' => __( 'فاصله داخلی', 'themsah' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 a.btn-service' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn-space',
            [
                'label' => __( 'فاصله', 'themsah' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .service-box-2 a.btn-service' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'select-box' => 'type-2',
                ]
            ]
        );

        $this->start_controls_tabs('box-btn');
        $this->start_controls_tab(
            'normal-btn',
            [
                'label' => __('عادی', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-color-button',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box-2 a.btn-service',
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'text-color-button',
            [
                'label' => esc_html__( 'رنگ متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.btn-service' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover-btn',
            [
                'label' => __('هاور', 'themsah'),
            ]
        );


        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background-hover-color-button',
                'label' => esc_html__( 'پس زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .service-box-2:hover a.btn-service',
                'condition' => [
                    'select-box' => 'type-2',
                ],
            ]
        );

        $this->add_control(
            'text-hover-color-button',
            [
                'label' => esc_html__( 'رنگ متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.btn-service:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( $settings['list'] ) { ?>
            <div class="thm-services">
			<?php foreach ( $settings['list'] as $item ) { ?>
                <div class="service-col">
                    <?php if( $settings['select-box'] == 'type-1') { ?>
                    <div class="service-box">
                        <img src="<?php echo $item['image']['url']; ?>" alt="<?php echo $item['list_title']; ?>">
                        <div class="content">
                            <div class="title d-inline-flex align-items-center">
								<?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            <h3 class="m-0"><?php echo $item['list_title']; ?></h3>
                        </div>
                        <p><?php echo $item['list_content']; ?></p>
                            <?php if ($item['btn-text']){ ?>
                        <a class="btn-service" href="<?php echo $item['btn-link']['url']; ?>"><?php echo $item['btn-text']; ?>
                            <?php \Elementor\Icons_Manager::render_icon( $item['btn-icon'], [ 'aria-hidden' => 'true' ] ); ?>
                        </a>
                    <?php } ?>
                    </div>
                </div>
                    <?php } else { ?>
                    <div class="service-box-2">
                        <div class="content">
                            <div class="title">
                                <div class="icon">
                                    <?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                </div>
                                <h3><?php echo $item['list_title']; ?></h3>
                            </div>
                            <p><?php echo $item['list_content']; ?></p>
                            <?php if ($item['btn-text']){ ?>
                                <a class="btn-service" href="<?php echo $item['btn-link']['url']; ?>"><?php echo $item['btn-text']; ?>
                                    <?php \Elementor\Icons_Manager::render_icon( $item['btn-icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                </a>
                            <?php } ?>
                        </div>
                    </div>
                    <?php } ?>
                </div>

			<?php } ?>
            </div>
		<?php } ?>

	<?php }


	protected function _content_template() {
	}
}
