<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Share extends Widget_Base {

	public function get_name() {
		return 'share';
	}

	public function get_title() {
		return __( 'اشتراک گذاری', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-share';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);

		$this->add_control(
			'title_of_facebook',
			[
				'label'       => __( 'عنوان فیسبوک', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'فیسبوک', 'themsah' ),
			]
		);

		$this->add_control(
			'title_of_google-plus',
			[
				'label'       => __( 'عنوان گوگل پلاس', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'گوگل پلاس', 'themsah' ),
			]
		);

		$this->add_control(
			'title_of_linkedin',
			[
				'label'       => __( 'عنوان لینکدین', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'لینکدین', 'themsah' ),
			]
		);

		$this->add_control(
			'title_of_telegram',
			[
				'label'       => __( 'عنوان تلگرام', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'تلگرام', 'themsah' ),
			]
		);

		$this->add_control(
			'title_of_twitter',
			[
				'label'       => __( 'عنوان توئیتر', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'توئیتر', 'themsah' ),
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'style',
			[
				'label' => __( 'استایل', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'icon-color',
			[
				'label'     => __( 'رنگ آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a' => 'color: {{VALUE}} !important',
				],
			]
		);
		$this->add_control(
			'icon-color-hover',
			[
				'label'     => __( 'رنگ هاور آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a:hover' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'icon-bac',
			[
				'label'     => __( 'رنگ پس زمینه آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a' => 'background: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'icon-bac-hover',
			[
				'label'     => __( 'رنگ هاور پس زمینه آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a:hover' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'share-icon-size',
			[
				'label' => __( 'سایز آیکن', 'themsah' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
						'step' => 1,
					],

				],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .share-btn a' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'cart-share-dimensions',
			[
				'label' => __( 'ابعاد آیکن', 'themsah' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 30,
						'max' => 80,
						'step' => 1,
					],

				],
				'default' => [
					'unit' => 'px',
					'size' => 45,
				],
				'selectors' => [
					'{{WRAPPER}} .share-btn a' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'border-radius-share-icon',
			[
				'label' => __( 'گردی لبه های آیکن', 'themsah' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .share-btn a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin-share-icon',
			[
				'label' => __( 'فاصله آیکن', 'themsah' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],

				],
				'default' => [
					'unit' => 'px',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} .share-btn a:not(:firs-child)' => 'margin-inline-start: {{SIZE}}{{UNIT}} !important;',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'tooltip-style',
			[
				'label' => __( 'استایل تولتیپ', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);
		$this->add_control(
			'name_color',
			[
				'label'     => __( 'رنگ متن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a span.site-tooltip' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_control(
			'name_bac',
			[
				'label'     => __( 'رنگ پس زمینه', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .share-btn a span.site-tooltip' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .share-btn a span.site-tooltip::before' => 'border-top-color: {{VALUE}} !important',
				],
			]
		);


		$this->end_controls_section();
	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>
        <div class="share-btn">
            <a class="fab fa-facebook" title="<?php echo $settings['title_of_facebook']; ?>" onclick="popup = window.open('http://www.facebook.com/sharer.php?u=<?php the_permalink(); ?>;t=<?php the_title(); ?>', 'PopupPage', 'height=450,width=500,scrollbars=yes,resizable=yes'); return false"></a>
            <a class="fab fa-google-plus" title="<?php echo $settings['title_of_google-plus']; ?>" onclick="popup = window.open('https://plus.google.com/share?url=<?php the_permalink(); ?>;title=<?php the_title(); ?>', 'PopupPage', 'height=450,width=500,scrollbars=yes,resizable=yes'); return false"></a>
            <a class="fab fa-linkedin" title="<?php echo $settings['title_of_linkedin']; ?>" onclick="popup = window.open('http://linkedin.com/shareArticle?mini=true&amp;url=<?php the_permalink(); ?>;title=<?php the_title(); ?>', 'PopupPage', 'height=450,width=500,scrollbars=yes,resizable=yes'); return false"></a>
            <a class="fab fa-telegram" title="<?php echo $settings['title_of_telegram']; ?>" onclick="popup = window.open('tg://msg?text=<?php the_permalink(); ?>', 'PopupPage', 'height=450,width=500,scrollbars=yes,resizable=yes'); return false"></a>
            <a class="fab fa-twitter" title="<?php echo $settings['title_of_twitter']; ?>" onclick="popup = window.open('http://twitter.com/home?status=<?php the_permalink(); ?>', 'PopupPage', 'height=450,width=500,scrollbars=yes,resizable=yes'); return false"></a>
        </div>
	<?php }


	protected function _content_template() {
	}
}
