<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Skill_Bar extends Widget_Base {

	public function get_name() {
		return 'skill-bar';
	}

	public function get_title() {
		return __( 'نوار پیشرف مهارت', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-skill-bar';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);


		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'show_title',
			[
				'label'        => __( 'نمایش عنوان', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'نمایش', 'themsah' ),
				'label_off'    => __( 'مخفی', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$repeater->add_control(
			'list_title', [
				'label'       => __( 'عنوان', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'راه حل های کسب و کار', 'themsah' ),
				'label_block' => true,
				'condition'   => [
					'show_title' => 'yes'
				]
			]
		);

		$repeater->add_control(
			'show_percent',
			[
				'label'        => __( 'نمایش درصد', 'themsah' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'نمایش', 'themsah' ),
				'label_off'    => __( 'مخفی', 'themsah' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$repeater->add_control(
			'percent', [
				'label'       => __( 'درصد', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::NUMBER,
				'default'     => __( '40', 'themsah' ),
				'label_block' => false,
			]
		);


		$this->add_control(
			'progress-list',
			[
				'label'   => __( 'آیتم ها', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __( 'راه حل های کسب و کار', 'themsah' ),
					],
					[
						'list_title' => __( 'راه حل های کسب و کار', 'themsah' ),
					],
				],

			]
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'استایل', 'themsah' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'item-spacing',
			[
				'label' => __('فاصله آیتم ها', 'themsah'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 20,
						'max' => 70,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .site-progress-bar' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_control(
			'text-color',
			[
				'label'     => __( 'رنگ متن ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .percent' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .title' => 'color: {{VALUE}} !important'
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'text_typography',
				'label'    => __( 'تایپوگرافی متن ها', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .d-flex.justify-content-between span',
			]
		);

		$this->add_control(
			'progress-bar-bar',
			[
				'label'     => __( 'رنگ پس زمینه آیتم ها', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default' => '#f6f6f6',
				'selectors' => [
					'{{WRAPPER}} .animated-progress' => 'background: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'skill-bar-bac',
				'label' => __('پس زمینه نوار پیشرفت', 'plugin-domain'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .progress-blue span',
			]
		);

		$this->add_responsive_control(
			'skill_bar_border_radius',
			[
				'label' => __('گردی لبه ها', 'plugin-domain'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .animated-progress' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( $settings['progress-list'] ) {
			foreach ( $settings['progress-list'] as $item ) { ?>
                <div class="site-progress-bar">
					<?php if ( 'yes' == $item['show_percent'] || 'yes' == $item['show_title'] ) { ?>
                        <div class="d-flex justify-content-between mb-1 mt-3 align-items-center">
                            <span class="title"><?php if ( 'yes' == $item['show_title'] ) {
									echo $item['list_title'];
								} ?></span>
							<?php if ( 'yes' == $item['show_percent'] ) { ?>
                                <span class="percent"></span>
							<?php } ?>
                        </div>
					<?php } ?>
                    <div class="animated-progress progress-blue">
                        <span data-progress="<?php echo $item['percent']; ?>"></span>
                    </div>
                </div>
			<?php }
		}
	}


	protected function _content_template() {
	}
}
