<?php
namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Scheme_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
class Themsah_slider_widget extends Widget_Base{

	public function get_name(){
		return 'themsahslider';
	}

	public function get_title(){
		return __( 'اسلایدر', 'themsah' );
	}

	public function get_icon() {
		return 'eicon-slider-device';
	}

	public function get_categories() {
		return [ 'themsah_cat' ];
	}
	public function get_keywords() {
		return [ 'slides', 'carousel', 'image', 'title', 'slider' ];
	}

	public static function get_button_sizes() {
		return [
			'xs' => __( 'خیلی کوچک', 'themsah' ),
			'sm' => __( 'کوچک', 'themsah' ),
			'md' => __( 'متوسط', 'themsah' ),
			'lg' => __( 'بزرگ', 'themsah' ),
			'xl' => __( 'خیلی بزرگ', 'themsah' ),
		];
	}

	protected function _register_controls() {
		$this->register_general_slide_controls();
		$this->register_general_slide_setting_controls();
		$this->register_general_slide_style_controls();
		$this->register_general_slide_title_style_controls();
		$this->register_general_slide_description_style_controls();
		$this->register_general_slide_button_style_controls();
		$this->register_general_slide_navigation_style_controls();
	}

	protected function register_general_slide_controls() {
		$this->start_controls_section(
			'section_slides',
			[
				'label' => __( 'اسلایدها', 'themsah' ),
			]
		);
        $this->add_control(
            'select-box',
            [
                'label' => esc_html__( 'نوع اسلایدر', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''  => esc_html__( 'نوع اول', 'plugin-name' ),
                    'type-2' => esc_html__( 'نوع دوم', 'plugin-name' ),

                ],
            ]
        );


        $repeater = new \Elementor\Repeater();
		$repeater->start_controls_tabs( 'slides_repeater' );
		$repeater->start_controls_tab( 'background', [ 'label' => __( 'پس زمینه', 'themsah' ) ] );

		$repeater->add_control(
			'background_color',
			[
				'label' => __( 'رنگ', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#bbbbbb',
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'background-color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'background_image',
			[
				'label' => _x( 'تصویر', 'Background Control', 'themsah' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'background-image: url({{URL}})',
				],
			]
		);
		$repeater->add_control(
			'background_size',
			[
				'label' => _x( 'اندازه', 'Background Control', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'cover',
				'options' => [
					'cover' => _x( 'پوشش', 'Background Control', 'themsah' ),
					'contain' => _x( 'کامل', 'Background Control', 'themsah' ),
					'auto' => _x( 'خودکار', 'Background Control', 'themsah' ),
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'background-size: {{VALUE}}',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_image[url]',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'animation_bg',
			[
				'label' => __( 'انیمیشن پس زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => '',
				'separator' => 'before',
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_image[url]',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'animation_bg_style',
			[
				'label' => __( 'نوع انیمیشن پس زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::ANIMATION,
				'default' => 'bounceIn',
				'conditions' => [
					'terms' => [
						[
							'name' => 'animation_bg',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'animation_bg_speed',
			[
				'label' => __( 'سرعت انیمیشن پس زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 's' ],
				'range' => [
					's' => [
						'min' => 0,
						'max' => 5,
						'step' => 0.5,
					],
				],
				'default' => [
					'unit' => 's',
					'size' => 2,
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'animation_bg',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .animation-bg' => '-webkit-animation-duration: {{SIZE}}{{UNIT}}; animation-duration: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$repeater->add_control(
			'animation_text',
			[
				'label' => __( 'انیمیشن متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => '',
				'separator' => 'before',
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_image[url]',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'animation_text_style',
			[
				'label' => __( 'نوع انیمیشن متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::ANIMATION,
				'default' => 'bounceIn',
				'conditions' => [
					'terms' => [
						[
							'name' => 'animation_text',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'background_overlay',
			[
				'label' => __( 'پوشش پس زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => '',
				'separator' => 'before',
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_image[url]',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'background_overlay_color',
			[
				'label' => __( 'رنگ', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => 'rgba(0,0,0,0.5)',
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_overlay',
							'value' => 'yes',
						],
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-background-overlay' => 'background-color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'background_overlay_blend_mode',
			[
				'label' => __( 'نوع رنگ', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'' => __( 'Normal', 'themsah' ),
					'multiply' => 'Multiply',
					'screen' => 'Screen',
					'overlay' => 'پوشش',
					'darken' => 'تیره',
					'lighten' => 'روشن',
					'color-dodge' => 'Color Dodge',
					'color-burn' => 'سوختگی رنگ',
					'hue' => 'Hue',
					'saturation' => 'Saturation',
					'color' => 'رنگ',
					'exclusion' => 'Exclusion',
					'luminosity' => 'Luminosity',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'background_overlay',
							'value' => 'yes',
						],
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-background-overlay' => 'mix-blend-mode: {{VALUE}}',
				],
			]
		);
		$repeater->end_controls_tab();
		$repeater->start_controls_tab( 'content', [ 'label' => __( 'محتوا', 'themsah' ) ] );

        $repeater->add_control(
            'top_heading',
            [
                'label' => __( 'بالای عنوان', 'themsah' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'عنوان اسلاید', 'themsah' ),
                'label_block' => true,
               
            ]
        );

		$repeater->add_control(
			'heading',
			[
				'label' => __( 'عنوان و توضیحات', 'themsah' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'عنوان اسلاید', 'themsah' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'description',
			[
				'label' => __( 'توضیحات', 'themsah' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'توضیحات اسلایدر', 'themsah' ),
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'button_text',
			[
				'label' => __( 'متن دکمه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'کلیک کنید', 'themsah' ),
			]
		);
		$repeater->add_control(
			'link',
			[
				'label' => __( 'لینک', 'themsah' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'themsah' ),
			]
		);
		$repeater->add_control(
			'link_click',
			[
				'label' => __( 'فعال کردن لینک', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'slide' => __( 'Whole Slide', 'themsah' ),
					'button' => __( 'Button Only', 'themsah' ),
				],
				'default' => 'slide',
				'conditions' => [
					'terms' => [
						[
							'name' => 'link[url]',
							'operator' => '!=',
							'value' => '',
						],
					],
				],
			]
		);
		$repeater->end_controls_tab();
		$repeater->start_controls_tab( 'style', [ 'label' => __( 'استایل', 'themsah' ) ] );
		$repeater->add_control(
			'custom_style',
			[
				'label' => __( 'سفارشی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'description' => __( 'استایل دلخواه تنظیم کنید', 'themsah' ),
			]
		);
		$repeater->add_control(
			'horizontal_position',
			[
				'label' => __( 'موقعیت افقی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'options' => [
					'left' => [
						'title' => __( 'چپ', 'themsah' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'راست', 'themsah' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-slide-content' => '{{VALUE}}',
				],
				'selectors_dictionary' => [
					'left' => 'margin-right: auto',
					'center' => 'margin: 0 auto',
					'right' => 'margin-left: auto',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'vertical_position',
			[
				'label' => __( 'جهت عمودی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'options' => [
					'top' => [
						'title' => __( 'بالا', 'themsah' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => __( 'پایین', 'themsah' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner' => 'align-items: {{VALUE}}',
				],
				'selectors_dictionary' => [
					'top' => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'text_align',
			[
				'label' => __( 'ترازبندی متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'options' => [
					'left' => [
						'title' => __( 'چپ', 'themsah' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'راست', 'themsah' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner' => 'text-align: {{VALUE}}',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'content_color',
			[
				'label' => __( 'رنگ محتوا', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-slide-heading' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-slide-description' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner .elementor-slide-button' => 'color: {{VALUE}}; border-color: {{VALUE}}',
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->end_controls_tab();
		$repeater->end_controls_tabs();

		$this->add_control(
			'slides',
			[
				'label' => __( 'اسلایدها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'show_label' => true,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'heading' => __( 'عنوان اسلاید 1', 'themsah' ),
						'description' => __( '', 'themsah' ),
						'button_text' => __( 'کلیک کنید', 'themsah' ),
						'background_color' => '#833ca3',
					],
					[
						'heading' => __( 'عنوان اسلاید 2', 'themsah' ),
						'description' => __( '', 'themsah' ),
						'button_text' => __( 'کلیک کنید', 'themsah' ),
						'background_color' => '#4054b2',
					],
					[
						'heading' => __( 'عنوان اسلاید 3', 'themsah' ),
						'description' => __( '', 'themsah' ),
						'button_text' => __( 'کلیک کنید', 'themsah' ),
						'background_color' => '#1abc9c',
					],
				],
				'title_field' => '{{{ heading }}}',
			]
		);
		$this->add_responsive_control(
			'slides_height',
			[
				'label' => __( 'ارتفاع', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 1000,
					],
					'vh' => [
						'min' => 10,
						'max' => 100,
					],
				],
				'default' => [
					'size' => 400,
				],
				'size_units' => [ 'px', 'vh', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .slick-slide' => 'height: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->end_controls_section();
	}
	protected function register_general_slide_setting_controls() {
		$this->start_controls_section(
			'section_slider_options',
			[
				'label' => __( 'گرینه های اسلاید', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SECTION,
			]
		);
		$this->add_control(
			'navigation',
			[
				'label' => __( 'ناوبری', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'both',
				'options' => [
					'both' => __( 'پیکان و نقطه ها', 'themsah' ),
					'arrows' => __( 'پیکان ها', 'themsah' ),
					'dots' => __( 'نقطه ها', 'themsah' ),
					'none' => __( 'هیچکدام', 'themsah' ),
				],
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label' => __( 'متوقف شدن هنگام هاور', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'autoplay',
			[
				'label' => __( 'پخش خودکار', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'autoplay_speed',
			[
				'label' => __( 'سرعت پخش خودکار', 'themsah' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 2000,
				'condition' => [
					'autoplay' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
				],
			]
		);
		$this->add_control(
			'infinite',
			[
				'label' => __( 'بینهایت', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'transition',
			[
				'label' => __( 'نرمی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'slide',
				'options' => [
					'slide' => __( 'اسلاید', 'themsah' ),
					'fade' => __( 'محو شدن', 'themsah' ),
				],
			]
		);
		$this->add_control(
			'transition_speed',
			[
				'label' => __( 'سرعت نرمی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 500,
			]
		);
		$this->end_controls_section();
	}
	protected function register_general_slide_style_controls() {
		$this->start_controls_section(
			'section_style_slides',
			[
				'label' => __( 'اسلایدها', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'content_max_width',
			[
				'label' => __( 'عرض محتوی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ '%', 'px' ],
				'default' => [
					'size' => '66',
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-content' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'slides_padding',
			[
				'label' => __( 'فاصله داخلی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .slick-slide-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'slides_border_radius',
			[
				'label' => __( 'گردی گوشه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .slick-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'slides_horizontal_position',
			[
				'label' => __( 'موقعیت افقی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'default' => 'center',
				'options' => [
					'left' => [
						'title' => __( 'چپ', 'themsah' ),
						'icon' => 'eicon-h-align-right',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'راست', 'themsah' ),
						'icon' => 'eicon-h-align-left',
					],
				],
				'prefix_class' => 'elementor--h-position-',
			]
		);
		$this->add_control(
			'slides_vertical_position',
			[
				'label' => __( 'موقعیت عمودی', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'default' => 'middle',
				'options' => [
					'top' => [
						'title' => __( 'بالا', 'themsah' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => __( 'پایین', 'themsah' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'prefix_class' => 'elementor--v-position-',
			]
		);
		$this->add_control(
			'slides_text_align',
			[
				'label' => __( 'ترازبندی متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'label_block' => false,
				'options' => [
					'right' => [
						'title' => __( 'راست', 'themsah' ),
						'icon' => 'fa fa-align-right',
					],
					'center' => [
						'title' => __( 'وسط', 'themsah' ),
						'icon' => 'fa fa-align-center',
					],
					'left' => [
						'title' => __( 'چپ', 'themsah' ),
						'icon' => 'fa fa-align-left',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .slick-slide-inner' => 'text-align: {{VALUE}}',
				],
			]
		);
		$this->end_controls_section();
	}
	protected function register_general_slide_title_style_controls() {
		$this->start_controls_section(
			'section_style_top_title',
			[
				'label' => __( 'متن بالای عنوان', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'top_heading_spacing',
			[
				'label' => __( 'فاصله', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .slick-slide-inner .elementor-slide-top-heading:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
		$this->add_control(
			'top_heading_color',
			[
				'label' => __( 'رنگ متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-top-heading' => 'color: {{VALUE}}',

				],
			]
		);
		$this->add_control(
			'top_heading_b_color',
			[
				'label' => __( 'رنگ پس زمینه متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-top-heading' => 'background-color: {{VALUE}}',

				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'top_heading_typography',
				
				'selector' => '{{WRAPPER}} .elementor-slide-top-heading',
			]
		);
		$this->end_controls_section();

        $this->start_controls_section(
            'section_style_title',
            [
                'label' => __( 'عنوان', 'themsah' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'heading_spacing',
            [
                'label' => __( 'فاصله', 'themsah' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-slide-inner .elementor-slide-heading:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $this->add_control(
            'heading_color',
            [
                'label' => __( 'رنگ متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-slide-heading' => 'color: {{VALUE}}',

                ],
            ]
        );
        $this->add_control(
            'heading_b_color',
            [
                'label' => __( 'رنگ پس زمینه متن', 'themsah' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-slide-heading' => 'background-color: {{VALUE}}',

                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                
                'selector' => '{{WRAPPER}} .elementor-slide-heading',
            ]
        );
        $this->end_controls_section();
	}
	protected function register_general_slide_description_style_controls() {
		$this->start_controls_section(
			'section_style_description',
			[
				'label' => __( 'توضیحات', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'description_spacing',
			[
				'label' => __( 'فاصله', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .slick-slide-inner .elementor-slide-description:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
		$this->add_control(
			'description_color',
			[
				'label' => __( 'رنگ متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-description' => 'color: {{VALUE}}',

				],
			]
		);
		$this->add_control(
			'description_b_color',
			[
				'label' => __( 'رنگ پس زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-description' => 'background-color: {{VALUE}}',

				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				
				'selector' => '{{WRAPPER}} .elementor-slide-description',
			]
		);
		
			$this->add_control(
			'border_content_color',
			[
				'label' => __( 'رنگ خط حاشیه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .type-2 .elementor-slide-description.elementor-ken-fadeInUp' => 'border-color: {{VALUE}} !important',

				],
			]
		);
		
		
		
		$this->end_controls_section();
	}
	protected function register_general_slide_button_style_controls() {
		$this->start_controls_section(
			'section_style_button',
			[
				'label' => __( 'دکمه', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'button_size',
			[
				'label' => __( 'اندازه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'sm',
				'options' => self::get_button_sizes(),
			]
		);
		$this->add_control( 'button_color',
			[
				'label' => __( 'رنگ متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button' => 'color: {{VALUE}}; border-color: {{VALUE}}',

				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .elementor-slide-button',
				
			]
		);
		$this->add_control(
			'button_border_width',
			[
				'label' => __( 'ضخامت کادر', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button' => 'border-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'گردی گوشه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'after',
			]
		);
		$this->start_controls_tabs( 'button_tabs' );
		$this->start_controls_tab( 'normal', [ 'label' => __( 'Normal', 'themsah' ) ] );

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'رنگ متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button' => 'color: {{VALUE}};',
				],
			]
		);

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'button_background_color',
                'label' => esc_html__( 'رنگ زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .elementor-slide-button',
            ]
        );

		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'رنگ کادر', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab( 'hover', [ 'label' => __( 'هاور', 'themsah' ) ] );

		$this->add_control(
			'button_hover_text_color',
			[
				'label' => __( 'رنگ متن', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button:hover' => 'color: {{VALUE}};',
				],
			]
		);
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'button_hover_background_color',
                'label' => esc_html__( 'رنگ زمینه', 'themsah' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .elementor-slide-button:hover',
            ]
        );
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'رنگ کادر', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slide-button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();
	}
	protected function register_general_slide_navigation_style_controls() {
		$this->start_controls_section(
			'section_style_navigation',
			[
				'label' => __( 'ناوبری', 'themsah' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'navigation' => [ 'arrows', 'dots', 'both' ],
				],
			]
		);
		$this->add_control(
			'heading_style_arrows',
			[
				'label' => __( 'پیکان ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
		$this->add_control(
			'arrows_position',
			[
				'label' => __( 'مکان پیکان ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'inside',
				'options' => [
					'inside' => __( 'داخل', 'themsah' ),
					'outside' => __( 'بیرون', 'themsah' ),
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);

        $this->add_control(
            'arrow_horizontal_position',
            [
                'label' => __( 'جینش افقی پیکان ها', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'left-arrows',
                'label_block' => false,
                'options' => [
                    'left-arrows' => [
                        'title' => __( 'چپ', 'themsah' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center-arrows' => [
                        'title' => __( 'وسط', 'themsah' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'right-arrows' => [
                        'title' => __( 'راست', 'themsah' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'conditions' => [
                    'terms' => [
                        [
                            'name' => 'select-box',
                            'value' => 'type-2',
                        ],
                    ],
                ],
            ]
        );

		$this->add_control(
			'arrows_size',
			[
				'label' => __( 'انداره پیکان ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 20,
						'max' => 60,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-prev:before, {{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-next:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
				$this->add_responsive_control(
			'nav_border_radius',
			[
				'label' => __( 'گردی گوشه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .slick-prev::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
					'{{WRAPPER}} .slick-next::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);
		$this->start_controls_tabs( 'arrows_icon_tabs' );
		$this->start_controls_tab( 'arrows_icon_normal', [ 'label' => __( 'Normal', 'themsah' ) ] );

		$this->add_control(
			'arrows_color',
			[
				'label' => __( 'رنگ آیکون', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-prev:before, {{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-next:before' => 'color: {{VALUE}};',
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
		$this->add_control(
			'arrows_background_color',
			[
				'label' => __( 'رنگ زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-prev:before, {{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-next:before' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab( 'arrows_icon_hover', [ 'label' => __( 'هاور', 'themsah' ) ] );

		$this->add_control(
			'arrows_hover_color',
			[
				'label' => __( 'رنگ آیکون', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-prev:hover:before, {{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-next:hover:before' => 'color: {{VALUE}};',
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
		$this->add_control(
			'arrows_hover_background_color',
			[
				'label' => __( 'رنگ زمینه', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-prev:hover:before, {{WRAPPER}} .elementor-slides-wrapper .slick-slider .slick-next:hover:before' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'navigation' => [ 'arrows', 'both' ],
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'heading_style_dots',
			[
				'label' => __( 'نقطه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'navigation' => [ 'dots', 'both' ],
				],
			]
		);
		$this->add_control(
			'dots_position',
			[
				'label' => __( 'مکان نقطه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'inside',
				'options' => [
					'outside' => __( 'Outside', 'themsah' ),
					'inside' => __( 'Inside', 'themsah' ),
				],
				'condition' => [
					'navigation' => [ 'dots', 'both' ],
				],
			]
		);
		$this->add_control(
			'dots_size',
			[
				'label' => __( 'انداره نقطه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 5,
						'max' => 15,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .elementor-slides .slick-dots li button:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'navigation' => [ 'dots', 'both' ],
				],
			]
		);
		$this->add_control(
			'dots_color',
			[
				'label' => __( 'رنگ نقطه ها', 'themsah' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .elementor-slides .slick-dots li button:before' => 'color: {{VALUE}};',
				],
				'condition' => [
					'navigation' => [ 'dots', 'both' ],
				],
			]
		);
		$this->add_control(
			'dot_active_size',
			[
				'label' => __( 'رنگ نقطه فعال', 'themsah' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 5,
						'max' => 30,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-slides-wrapper .elementor-slides .slick-dots li.slick-active button:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'navigation' => [ 'dots', 'both' ],
				],
			]
		);
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings();



		if ( empty( $settings['slides'] ) ) {
			return;
		}

		$slides = [];
		$slide_count = 0;

		foreach ( $settings['slides'] as $slide ) {
			$slide_html = '';
			$btn_attributes = '';
			$slide_attributes = '';
			$slide_element = 'div';
			$btn_element = 'div';
			$slide_url = $slide['link']['url'];

			if ( ! empty( $slide_url ) ) {
				$this->add_render_attribute( 'slide_link' . $slide_count, 'href', $slide_url );

				if ( $slide['link']['is_external'] ) {
					$this->add_render_attribute( 'slide_link' . $slide_count, 'target', '_blank' );
				}

				if ( 'button' === $slide['link_click'] ) {
					$btn_element = 'a';
					$btn_attributes = $this->get_render_attribute_string( 'slide_link' . $slide_count );
				} else {
					$slide_element = 'a';
					$slide_attributes = $this->get_render_attribute_string( 'slide_link' . $slide_count );
				}
			}

			$txt_ani_class = '';
			if ( '' != $slide['animation_text'] ) {
				$txt_ani_class = ' elementor-ken-' . $slide['animation_text_style'];
			}

			if ( ! empty( $settings['button_size'] ) ) {
				$button_size_class = ' elementor-size-' . $settings['button_size'];
			}

			$ken_class = '';
			if ( '' != $slide['animation_bg'] ) {
				$ken_class = ' animation-bg elementor-ken-' . $slide['animation_bg_style'];
			}

			if ( 'yes' === $slide['background_overlay'] ) {
				$slide_html .= '<div class="elementor-background-overlay' . $ken_class . '"></div>';
			}

			$slide_html .= '<div class="elementor-slide-content">';

			if ( $slide['top_heading'] ) {
				$slide_html .= '<div class="elementor-slide-top-heading' . $txt_ani_class . '">' . $slide['top_heading'] . '</div>';
			}

            if ( $slide['heading'] ) {
                $slide_html .= '<div class="elementor-slide-heading' . $txt_ani_class . '">' . $slide['heading'] . '</div>';
            }

			if ( $slide['description'] ) {
				$slide_html .= '<div class="elementor-slide-description' . $txt_ani_class . '">' . $slide['description'] . '</div>';
			}

			if ( $slide['button_text'] ) {
				$button_text = $slide['button_text'];
				$slide_html .= "<$btn_element $btn_attributes class='elementor-button elementor-slide-button $txt_ani_class $button_size_class'>$button_text</$btn_element>";
			}

			$slide_html .= '</div>';
			$slide_html = '<div class="slick-slide-bg' . $ken_class . '"></div><' . $slide_element . ' ' . $slide_attributes . ' class="slick-slide-inner">' . $slide_html . '</' . $slide_element . '>';
			$slides[] = '<div class="elementor-repeater-item-' . $slide['_id'] . ' slick-slide">' . $slide_html . '</div>';
			$slide_count++;
		}

		$is_rtl = is_rtl();
		$direction = $is_rtl ? 'rtl' : 'ltr';
		$show_dots = ( in_array( $settings['navigation'], [ 'dots', 'both' ] ) );
		$show_arrows = ( in_array( $settings['navigation'], [ 'arrows', 'both' ] ) );

		$slick_options = [
			'slidesToShow' => absint( 1 ),
			'autoplaySpeed' => absint( $settings['autoplay_speed'] ),
			'autoplay' => ( 'yes' === $settings['autoplay'] ),
			'infinite' => ( 'yes' === $settings['infinite'] ),
			'pauseOnHover' => ( 'yes' === $settings['pause_on_hover'] ),
			'speed' => absint( $settings['transition_speed'] ),
			'arrows' => $show_arrows,
			'dots' => $show_dots,
			'rtl' => $is_rtl,
		];

		if ( 'fade' === $settings['transition'] ) {
			$slick_options['fade'] = true;
		}

		$carousel_classes = [ 'elementor-slides' ];

		if ( $show_arrows ) {
			$carousel_classes[] = 'slick-arrows-' . $settings['arrows_position'];
		}

		if ( $show_dots ) {
			$carousel_classes[] = 'slick-dots-' . $settings['dots_position'];
		}

		$this->add_render_attribute( 'slides', [
			'class' => $carousel_classes,
			'data-slick' => wp_json_encode( $slick_options ),
		] );

		?>
		
	
        <div class="elementor-slides-wrapper <?php echo $settings['select-box'].' '.$settings['arrow_horizontal_position']; ?>  elementor-slick-slider" dir="<?php echo esc_attr( $direction ); ?>">
            <div <?php echo $this->get_render_attribute_string( 'slides' ); ?>>
				<?php echo implode( '', $slides ); ?>
            </div>
        </div>
		<?php
	}

	protected function _content_template() {
		?>
        <#
        var isRtl           = <?php echo is_rtl() ? 'true' : 'false'; ?>,
        direction       = isRtl ? 'rtl' : 'ltr',
        navi            = settings.navigation,
        showDots        = ( 'dots' === navi || 'both' === navi ),
        showArrows      = ( 'arrows' === navi || 'both' === navi ),
        autoplay        = ( 'yes' === settings.autoplay ),
        infinite        = ( 'yes' === settings.infinite ),
        speed           = Math.abs( settings.transition_speed ),
        autoplaySpeed   = Math.abs( settings.autoplay_speed ),
        fade            = ( 'fade' === settings.transition ),
        buttonSize      = settings.button_size,
        sliderOptions = {
        "initialSlide": Math.max( 0, editSettings.activeItemIndex-1 ),
        "slidesToShow": 1,
        "autoplaySpeed": autoplaySpeed,
        "autoplay": false,
        "infinite": infinite,
        "pauseOnHover":true,
        "pauseOnFocus":true,
        "speed": speed,
        "arrows": showArrows,
        "dots": showDots,
        "rtl": isRtl,
        "fade": fade
        }
        sliderOptionsStr = JSON.stringify( sliderOptions );
        if ( showArrows ) {
        var arrowsClass = 'slick-arrows-' + settings.arrows_position;
        }

        if ( showDots ) {
        var dotsClass = 'slick-dots-' + settings.dots_position;
        }

        #>
        <div class="elementor-slides-wrapper elementor-slick-slider" dir="{{ direction }}">
            <div data-slick="{{ sliderOptionsStr }}" class="elementor-slides {{ dotsClass }} {{ arrowsClass }}">
                <# _.each( settings.slides, function( slide ) { #>
                <div class="elementor-repeater-item-{{ slide._id }} slick-slide">
                    <#
                    var kenClass = '';

                    if ( '' != slide.animation_bg ) {
                    kenClass = ' animation-bg elementor-ken-' + slide.animation_bg_style;
                    }

                    var txtAniClass = '';

                    if ( '' != slide.animation_text ) {
                    txtAniClass = ' elementor-ken-' + slide.animation_text_style;
                    }
                    #>
                    <div class="slick-slide-bg{{ kenClass }}"></div>
                    <div class="slick-slide-inner">
                        <# if ( 'yes' === slide.background_overlay ) { #>
                        <div class="elementor-background-overlay{{ kenClass }}"></div>
                        <# } #>
                        <div class="elementor-slide-content">
                            <# if ( slide.heading ) { #>
                            <div class="elementor-slide-heading{{ txtAniClass }}">{{{ slide.heading }}}</div>
                            <# }
                            if ( slide.description ) { #>
                            <div class="elementor-slide-description{{ txtAniClass }}">{{{ slide.description }}}</div>
                            <# }
                            if ( slide.button_text ) { #>
                            <div class="elementor-button elementor-slide-button{{ txtAniClass }} elementor-size-{{ buttonSize }}">{{{ slide.button_text }}}</div>
                            <# } #>
                        </div>
                    </div>
                </div>
                <# } ); #>
            </div>
        </div>
		<?php
	}
}
