<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


class Team extends Widget_Base {

	public function get_name() {
		return 'Team';
	}

	public function get_title() {
		return __( 'باکس اعضای تیم', 'themsah' );
	}


	public function get_icon() {
		return 'eicon-custom-team';
	}


	public function get_categories() {
		return [ 'themsah_cat' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'محتوا', 'themsah' ),
			]
		);
		$this->add_control(
			'image',
			[
				'label'   => __( 'تصویر', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'list_title', [
				'label'       => __( 'نام', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'تیم تمساح', 'themsah' ),
				'label_block' => true,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'icon',
			[
				'label'   => __( 'ایکن', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value'   => 'fas fa-instagram',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label'   => __( 'لینک', 'themsah' ),
				'type'    => \Elementor\Controls_Manager::URL,
				'default' => [
					'url' => ''
				],
			]
		);


		$this->add_control(
			'list',
			[
				'label'       => __( 'شبکه های اجتماعی', 'themsah' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'icon' => __( 'fas fa-instagram', 'themsah' ),
					],

				],
				'title_field' => 'شبکه اجتماعی',
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'تنظیمات محتوای باکس', 'plugin-name' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'box-border-radius',
			[
				'label' => __( 'گردی گوشه ها', 'plugin-domain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .team .box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'سایه باکس', 'plugin-domain' ),
				'selector' => '{{WRAPPER}} .team .box',
			]
		);

		$this->add_responsive_control(
			'image-height',
			[
				'label' => __( 'ارتفاع تصویر', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 380,
				],
				'selectors' => [
					'{{WRAPPER}} .team .box' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content-bac',
			[
				'label'     => __( 'پس زمینه محتوا', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,

				'selectors' => [
					'{{WRAPPER}} .team .box .content' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content-b-color',
			[
				'label'     => __( 'رنگ خط بالا', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .box:hover .content' => 'border-color: {{VALUE}}',
				],
			]
		);



		$this->add_control(
			'title_color',
			[
				'label'     => __( 'رنگ عنوان', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .box .content h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'تایپوگرافی عنوان', 'themsah' ),
				
				'selector' => '{{WRAPPER}} .team .box .content h3',
			]
		);


		$this->add_control(
			'icon-color',
			[
				'label'     => __( 'رنگ آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,

				'selectors' => [
					'{{WRAPPER}} .team .box .content a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'icon-color-hover',
			[
				'label'     => __( 'رنگ هاور آیکن', 'themsah' ),
				'type'      => \Elementor\Controls_Manager::COLOR,

				'selectors' => [
					'{{WRAPPER}} .team .box .content a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

	}


	protected function render() {
		$settings = $this->get_settings_for_display(); ?>
        <div class="team">
                <div class="box">
                    <img src="<?= $settings['image']['url']; ?>" alt="">
                    <div class="content">
                        <h3><?= $settings['list_title'];?></h3>
						<?php if ( $settings['list'] ) { ?>
                            <div class="socials">
								<?php foreach ( $settings['list'] as $item ) { ?>
                                    <a href="<?= $item['link']['url'];?>"> <?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?> </a>
								<?php } ?>
                            </div>
						<?php } ?>
                    </div>
                </div>
        </div>


	<?php }


	protected function _content_template() {
	}
}
