<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use WP_Query;


if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly


class Thetitle extends Widget_Base {

    public function get_name() {
        return 'Thetitle';
    }

    public function get_title() {
        return __( 'عنوان صفحه', 'themsah' );
    }


    public function get_icon() {
        return 'eicon-post-title';
    }


    public function get_categories() {
        return [ 'themsah_cat' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'Content', 'plugin-name' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'tag-name',
            [
                'label'   => __( 'تگ HTML', 'themsah' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'h2',
                'options' => [
                    'h1'   => __( 'H1', 'themsah' ),
                    'h2'   => __( 'H2', 'themsah' ),
                    'h3'   => __( 'H3', 'themsah' ),
                    'h4'   => __( 'H4', 'themsah' ),
                    'h5'   => __( 'H5', 'themsah' ),
                    'h6'   => __( 'H6', 'themsah' ),
                    'span' => __( 'span', 'themsah' ),
                    'div'  => __( 'div', 'themsah' ),
                    'p'    => __( 'p', 'themsah' ),
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => __( 'رنگ عنوان صفحه', 'themsah' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .the-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'label'    => __( 'تایپوگرافی', 'themsah' ),
                
                'selector' => '{{WRAPPER}} .the-title',
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__( 'چینش افقی', 'themsah' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'چپ', 'themsah' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'وسط', 'themsah' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'راست', 'themsah' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'flex-start',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .the-title' => 'text-align:{{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }


    protected function render() {
        $settings = $this->get_settings_for_display();
        echo '<' . $settings['tag-name'] . ' class="the-title">';
        global $wp_query;
        if ( is_tax() ) {
            if ( have_posts() ) {
                while ( have_posts() ) {
                    the_post();
                }
            }
            $tax = $wp_query->get_queried_object();
            echo $tax->name;
        } elseif ( is_post_type_archive( 'portfolio' ) ) {
            if ( have_posts() ) {
                while ( have_posts() ) {
                    the_post();
                }
            }
            echo get_theme_mod( 'portfolio_label', 'پروژه ها' );
        } elseif ( is_singular() && ! is_page() ) {
            if (\Elementor\Plugin::$instance->editor->is_edit_mode()){
                $post_meta = get_post_meta( get_the_ID() );
                if ( $post_meta['themsah-select-template'][0] == 'post_single' ) {
                    global $post;
                    if ( ! is_singular( 'post' ) ) {
                        $post = themsah_get_preview_post(); // phpcs:ignore
                        setup_postdata( $post );
                    }

                    the_title();

                    if ( ! is_singular( 'post' ) ) {
                        wp_reset_postdata();
                    }
                } elseif ( $post_meta['themsah-select-template'][0] == 'product_single' ) {
                    global $post;
                    if ( ! is_singular( 'product' ) ) {
                        $post = themsah_get_preview_product(); // phpcs:ignore
                        setup_postdata( $post );
                    }

                    the_title();

                    if ( ! is_singular( 'product' ) ) {
                        wp_reset_postdata();
                    }

                }elseif ( $post_meta['themsah-select-template'][0] == 'portfolio_single' ) {
                    $the_query = new WP_Query( array( 'post_type' => 'portfolio', 'posts_per_page' => 1 ) );
                    if ( $the_query->have_posts() ) {
                        while ( $the_query->have_posts() ) {
                            $the_query->the_post();
                            the_title();
                        }
                    }wp_reset_postdata();
                }elseif ($post_meta['themsah-select-template'][0] == 'product_archive'){
                    echo get_the_title( wc_get_page_id( 'shop' ) );
                }else {
                    global $pagenow;
                    if (( $pagenow == 'page.php' ) || (get_post_type() == 'page')) {
                        wp_title( '' );
                    }
                }

            }else {
                if ( have_posts() ) {
                    while ( have_posts() ) {
                        the_post();
                    }
                }
                the_title();
            }



        } elseif ( is_page() ) {

            wp_title( '' );

        } elseif ( is_category() || is_tag() ) {
            if ( have_posts() ) {
                while ( have_posts() ) {
                    the_post();
                }
            }
            wp_title( '' );
        } else {
            if ( have_posts() ) {
                while ( have_posts() ) {
                    the_post();
                }
            }
            wp_title( '' );
        }

        echo '</' . $settings['tag-name'] . '>';
    }


    protected function _content_template() {
    }
}
