<?php

namespace ThemsahAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;


if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Themsah_Image_Box extends Widget_Base
{

    public function get_name()
    {
        return 'themsah-image-box';
    }

    public function get_title()
    {
        return __('باکس تصویر', 'themsah');
    }


    public function get_icon()
    {
        return 'eicon-image';
    }


    public function get_categories()
    {
        return ['themsah_cat'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content5',
            [
                'label' => __('تنظیمات باکس', 'themsah'),
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__( 'انتخاب عکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_content55',
            [
                'label' => __('تنظیمات محتوای باکس', 'themsah'),
            ]
        );

        $this->add_control(
            'widget_number',
            [
                'label' => esc_html__( 'متن بالا', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Default title', 'plugin-name' ),

            ]
        );
        $this->add_control(
            'widget_title',
            [
                'label' => esc_html__( 'متن پایین', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Default title', 'plugin-name' ),

            ]
        );
        $this->add_control(
            'icon-image',
            [
                'label' => esc_html__( 'ایکون', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-star',
                    'library' => 'solid',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'style_section',
            [
                'label' => esc_html__( 'تنظیمات باکس', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'width',
            [
                'label' => esc_html__( 'عرض عکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .themsah-image' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'image-border-radius',
            [
                'label' => esc_html__( 'انحنای مرز', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .themsah-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'before-image',
            [
                'label' => esc_html__( 'رنگ حاشیه' , 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themsah-image::after ' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'style_section_content',
            [
                'label' => esc_html__( 'تنظیمات محتوای باکس', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'background-box-content',
            [
                'label' => esc_html__( 'رنگ پس زمینه' , 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .info-image' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'سایه باکس', 'plugin-name' ),
                'selector' => '{{WRAPPER}} .info-image',
            ]
        );


        $this->add_control(
            'box-border-radius',
            [
                'label' => esc_html__( 'انحنای مرز', 'plugin-name' ),
                'separator' => 'after',
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .info-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'color-top-text',
            [
                'label' => esc_html__( 'رنگ متن بالا' , 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .info-image span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => esc_html__( 'تایپوگرافی متن بالا' , 'plugin-name' ),
                'selector' => '{{WRAPPER}} .info-image span',
            ]
        );

        $this->add_control(
            'color-bottom-text',
            [
                'label' => esc_html__( 'رنگ متن پایین' , 'plugin-name' ),
                'separator' => 'before',
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .info-image p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography1',
                'label' => esc_html__( 'تایپوگرافی متن پایین' , 'plugin-name' ),
                'selector' => '{{WRAPPER}} .info-image p',

            ]
        );
        $this->add_control(
            'background-icon',
            [
                'label' => esc_html__( 'بک گراند ایکون' , 'plugin-name' ),
                'separator' => 'before',
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .icon-image' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'color-icon',
            [
                'label' => esc_html__( 'رنگ ایکون' , 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .icon-image svg fill' => 'path: {{VALUE}}',
                    '{{WRAPPER}} .icon-image i' => 'color: {{VALUE}}',

                ],
            ]
        );

        $this->add_control(
            'font-icon',
            [
                'label' => esc_html__( 'سایز آیکون', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],

                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .icon-image svg' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .icon-image i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );



        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>

        <div class="themsah-image">
            <img src=" <?php echo  $settings['image']['url']; ?> " alt="">
            <div class="info-image">
                <span><?php echo $settings['widget_number']; ?></span>
                <p><?php echo $settings['widget_title']; ?></p>
                <div class="icon-image">
                    <?php \Elementor\Icons_Manager::render_icon( $settings['icon-image'], [ 'aria-hidden' => 'true' ] ); ?>
                </div>
            </div>
        </div>


    <?php }


    protected function _content_template()
    {
    }
}
